; Convenient execution of Scheme files from Emacs.
; Top level functions: laml-process-current-buffer, laml-process-buffer,
; and laml-sync-process-current-buffer. 

; The LAML library and programs are written by Kurt Normark, Aalborg University, Denmark.
; Copyright (C) 1999  Kurt Normark, normark@cs.auc.dk.
; 
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

; Indentical to windows_nt40_mzscheme_laml-execute.el

; OK on GNU emacs on win98 and NT4.0.     OK on WinEmacs on win98 and NT4.0
(defun laml-process-current-buffer ()
  "Run mzScheme on the file in the current buffer. Before processing, save the current buffer."
  (interactive)
  (let* ((cur-dir (current-directory))
         (file-path (concat cur-dir (current-file)))
         (laml-init (concat laml-dir "laml.init"))
         (original-buffer (current-buffer))
         (buf-name-1 (buffer-name (current-buffer)))
         (buf-name
            (if (buffer-versioned buf-name-1)
                (buffer-without-version buf-name-1)
                buf-name-1))
         (filename-without-extension (file-name-proper buf-name))
         (out-buf (get-buffer-create "scm-output"))
        )
    (kill-laml-processes)
    (save-buffer)
    (delete-other-windows)
    (split-window)
    (show-buffer (other-window 1) out-buf)
    (set-buffer out-buf)
    (erase-buffer)
    (insert "LAML Emacs Processing") (insert CR)
    (goto-char (point-max))
    (start-process "LAML" out-buf scheme-exec  "-v"  "-f" laml-init "-d" file-path 
                    filename-without-extension cur-dir)
    (other-window 1)
    (enlarge-window source-window-enlargement)
    ))




; This implementation depends on the pressence of the init file laml.init in the laml directory
; which sets laml-dir.
; OK on GNU emacs on win98 and NT4.0.     OK on WinEmacs on win98 and NT4.0
(defun laml-process-buffer (buffer)
  "Process the laml buffer by mzScheme.  Buffer may be a buffer name, or a buffer.
Before processing, save the buffer."
  (interactive)
  (let* ((cur-dir (current-directory))
         (laml-init (concat laml-dir "laml.init"))
         (buf-name (if (bufferp buffer) (buffer-name buffer) buffer))
         (the-buffer (if (bufferp buffer) buffer (get-buffer buffer)))
         (buf-name-1
            (if (buffer-versioned buf-name)
                (buffer-without-version buf-name)
                buf-name))
         (filename-without-extension (file-name-proper buf-name-1))
         (out-buf (get-buffer-create "scm-output")))
    (kill-laml-processes)
    (set-buffer buffer)
    (save-buffer)
    (delete-other-windows)
    (split-window)
    (show-buffer (other-window 1) out-buf)
    (set-buffer out-buf)
    (erase-buffer)
    (insert "LAML Emacs Processing") (insert CR)
    (let* ((file-path (buffer-file-name the-buffer))     ; full path of buffer's file
           (buf-dir   (file-name-directory file-path))    ; directory part of file-path
          )
      (start-process "LAML" out-buf  scheme-exec  "-v" "-f" laml-init
                     "-d" file-path filename-without-extension buf-dir))))


; mzScheme - synchronous
; OK on GNU emacs on win98 and NT4.0.     OK on WinEmacs on win98 and NT4.0
(defun laml-sync-process-current-buffer ()
  "Run mzScheme on the file in the current buffer. Wait until finished. Show the last line of the Scheme output in the minibuffer"
  (interactive)
  (let* ((cur-dir (current-directory))
         (scm-output (get-buffer-create "sync-scm-output"))
         (file-path (concat (current-directory) (current-file)))
         (laml-init (concat laml-dir "laml.init"))
         (buf-name-1 (buffer-name (current-buffer)))
         (buf-name
             (if (buffer-versioned buf-name-1)
                 (buffer-without-version buf-name-1)
                 buf-name-1))
         (filename-without-extension (file-name-proper buf-name))
       )
    (save-buffer)
    (set-buffer scm-output)
    (erase-buffer)
    (message "Synchronous LAML processing. Please wait...")
    (call-process scheme-exec nil scm-output nil  "-v"  "-f" laml-init "-d" file-path 
                    filename-without-extension cur-dir)
    (message (last-buffer-line scm-output))))







