; The LAML library and programs written by Kurt Normark, Aalborg University, Denmark.
; Copyright (C) 1999  Kurt Normark.
; 
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


;;;; This tool generates a sequence of Scheme define forms for a specified set of tags (such as the tags in a version or variant
;;;; of HTML).
;;;; More specifically, we are able to generate a text file with Scheme definitions for a specified set of HTML single and double tags.<p>
;;;; You must call the procedure generate-html in order to carry out the generation.
;;;; This makes the file: html-autogenerated-functions.scm.
;;;; The generated functions call generate-tag-function and generate-tag1-function, both of which can be found in the
;;;; HTML vers. 1 library. <p>
;;;; The generated file can be loaded or inserted into another file. <p>
;;;; The HTML vers. 1 library is an example of a library which includes a result generated by this tool.<p>
;;;; Usage: Start a Scheme interpreter, and define the variable laml-dir appropriately.
;;;; Load this file into your Scheme system, adapt the lists of tags, and call the function generate-html.<p>
;;;; <b> Please notice that this is NOT the tool that generates the accurate HTML mirror which is now used in LAML. </b>

(load (string-append laml-dir "laml.scm"))

(define (lib-load f)
  (load (string-append laml-dir laml-library "/" f)))

(lib-load "general.scm")
(lib-load "file-read.scm")

;; a list of a html single tags (symbols) for which we want to generate Scheme mirrors. 
;; A list of Scheme symbols.
(define html-single-tags 
  (list 'area 'base 'basefont 'bgsound 'br 'col 'colgroup 'hr 'img 'input 'isindex 'link 'meta 'nextid 'plaintext 'pre 's 
        'spacer 'tbody 'tfoot 'thead 'wbr
  )
)

;; a list of a html double tags (symbols) for which we want to generate Scheme mirrors. 
;; A list of Scheme symbols.
(define html-double-tags 
  (list 'a 'address 'applet 'b 'big 'blockquote 'body 'caption 'center 'cite 'code 'comment 'dd 'dfn 'dir 'div 'dl
        'dt 'em 'embed 'font 'form 'frame 'frameset 'h1 'h2 'h3 'h4 'h5 'h6 'head 'html 'i 'iframe 'kbd 'li 'map
        'marquee 'menu 'multicol 'nobr 'noframes 'noscript 'object 'ol 'option 'p 'param 'samp 'script 'select 'small 'span
        'strike 'strong 'style 'sub 'sup 'table 'td 'textarea 'title 'tr 'tt 'ul 'var 
  )
)

(define double-standard-1-comment ";; A Scheme mirrored HTML single tag function. Auto generated by means of the functions in html-tag-generation.scm. <p>
;; Usage: <pre>(html:tag 'attr1 val1 'attr2 val2) </pre>")

(define double-standard-2-comment ";; A Scheme mirrored HTML double tag function. Auto generated by means of the functions in html-tag-generation.scm. <p>
;; Usage: <pre>(html:tag contents-form 'attr1 val1 'attr2 val2) </pre>")

(define quote-string (as-string #\"))
(define CR-string (as-string #\newline))

(define (string-it x)
  (string-append quote-string  x quote-string))

(define (define-form tag)
 (let ((tag-string (as-string tag)))
  (string-append 
     double-standard-2-comment CR-string
     "(" "define" " " "html:" tag-string " " "(" "generate-tag-function" " " (string-it tag-string) ")" ")" CR-string)))

(define (define-form-1 tag)
 (let ((tag-string (as-string tag)))
  (string-append 
     double-standard-1-comment  CR-string
     "(" "define" " " "html:" tag-string " " "(" "generate-tag1-function" " " (string-it tag-string) ")" ")" CR-string)))

;; The functions which generate the Scheme mirror from the lists html-double-tags and html-single-tags.
;; Given the lists html-single-tags and html-double-tags, write a sequence of Scheme define forms to a text file.
;; This mirrors all the tags in the two lists into the Scheme programming language.
;; The result is written to the file html-autogenerated-functions.scm
(define (generate-html)
 (let* ((result-double
          (map define-form html-double-tags))
        (result-single
          (map define-form-1 html-single-tags))
        (CR-result-double
          (map (lambda (form) (string-append form CR-string)) result-double))
        (CR-result-single
          (map (lambda (form) (string-append form CR-string)) result-single)))
  (write-text-file
    (string-append "; generated by html-tag-generation.scm. Do not edit" CR-string
                   (apply string-append CR-result-double)
                   (apply string-append CR-result-single))
    "html-autogenerated-functions.scm")))





