(((kind "manual-page") (description "This function is the main function. As such, this function IS the schemedoc tool.
The function takes as input a name of a scheme file (full path, file extension inclusive).
The function returns a list structures suitable for the manual style to display via the function
make-manual. Notice that make-manual is not called from this function.
") (title "extract-documentation-from-scheme-file") (form (extract-documentation-from-scheme-file scheme-file))) ((kind "manual-page") (description "A boolean variable which tells whether to delete the temporary (by this tool) generated source
file, in which comments are syntactical Lisp forms. The name of the source file is determined by
the variable temp-output-file. By default, the value is t.
") (title "delete-comment-file?") (form delete-comment-file?)) ((kind "manual-section") (section-title "How to use comments for documentation purposes.") (section-body "
In order to have documentation extracted, the documentation is organized in comments
with one, two, three, or four initial semicolons. Recall that semicolons are the Lisp lexical
comment symbols: The rest of a line with a semicolon is a comment.<p>
All one comment semicolon comments are ignored by this facility. N semicolon comments, N higher than one, are called SchemeDoc comments. <p>
Two semicolon comments are used as comments of define forms. You can either place
the comment before the define form or after the name/signature of the define form. <p>
Three semicolon comments
are used for text sections between documented forms.  The first
sentence (separated with '.' and a space) is used as the title of the text section.
(This text your are reading now - in a browser- is written in a three semicolon comment).<p>
Four semicolon comments are used as the introduction to a documentation document. 
There should, as such, only by one four semicolon comment in a Scheme file. <p>

Please notice that function definitions of the form <p>
<pre>
  (define f (lambda (par) ...)) <p>
</pre>
should be documented with a two semicolon comment before the form, whereas <p>
<pre>
  (define (f par) ...) <p>
</pre>
can be documented with two semicolon comments before the form or just after (f par). 
If you have two semicolon comments both before and within the define form they are concatenated. <p>
It is possible to use HTML formatting within a schemedoc comment.<p>

In comments at level two there
may be additional <b>internal tagging</b> at the end of the comment. Here is an example:<p>

<pre>;; Return the fifth element of a list
;; .form (fifth x)
;; .parameter x must be a list
(define fifth (make-selector-function 5)) 
</pre>

The Schemedoc tool parses the comments and returns a list like

<pre>
(
 (description \"Return the fifth element of a list\")
 (form \"(fifth x)\"
 (param \"x must be a list\")
)
</pre>
The manual producing tool may decide to parse additional parts of the strings (the cadr parts of the lists shown above).<p>

The general format of an internal Schemdoc tag is: <br>
 <kbd>.key description</kbd>.<p>

The rules concerning internal tags in Schemedoc comments are the following:

<ol>
<li> Each tag starts with a dot '.' and runs through the line, until CR.
<li> The only characters allowed between the semicolons and <kbd>.key</kbd> are blank space characters (space, tab).
<li> Internal tags must be at the end of a comment; no descriptions (besides other internal tags) must be found after them.
<li> key can be an arbitry symbol without spaces. The manual style, however, only recognizes title, form, pre-condition, 
     description, parameter, reference, internal-references, misc, and comment. 
<li> The descriptions in .title, .precondition, .example, .comment, .return and .misc is arbitrary free text (without newlines).
<li> There cannot be an internal tag on the first comment line. In other words, the first line must be a description.
<li> Of parsing purposes, string quotes must be used around categories, anchors, refs and urls in .reference and .internal-references.
</ol>
The following internal tags are supported
<pre>
  .title Some title
  .form (form-name par1 par2)
  .pre-condition Some Precondition
  .description Some Description
  .parameter par-name parameter description
  .example some example
  .reference \"category\" \"anchor\" \"url\"
  .internal-references \"category\" \"ref1\" \"ref2\" ...
  .misc Miscelaneous information
  .comment Internal comment
  .returns Return value description
</pre>

Internal references support categorized cross references within the current manual page. <p>

A reference is a categoried reference from an anchor to an arbitrary url.<p>

We see that all manual clauses of the LAML manual document styles are supported except
<kbd>parameters</kbd> (plural) and <kbd>cross-references</kbd>. These two are made
automatically from a number of <kbd> parameter </kbd> clauses (singular), and a 
number of <kbd> reference </kbd> and <kbd> internal-references </kbd> clauses (not necessarily adjecent).



")) ((kind "manual-section") (section-title "The first internal function.") (section-body "
The function in this section makes lexical Lisp style comments to syntactical comments.
We document it because it may be useful in its own right.")) ((kind "manual-page") (description "Given the source file, scheme-input-file, make another file scheme-output-file,
in which the lexical comments are turned into syntactic comments in terms of comment forms.
The first parameter of a comment form is the number of semicolons in the lexical comment.
The second parameter is the comment text itself. Several consequtive lines of (equally leveled
comments) are organized in one comment form.
") (title "lexical-to-syntactical-comments!") (form (lexical-to-syntactical-comments! scheme-input-file scheme-output-file))) ((kind "manual-page") (description "The name of the file where the function lexical-to-syntactical-comments! places it's output
") (title "temp-output-file") (form temp-output-file)) ((kind "manual-section") (section-title "The second internal function.") (section-body "
The function in this section extracts relevant level n, n > 2, comments
for documentation purposes")) ((kind "manual-page") (description "A variable holding the extracted manual abstract.
") (title "extracted-manual-abstract") (form extracted-manual-abstract)) ((kind "manual-page") (description "Extract a manual style list of documentation from file-name and return it.
It is assumed that file-name contains syntactical (comment ...) comments.
") (title "extract-relevant-documentation") (form (extract-relevant-documentation file-name))) ((kind "manual-section") (section-title "Internal tagging support in schemedoc comments.") (section-body "
")) ((kind "manual-page") (description "Parse the comment string, in order to extract internal tagging.
If no internal tagging is found return ((description \"comment-string\")).
If at least one internal tag is found return an a-list of the form
((tag-1-symbol va1-1-string) (tag-2-symbol va1-2-string) ...). The string part
before the first tag is returned as (description \"string part before first tag\")
in the list.
") (title "extract-internal-tagging") (form (extract-internal-tagging comment-string))) ((kind "manual-section") (section-title "Known problems.") (section-body "<pre>
A single semicolon comment ; without any trailing text causes problems for the transformation to syntactical comments.
</pre>
")))