(((kind "manual-section") (section-title "The format of the parse tree.") (section-body "A <em>parse tree</em> T  produced by this tool is of the form
<pre>    (tree N ST1 ST2 ... STn) </pre>
where STi, i=1..n are parse trees (recursively) and N is a node (see below). <p>
A leaf node N may be of the form
<pre>    (tree N) </pre>
or just N if N is a string (corresponding to textual contents) or an empty tag (a tag without contents).<p>
An <em>inner node</em> of a parse tree corresponds to a tag (an element) with contents. Such a node is represented
by the following 'tag structure':
<pre>    (tag kind tag-name . attr-info) </pre>
tag is a symbol (for tagging). kind is either start or start-end (both symbols).
tag-name is a string. Attr-info is the attribute on property list format.<p>
A <em>terminal node</em> may be a start-end node, a comment node or just a contents string. End tags are not represented 
in the parse tree.<p>
Here is an example of a start-end node (empty node) with two properties:
<pre>    (tag start-end \"title\" role \"xxx\" size \"5\") </pre>
Comments are represented as comment nodes of the form
<pre>    (comment comment-string) </pre> <p>
Declaration nodes of the form
<pre>    (declaration kind value) </pre>
are also possible. They are for instance used for document type (???) information in HTML. Finally nodes of the form
<pre>    (xml-declaration attribute-property-list) </pre>
are supported.


")) ((kind "manual-section") (section-title "Top level parser functions.") (section-body "
")) ((kind "manual-page") (description "Top level parse function which takes an XML file name as input, and delivers a parse tree on out-file-path.
file-path is a file path (relative or absolute) with or without an extension. The default extension is xml.
The parse tree is written on the file out-file-path.
") (title "parse-xml-file") (form (parse-xml-file in-file-path out-file-path))) ((kind "manual-page") (description "This function parses a file and returns the parse tree.
file-path is a file path (relative or absolute) without any extension. 
") (title "parse-xml") (form (parse-xml file-path))) ((kind "manual-page") (description "A global varible holding the latest produced parse tree
") (title "resulting-parse-tree") (form resulting-parse-tree)) ((kind "manual-page") (description "aggregate remaining stack entries as subtrees of a kind node. kind is a symbol, such
as html-tree or xml-tree
") (title "aggregate-final-parse-tree") (form (aggregate-final-parse-tree kind))) ((kind "manual-section") (section-title "Utility parser functions.") (section-body "
The functions in this section are all miscelaneous and utility functions of the parser.

")) ((kind "manual-page") (description "Traverse the parse tree, tree, and return a list of result-transformed nodes 
that satisfy the node-interesting? predicate in the parse tree.
In other words, apply the node-interesting? predicate to all subtrees of the tree during the traversal, and return
the result-transformed list of subtrees.
Both the functions node-interesting? and result-transformer are applied on trees and subtrees.") (example " (traverse-and-collect-from-parse-tree resulting-parse-tree (is-tag-of-kind? 'a) parse-tree-to-laml-expression) ") (title "traverse-and-collect-from-parse-tree") (form (traverse-and-collect-from-parse-tree tree node-interesting? result-transformer))) ((kind "manual-page") (description "Traverse the parse tree, tree, and return the list all attribute values of the attribute attr-key found
in the tree.") (example "(collect-attributes-in-tree tree 'href) ") (title "collect-attributes-in-tree") (form (collect-attributes-in-tree tree attr-key))) ((kind "manual-page") (description "Retun a predicate which tests whether a subtree or node is of tag-kind (a symbol or string).
This function is a useful second parameter to traverse-and-collect-from-parse-tree.
") (title "is-tag-of-kind?") (form (is-tag-of-kind? tag-kind))) ((kind "manual-page") (description "Display parser status in case of error in the parse process.
") (title "parser-status") (form (parser-status))) ((kind "manual-page") (description "Transform an XML or HTML parse tree to a similar LAML expression on output-file. 
When processed, the LAML file will write the a LAML file, say f.laml, 
to f.html in the same directory as the laml file.
") (title "parse-tree-to-laml") (form (parse-tree-to-laml tree output-file))) ((kind "manual-page") (description "Transform an XML or HTML parse tree to a LAML expressions (in terms of a Scheme list structure).
This function is similar to parse-tree-to-laml which delivers a textual result 
(a string) on an output file
") (title "parse-tree-to-laml-expression") (form (parse-tree-to-laml-expression tree))) ((kind "manual-section") (section-title "Top level XML pretty printing functions.") (section-body "
")) ((kind "manual-page") (description "Pretty prints the XML parse tree (Lisp file) in in-file-path.
Outputs the pretty printed result in out-file-path.") (form "(pretty-print-xml-parse-tree-file in-file-path [out-file-path])") (title "pretty-print-xml-parse-tree-file")) ((kind "manual-page") (description "Pretty prints a HTML parse tree, and return the result as a string.
") (title "pretty-print-xml-parse-tree") (form (pretty-print-xml-parse-tree parse-tree))) ((kind "manual-section") (section-title "Variables that control the pretty printing.") (section-body "These variables apply for both HTML and XML.

")) ((kind "manual-page") (description "An integer which gives the level of indentation
") (title "indentation-delta") (form indentation-delta)) ((kind "manual-page") (description "A boolean which controls the application of single line pretty printing.
If true, the pretty printer will pretty print short list forms on a single line
") (title "use-single-lining") (form use-single-lining)) ((kind "manual-page") (description "An integer that expresses the preferred maximum column width
") (title "prefered-maximum-width") (form prefered-maximum-width)))