; The LENO lecture note LAML style. html4.0 supported.

; The LAML library and programs are written by Kurt Normark, Aalborg University, Denmark.
; Copyright (C) 1999  Kurt Normark, normark@cs.auc.dk.
; 
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(define leno-version "10")

(define (set-language language)
  ; either the symbol 'danish og 'english.
 (set! language-preference language) ; language-preference is in laml.scm
)

(define notes-subtitle #f)

(define slide-header-as-frame? #f)

(define lecture-note-verbose-mode #t)

; A variable which controls the generation of the header banner in slide view.
; If the value is the symbol normal use normal slide header (navigation buttons).
; If the value of the variable is none generate an empty header banner.
; In the value is minimal generate a tiny small font info about the slide.
; With the values none or minimal, navigation from slide to slide must be done via the keyboard.
(define slide-header? 'normal) ; one of the symbols normal, none, or minimal

; A variable which controls whether to make a parallel trail of the lecture.
; This makes a frameset for each slide, cause many more files in the html directory.
(define trail-of-lecture? #f)

; A variable which controls the generation of an index page side by side with the LAML LENO source file.
(define source-level-index-page? #t)

; A variable which controls whether to make a nice and simple title page.
; This also controls the abstract page.
(define lecture-title-page? #t)

; If #f, do not generate Javascript scripts at all.
(define java-scripting #t)

; Add extra space such that the slide contents is displaced to the right.
; Useful if the browser or projector clips the left part of the screen.
; A number of pixels.
(define slide-page-offset 0)

; A variable which determine how Javascript scripts are loaded.
; The value must be one of the symbols 'static or 'dynamic.
; If static, the javascript is included inline into the generated HTML page.
; if dynamic, the javascript is loaded from the javascript sub-directory of the html directory.
; This variable is only relevant if java-scripting is #t
; Dynamic is recommended!
(define javascript-loading 'dynamic)

; It is possible to advance from one slide to the next via either single or double click.
; The value of this variable determines whether to use single or double click for page advancement.
; Use one of the values single-press or double-press (symbols).
; The value double-press is default and recommended. If you use single page advancement this collides with text selection.
(define mouse-advancement 'double-press)

; A variable which controls whether to copy image icons from the software directory to the html destination directory.
(define copy-image-files? #t)

; A variable which controls whether to copy user made graphics files (normal and small) from the software directory to the html destination directory.
(define copy-note-graphics? #t)

; A variable which controls whether to copy lecturer photos from the software directory to the html destination directory.
(define copy-lecturer-photos? #t)

; ---------------------------------------------------------------------------------------------------------------
; Show and speak control

; A variable that controls the automatic progressing slide show and speak.
; If #t, generate pages for automatic slide show and speak. If #f, do not.
; Redefine or re-assign after the loading of lecture-notes.scm (this file).
(define show-and-speak? #f)

; The default showing time in second for automatic show (and speak).
; Does only apply if show-and-speak is true.
(define default-showing-time 2)

; A number of seconds added to every showing time. Normally 0.
; Useful to make additional, fixed delay of show-and-speak showing times
(define additional-showing-time 0)

; A variable that defines the sound source. One of the symbols real-audio or wave-file.
; Notice that the value of this variable is coupled to speak-url-prefix and speak-file-prefix.
; Defaults to real-audio.
(define sound-source 'real-audio)

; The element-part of the default show-and-speak-clause
; This is the show-and-speak clause supplied on a note page if no explicit show-and-speak clause is given.
(define default-show-and-speak-clause
  (list (list 'slide-part 1 default-showing-time)))

; The prefix of the url to speaker sound
; Must be redefined after the loading of lecture-note.scm, such as in post-notes.scm.
; Notice that the value of this variable is coupled to sound-source and speak-file-prefix.
(define speak-url-prefix "")

; An optional file prefix to the sound files
; If #f, there is no such file prefix.
; Can be redefined after the loading of this file. For instance in post-notes.scm
; Notice that the value of this variable is coupled to sound-source and speak-url-prefix.
(define speak-file-prefix #f)

; Return the full sound file path of sound, of #f it it is not available
(define (sound-file-path sound)
  (if speak-file-prefix
      (string-append speak-file-prefix (as-string sound) ".wav")
      #f))

; Return a speak-url formed by speak-url-prefix, name (the parameter) and the fixed extension .wav
(define (speak-url name)
 (cond ((eq? sound-source 'wave-file) (speak-url-wave name))
       ((eq? sound-source 'real-audio) (speak-url-real-audio name))
       (else (error (string-append "speak-url: Unknown sound-source: " (as-string sound-source))))))

(define (speak-url-wave name)
  (string-append speak-url-prefix name ".wav"))

(define (speak-url-real-audio name)
  (string-append speak-url-prefix name ".rm"))

; An internal variable in which to collec speak entries. 
; Goes to the internal speak file, named by the function speak-file-name.
(define speak-list-in-this-lecture '())

; Return the name of the internal spk file. The parameter defaults to the id of the current lecture.
; Alternatively, the id of another lecture may be passed.
(define (speak-file-name . optional-parameter-list)
 (let ((id (optional-parameter 1 optional-parameter-list (as-string lecture-id))))
   (string-append note-source-directory "internal/" id ".spk")))

; A internal global variable that controls if we are located in a show and speak context.
; From a functional programming point of view, this variable is a bad idea.
; Alternatively, we should have entirely separate functions for generation of 
; show and speak pages. 
(define show-and-speak-context #f)

; ---------------------------------------------------------------------------------------------------------------
; Elucidator linking defaults:

; The name of the elucidator browser window, as passed as target attribute to an anchor element.
; If false (#f) do not apply target.
(define elucidator-default-target #f)

; An enumeration of all LENO image (icon) files. These files are copied from the images directory of the software directory to the 
; images directory of the note source directory, if the copy-image-files? variable is true.
(define leno-image-files
  (list "nav-up.gif" "nav-left.gif" "nav-right.gif" "nav-right-red.gif" "todisk.gif" "index.gif" "question.gif"
        "nav-home.gif" "nav-book.gif" "nav-notes.gif" "nav-slide.gif" "arrow-down.gif" "arrow-up.gif" "exclamation.gif" "exclamation-red-ring.gif" "no-frames.gif"

        "program-icon.gif" "exercise-icon-en.gif" "exercise-icon-dk.gif" "image-series-icon-dk.gif"  "image-series-icon-en.gif"
        "program-icon-small.gif" "exercise-icon-en-small.gif" "exercise-icon-dk-small.gif" "image-series-icon-dk-small.gif"  "image-series-icon-en-small.gif"

        "elucidator-icon.gif" "elucidator-icon-small.gif"

        "nav-contents-frame.gif" "nav-up-frame.gif" 
        "nav-current-frame.gif" "nav-down-frame.gif" "think.gif"

        "blank-pillar.gif"  
        "left-quote.gif" "right-quote.gif"

        "nav-down-empty.gif"  "nav-down-frame-empty.gif"  "nav-left-empty.gif" "nav-left-frame-empty.gif" "nav-right-empty.gif"
        "nav-right-frame-empty.gif" "nav-up-empty.gif"  "nav-up-frame-empty.gif"

        "red-ball-large.gif" "red-ball-small.gif"
        "yellow-ball-large-rised.gif" "yellow-ball-large.gif" "yellow-ball-small.gif"
        "blue-ball-small.gif" "blue-ball-large.gif"
        "cyan-ball-large.gif" "cyan-ball-small.gif"
        "green-ball-large.gif" "green-ball-small.gif"

        "small-speaker.gif" "small-speaker-empty.gif" 

        "atomspin.gif" "atomspin-freeze.gif"

        "speaker.gif" "speaker-empty.gif" "no-speaker.gif" "pause.gif" ; not used yet

        "logo.gif"
  )
)

; Return the program icon name, given language (danish or english) and size (large or small)
(define (program-icon-name language size)
  (cond ((eq? size 'large) "program-icon.gif")
        ((eq? size 'small) "program-icon-small.gif")
        (else (error "program-icon-name. Unknown size"))))

; Return the exercise icon name, given language (danish or english) and size (large or small)
(define (exercise-icon-name language size)   
  (cond ((and (eq? size 'large) (eq? language 'danish)) "exercise-icon-dk.gif")
        ((and (eq? size 'small) (eq? language 'danish)) "exercise-icon-dk-small.gif")
        ((and (eq? size 'large) (eq? language 'english)) "exercise-icon-en.gif")
        ((and (eq? size 'small) (eq? language 'english)) "exercise-icon-en-small.gif")
        (else (error "exercise-icon-name. Unknown language or size"))))

; Return the image-series icon name, given language (danish or english) and size (large or small)
(define (image-series-icon-name language size)  
  (cond ((and (eq? size 'large) (eq? language 'danish)) "image-series-icon-dk.gif")
        ((and (eq? size 'small) (eq? language 'danish)) "image-series-icon-dk-small.gif")
        ((and (eq? size 'large) (eq? language 'english)) "image-series-icon-en.gif")
        ((and (eq? size 'small) (eq? language 'english)) "image-series-icon-en-small.gif")
        (else (error "image-series-icon-name. Unknown language or size"))))

(define (elucidator-icon-name language size)   
  (cond ((and (eq? size 'large) (eq? language 'danish)) "elucidator-icon.gif")
        ((and (eq? size 'small) (eq? language 'danish)) "elucidator-icon-small.gif")
        ((and (eq? size 'large) (eq? language 'english)) "elucidator-icon.gif")
        ((and (eq? size 'small) (eq? language 'english)) "elucidator-icon-small.gif")
        (else (error "elucidator-icon-name. Unknown language or size"))))


(define image-file-access #f)


; The preferred maximum length of file names, including extension, excluding initial path.
; This size may be important for CD file systems.
; A warning is issed if the preferred maxiumum length is exceeded.
(define preferred-maximum-filename-length 64)

; The directory in which the LENO Scheme software resides.
(define leno-software-directory (string-append software-directory "styles/lecture-notes/"))

(define (leno-software-dir-file . x) (string-append leno-software-directory (list-to-string x "")))

; The directory in which the note source is located defined by the variable note-source-directory. Must be redefined in notes.scm

(define front-index? #t)  ; make front index (top level)
(define (include-front-index) (set! front-index? #t))
(define (exclude-front-index) (set! front-index? #f))

(define word-index? #t)   ; make word index - only affects the generation and the presentation of the word index, 
                          ; not the adding of word to internal idx files.
(define split-word-index-alphabetically? #t)  ; make a separate index for each letter in the alphabet
(define (include-word-index) (set! word-index? #t))
(define (exclude-word-index) (set! word-index? #f))


(define cross-references? #f) ; generate a separate page of lecture note wide cross references

(define course-dir #f) ; #f if no relevant course dir exists. The course dir is the directory of the course-plan directory,
                       ; from which we can extract information about the course in which these notes are used.
                       ; redefined in post-notes.scm if necessary.

(define note-specific-image-files '()) ; the list of note specific image files which are copied from the note
                                       ; source file directory to the html/images directory.
                                       ; If you have such images in your notes, redefine this variable in post-notes.scm.
                                       ; One of these file can be logo.gif, which is used bu the logo-img function to present
                                       ; a university logo on some pages.

(define note-specific-graphics-files '()) ; A list in which to accumulate the user made graphics file names (name and extension only).

; The URL which is linked to from the logo.
; If it is the empty string, do not link.
(define logo-url "") 


; Relative address of the directory with lecture photos. Relative to the destination html directory.
; Can also be an absolute URL.
; Can be redefined or assigned after lecture-notes.scm (this file) is loaded. Can be done in post-notes.scm.
; The default, however, is in lecturer-photos in the destination html directory.
; If copy-lecturer-photos? is #t then do never than the default.
(define lecturer-photo-url-prefix "lecturer-photos/")

; The width of a table cell for lecturer photos
(define lecturer-photo-width 200)

; The list of photo names, such as ("normark1.jpg" "normark2.jpg") of photos found at the address lecturer-photo-url-prefix.
; Must be redefined or assigned after lecture-notes.scm (this file) is loaded. Can be done in post-notes.scm.
(define lecturer-photo-list '())



; -----------------------------------------------------------------------------------------------------------------------------------------------------------
; ANNOTATIONS
; Annotations of LENO material is supported by an external CGI based tool called Annotator.
; Contains a few redundant defintions from the annotator stuff. Consider loading annotator lib if more is needed.

; Notice that the use of the Annotator assumes that the function course-absolute-url is defined

(define annotator-support? #f) ; Generate links to the annotator - an external tool to LENO.
                              ; Change the value of this variable after this file is loaded - for instance in post-notes.scm

; A symbol that designates the top level annotation name (becomes directory name in the annotator data dir).
; Must be redefined in post-notes.scm if annotator-support is #t.
(define annotator-symbol #f)

; The URL prefix of the annoator. Change this according to you local installation.
; Only used if annotator-support? is #t.
(define annotator-url-prefix "http://www.cs.auc.dk/~normark/cgi-bin/annotator/")

; The absolute path to the Annotator CGI directory.
; Only used if annotator-support? is #t.
(define annotator-cgi-directory "/user/normark/.public_html/cgi-bin/annotator/")

(define (annotator-url annotator-cgi-program key-list val-list)
  (string-append annotator-url-prefix annotator-cgi-program "?" (make-url-parameters key-list val-list)))

; Return a full path to an annotator cgi-bin directory file
(define (annotator-cgi-file final-path)  
  (string-append annotator-cgi-directory final-path))

(define annotator-id-separator-char #\$)

; Encode id-list to a dollar (or whatever) separated string suitable for URL parameter passing purposes
(define (encode-annotation-ids id-list)
  (list-to-string id-list (as-string annotator-id-separator-char)))

; Return the list of existing annotations (a-list format) of the given category
; Corresponds roughly to the function annotation-catalogue-list in annotator-lib.scm (modulo the filtering with non-categorial).
(define (list-of-submitted-annotations . decoded-id-list)
  (let ((all-data-path (annotator-cgi-file (string-append "data/" (list-to-string decoded-id-list "/") "/" "all.dat"))))
   (letrec ((non-categorial string?))
    (if (file-exists? all-data-path)
        (filter non-categorial (file-read all-data-path))
        '()))))


; -----------------------------------------------------------------------------------------------------------------------------------------------------------
; EXERCISES:

; Notice that the use of the Exercise Manager assumes that the function course-absolute-url is defined

(define exercise-index? #t)   ; generate a separate exercise index pr. lecture, an overall exercise index, and appropriate linking to these

(define exercise-manager-support? #f) ; generate framed exercises with support of the exercise-manager - synchronous (an external tool to LENO).
                                      ; only one of exercise-manager-support? and distance-education-support? are allowed to be true

(define distance-education-support? #f) ; generate framed exercises with support of the distance education tool  - asynchronous (an external tool to LENO).
                                        ; Meant for IDAFUS connection.
                                        ; In case of distance-education-support? a number of other variables are assumed to be defined.

(define exercise-manager-url-prefix "http://www.cs.auc.dk/~normark/cgi-bin/exercise-manager-1/")

(define (exercise-manager-url cgi-program key-list val-list)
  (string-append exercise-manager-url-prefix cgi-program "?" (make-url-parameters key-list val-list)))


(define reveal-exercise-solutions? #f)  ; should the solutions be revealed from these lecture notes.
                                        ; set it in individual note laml files.
                                        ; does not ALONE affect the overall exercise index. See reveal-all-solutions?

(define reveal-all-solutions? #f) ; Controls whether solutions are shown in overall exercise index.
                                  ; Should and must be #f during the semester.
                                  ; reveal-exercise-solutions? does not provide enough control, because we do never want to hide
                                  ; already revealed solutions.

(define lecture-exercise-list '())  ; The list of exercises in a lecture
                                    ; Entries of the form (exercise-id title page-id exercise-number-on-page body exercise-number-in-lecture solution-symbol).


; -------------------------------------------------------------------------------------------------
; IDAFUS Integration variables
; Does only apply if distance-education-support? is #t

; The absolute path to the IDAFUS instance in cgi-bin:
(define idafus-absolute-cgi-path #f)

; The id of the IDAFUS unit to which the exercises belong
(define idafus-unit-id #f)


; The start date of the activities. Format ddmmyyyy
(define idafus-start-date #f)

; The end date of the activities. Format ddmmyyyy
(define idafus-end-date #f)

; A teacher user name - only a single name is supported
(define idafus-teacher #f)


; -------------------------------------------------------------------------------------------------

(define lecture-list-from-course-plan '())  ; We attempt to read the internal course plan file in begin-notes.

; Return whether (note) exercises are shown in a frame.
; It requires a different form of navigation out from such a frame.
(define (frame-exercises?)
  exercise-manager-support?) 

; An a list of lecture-id solution-password pairs.
; Defined in post-notes.scm
; If it is the empty list, no solution password constituents are added to solution file names.
(define solution-passwords '())

; Remembers the actaually used exercise model. Assigned by the procedure exercise-model.
(define used-exercise-model #f)

; Define the overall exercise model for these notes.
; The procedures sets the variables above.
; Kind is one of the symbols:
; none: No exercises at all in these notes.
; make-indexes: Make exercise indexes in these notes.
; make-indexes-and-solutions-per-lecture: Make exercise indexes and lecture-specific solution indexes.
; make-indexes-and-solutions-lecture-wide: Make exercise indexes, lecture-specific solution indexes, and a global solution index.
; synchronous-exercises: Make exercise indexes, solution indexes at a/after a certain point in time, plus framed exercises with room for the exercise manager.
; asynchronous-exercises: Make exercise indexes, NO solution indexes all, plus framed exercises with room for the asynchronous distance education tool.
(define (exercise-model kind)
  (set! used-exercise-model kind)
  (cond ((eq? kind 'none)
             (begin (set! exercise-index? #f) 
                    (set! exercise-manager-support? #f)
                    (set! distance-education-support? #f)
                    (set! reveal-exercise-solutions? #f)
                    (set! reveal-all-solutions? #f)
             ))
       ((eq? kind 'make-indexes)
             (begin (set! exercise-index? #t) 
                    (set! exercise-manager-support? #f)
                    (set! distance-education-support? #f)
                    (set! reveal-exercise-solutions? #f)
                    (set! reveal-all-solutions? #f)
             ))
       ((eq? kind 'make-indexes-and-solutions-per-lecture)
             (begin (set! exercise-index? #t) 
                    (set! exercise-manager-support? #f)
                    (set! distance-education-support? #f)
                    (set! reveal-exercise-solutions? #t)
                    (set! reveal-all-solutions? #f)
             ))
       ((eq? kind 'make-indexes-and-solutions-lecture-wide)
             (begin (set! exercise-index? #t) 
                    (set! exercise-manager-support? #f)
                    (set! distance-education-support? #f)
                    (set! reveal-exercise-solutions? #t)
                    (set! reveal-all-solutions? #t)
             ))
       ((eq? kind 'synchronous-exercises)
             (begin (set! exercise-index? #t) 
                    (set! exercise-manager-support? #t)
                    (set! distance-education-support? #f)
                    (set! reveal-exercise-solutions? #f)   ; reveal at a certain point in time - controlled by other means
                                                           ; see the function do-reveal-exercise-solutions?
                    (set! reveal-all-solutions? #f)
             ))
       ((eq? kind 'asynchronous-exercises)
             (begin (set! exercise-index? #t) 
                    (set! exercise-manager-support? #f)
                    (set! distance-education-support? #t)
                    (set! reveal-exercise-solutions? #f)
                    (set! reveal-all-solutions? #f)
             ))
       (else (error "Exercise model: Unknow exercise model"))))


; a more elaborate decission function than the variable reveal-exercise-solutions? determining if the solutions
; should be revealed in these notes
; in case exercise-manager-support? is #t this function depends on lecture-exercise-reveal-time from notes.scm
(define (do-reveal-exercise-solutions?)
  (cond (exercise-manager-support? (and reveal-exercise-solutions? (> (current-time) (lecture-exercise-reveal-time lecture-id))))
        (else reveal-exercise-solutions?)))

; -----------------------------------------------------------------------------------------------------------------------------------------------------------
; QUIZ SUPPORT

(define quiz-support? #t)

(define quiz-url-prefix "http://www.cs.auc.dk/~normark/cgi-bin/quiz/")
(define quiz-software-dir (string-append laml-dir "tools/quiz/"))
(define quiz-cgi-directory "/user/normark/.public_html/cgi-bin/quiz/")

; The list of questions/answers in this lecture
(define quiz-list '())

; Make and return a LENO quiz entry as stored in the -.quiz file
; This is not the same as a quiz entry as supported by the quiz tool.
(define (make-leno-quiz-entry question answer-list absolute-note-url)
  (list question answer-list absolute-note-url))

; Selectors for internal LENO quiz entries:
(define leno-quiz-question (make-selector-function 1 "leno-quiz-question"))
(define leno-quiz-answer-list (make-selector-function 2 "leno-quiz-answer-list"))
(define leno-quiz-background-url (make-selector-function 3 "leno-quiz-background-url"))


; Return the name of the quiz file. The parameter defaults to the id of the current lecture.
; Alternatively, the id of another lecture may be passed.
(define (quiz-file-name . optional-parameter-list)
 (let ((id (optional-parameter 1 optional-parameter-list (as-string lecture-id))))
   (string-append note-source-directory "internal/" id ".quiz")))

; Return the external (quiz tool defined) format of leno-quiz-entry (as found on the -.quiz file).
; The second parameter n is the number of the question
(define (internal-quiz-format leno-quiz-entry n)
  (let* ((question (car (element-contents (leno-quiz-question leno-quiz-entry)))) ; the element-contents is always a list
         (question-id (string-append lecture-id "-" (as-string n)))
         (answers  (element-contents (leno-quiz-answer-list leno-quiz-entry)))
         (internal-answers (map internal-quiz-answer-format answers))
         (back-url (leno-quiz-background-url leno-quiz-entry))
        )
    (make-quiz-entry (as-symbol question-id) question back-url internal-answers)))

(define (internal-quiz-answer-format leno-answer-entry)
  (let* ((answer-contents (element-contents leno-answer-entry))
         (answ (first answer-contents))
         (corr (second answer-contents))
         (clar (third answer-contents)))
    (make-answer-entry answ (as-number corr) clar)))


; -----------------------------------------------------------------------------------------------------------------------------------------------------------

(define include-source-file-listing? #t)  ; add a list of source files to book view. Normally #f
                                          ; only of interest to the author of these notes

(define help-and-about-page? #t)  ; generate a fixed LENO help and about page

(define laml-source-file-name-without-extension (source-filename-without-extension))

(define lecture-id laml-source-file-name-without-extension)
(define lecture-title "") ; assigned later
(define lecture-author-info "") ; assigned later
(define lecture-abstract "") ; assigned in lecture-intro
(define lecture-date "") ; assigned in lecture-intro

(define lecture-list (map car lecture-sections))
(define lecture-titles (map cadr lecture-sections))

(define target-extension "html")
(define file-name-of-word-index "note-index") ; i.e., place word index on a file note-index. Becomes html/note-index.html
(define top-level-note-file-name "index")     ; i.e., place top level file at index. Becomes html/index.html
(define overall-exercise-index-name "exercise-index")  ; the name of the overall exercise index.

(define list-of-source-files '())   ;  a list of all source files process by source-program in this lecture
(define cross-refs-in-this-lecture '())   ; in this list we collect all cross references in this lecture
(define lsp-contents-in-this-lecture '())  ; in this list we collect the full contents of the notes as Lisp data structure 

; user level function
; add a cross reference entry to this lecture's list of cross references
; ref is of the for (internet-reference ...) (note-reference ...) or (informal-reference ...)

(define (add-lecture-reference ref)
  (set! cross-refs-in-this-lecture (cons ref cross-refs-in-this-lecture)))

; general.scm is loaded by laml.scm
(lib-load "cgi.scm")
(lib-load "encode-decode.scm")

(if (and laml-load-variation (eq? laml-load-variation 'no-html-mirror))
    (begin #f) ; load no html mirror stuff
    (begin
      (lib-load "html4.0-loose/basis.scm")
      (lib-load "html4.0-loose/surface.scm")
      (lib-load "html4.0-loose/convenience.scm")))


(lib-load "color.scm")
(lib-load "time.scm")
(lib-load "file-read.scm")

(if quiz-support?
    (load (string-append quiz-software-dir "quiz-lib.scm")))

; Now assigning image-file-access. Images (icons) are located in a subdirectory of the html directory
(set-image-file-path! 'sub-directory)

; Given the leno language (a symbol, either 'danish og 'english, return the language string used in a meta lang attribute
(define (meta-language leno-language)
  (cond ((eq? leno-language 'danish) "da")   ; see: http://www.indigo.ie/egt/standards/iso639/iso639-1-en.html
        ((eq? leno-language 'engslin) "en-us")
        (else "dk")))

(define (copyright-clause)
  (html-comment "The material in this file is copyrighted (c) by Kurt Nrmark, Aalborg University, Denmark. Email: normark@cs.auc.dk. All rights reserved."))


(define (set-lecture-name name-without-extension)
  ; Force the name of html files generated from this source to have 
  ; a certain lecture name. Especially useful under drscheme, but
  ; also works in other scheme systems. Must be placed before
  ; begin-notes.
  (set! lecture-id name-without-extension))

(define (set-lecture-number n)
  (set! lecture-number n))

; ----------------------------------------------------------
; Selectors to the lecture-sections list:

; Return the title of section n from lecture-sections
(define (lecture-title-of lecture-sections n)
 (second (list-ref lecture-sections (- n 1))))

; Return the id of section n from lecture-sections. The returned id is a string.
(define (lecture-id-of lecture-sections n)
 (as-string (first (list-ref lecture-sections (- n 1)))))

; Return the number of the lecture with id, based on the sequence of
; lectures in lecture-sections. The first lecture counts as number one.
; Returns #f if the lecture cannot be located in lecture-sections.
; This is a more advance selecture, due to the need of searching/counting for the number.
(define (lecture-number-of lecture-sections lecture-id)
 (let ((res (lecture-number-of-1 lecture-sections lecture-id 1)))
   (if res
       res
       (laml-error "lecture-number-of:" "Unknown lecture-id" lecture-id))))

(define (lecture-number-of-1 lecture-sections lecture-id i)
 (cond ((null? lecture-sections) #f)
       ((equal? (as-string (car (first lecture-sections))) (as-string lecture-id)) i)
       (else (lecture-number-of-1 (cdr lecture-sections) lecture-id (+ i 1)))))
  

; ----------------------------------------------------------


; obsolete:
(define (set-previous-lecture name-without-extension)
  ; set the previous lecture, such that linking at lecture level becomes possible
  (error "set-previous-lecture is obsolete. Now calculated automatic from current-lecture and lecture-number")
  (if (and (string? name-without-extension) 
           (> (string-length name-without-extension) 0))
    (set! previous-lecture name-without-extension)))

; obsolete:
(define (set-next-lecture name-without-extension)
  ; set the next lecture, such that linking at lecture level becomes possible
  (error "set-next-lecture is obsolete. Now calculated automatic from current-lecture and lecture-number")
  (if (and (string? name-without-extension) 
           (> (string-length name-without-extension) 0))
    (set! next-lecture name-without-extension)))

(define (set-previous-lecture name-without-extension)
  (display-warning "The call of set-previous-lecture is ignored"))

(define (set-next-lecture name-without-extension)
  (display-warning "The call of set-next-lecture is ignored"))

; calculation of previous lecture from lecture counts
(define (calculate-previous-lecture! this-lecture last-lecture)
 (if (> last-lecture 1)
  (if (> this-lecture 1) 
      (set! previous-lecture (list-ref lecture-list (- this-lecture 2)))  ; adjusting because list-ref counts from 0
      (set! previous-lecture #f))
  (set! previous-lecture #f))
)

; calculation of next lecture from lecture counts
(define (calculate-next-lecture! this-lecture last-lecture)
 (if (> last-lecture 1)
  (if (< this-lecture last-lecture) 
      (set! next-lecture (list-ref lecture-list this-lecture))            ; adjusting because list-ref counts from 0
      (set! next-lecture #f))
  (set! next-lecture #f))
)
  

; arrange that slide headers are generated as frames.
; default: simple and plain slide headers
; this facility is still problematic
(define (generate-frame-slide-headers)
  (set! slide-header-as-frame? #t))


; ----------------------------------------------------------------------
; name and file related functions:

; Name of programs, excercises, and image series
; Presentation-kind is a symbol or string: slide, note, book
; Kind is a symbol or string: program, images, exercise.  Image is used for image series.
; Number is a non-zero integer: The number of element on slide.
; The optional subnumber is used to number sub element, such as individual images in an image series
; Programs, exercises, and image series are numbered pr. page, and individually pr. kind.
(define (page-element-name lecture-id page-id presentation-kind kind number . sub-number)
  (let ((sn (if (not (null? sub-number)) (car sub-number) #f)))
   (if (page-element-ok? presentation-kind kind)
       (string-append (as-string lecture-id) "-" (as-string page-id) "-"
                      (as-string presentation-kind) "-" (as-string kind) "-" (as-string number)
                      (if sn "-" "") (if sn (as-string sn) ""))
       (error (string-append "page-element-name: Parameter problems: " (as-string presentation-kind) " " (as-string kind))))))

(define (page-element-ok? pk k)
  (let ((pk1 (as-string pk))
        (k1  (as-string k)))
   (and 
     (or (equal? pk1 "slide") (equal? pk1 "note") (equal? pk1 "book") (equal? pk1 "show"))
     (or (equal? k1 "program") (equal? k1 "images") (equal? k1 "exercise") (equal? k1 "exercise-frame")))))

(define (slide-name-0 lecture-name slide-name)
  (string-append (as-string lecture-name) "-" "slide" "-" (as-string slide-name)))

(define (slide-name lecture-name slide-name)
  (if slide-header-as-frame?
     (filename-of-main-frame lecture-name slide-name)  
     (slide-name-0 lecture-name slide-name)))

(define (show-and-speak-slide-name lecture-name slide-name number)
  (string-append (as-string lecture-name) "-" "show" "-" (as-string slide-name) "-" (as-string number)))

; Naming of sound files in the speak directory
; Kind is either slide-part, program-part, exercise-part, or image-series-part (a symbol).
; Number is the part number from the show-and-speak clause.
; There may be one optional parameter: a subnumber in case kind is image-series-part
(define (speak-name lecture-id page-id kind number . optional-parameter-list)
 (let ((sub-number (optional-parameter 1 optional-parameter-list #f)))
  (string-append (as-string lecture-id) "-" (as-string page-id) "-" (as-string kind) 
                 "-" (as-string number)
                 (if sub-number
                     (string-append "-" (as-string sub-number))
                     ""))))

(define (note-name lecture-name slide-name)
  (string-append (as-string lecture-name) "-" "note"  "-" (as-string slide-name)))

(define (book-name lecture-name)
  (string-append (as-string lecture-name) "-" "book"))

(define (index-name lecture-name)
  (as-string lecture-name))

; Return a program name given lecture-id, page-id, presentation-kind (slide, note, book, show)
; and the program number on this page
(define (program-name lecture-id page-id presentation-kind number)
  (page-element-name lecture-id page-id presentation-kind 'program number))

(define (image-name lecture-name page-id presentation-kind number sub-number)
  (page-element-name lecture-id page-id presentation-kind 'images number sub-number))

(define (exercise-name lecture-id page-id presentation-kind number)
  (page-element-name lecture-id page-id presentation-kind 'exercise number))

; We don't want the students to guess the solution file names.
; Therefore we add a password-like constituent pr. lecture-id
(define (exercise-solution-name lecture-id page-id number)
 (let ((solution-password (defaulted-get (as-symbol lecture-id) solution-passwords "")))
  (string-append (as-string lecture-id) solution-password "-" (as-string page-id) "-" "solution" "-" (as-string number))))

; A variant of exercise-solution-name which returns a 'secret' file name. Only revealed to teaching assistants.
(define (exercise-secret-solution-name lecture-id page-id number)
  (string-append (as-string lecture-id) "-" (as-string page-id) "-" "aau25" "-" (as-string number)))

; The name of the frame file, which contains the exericise and the exercise manager
(define (exercise-frame-name lecture-id page-id presentation-kind number)
  (page-element-name lecture-id page-id 'note 'exercise-frame number))

(define (end-show-and-speak-page-name lecture-id)
  (string-append (as-string lecture-id) "-" "end-show-speak"))

(define (internal-show-and-speak-page-name lecture-id)
  (string-append (as-string lecture-id) "-" "internal-show-speak"))


(define (word-index-name lecture-name)
  (string-append (as-string lecture-name) "-" "index"))

(define (exercise-index-name lecture-name)
  (string-append (as-string lecture-name) "-" "exercise-index"))

(define (all-exercises-name lecture-name)
  (string-append (as-string lecture-name) "-" "all-exercises"))

(define (all-exercises-and-solutions-name lecture-name)
 (let ((solution-password (defaulted-get (as-symbol lecture-name) solution-passwords "")))
  (string-append (as-string lecture-name) solution-password "-" "all-exercises-solutions")))

; We could add a lecture-specific 'cryptic' string to this name:
(define (secret-all-exercises-and-solutions-name lecture-name)
  (string-append (as-string lecture-name) "-" "exercises-internal"))

; the name of the top navigation bar
(define (filename-of-top-navigation lecture-name slide-name)
  (string-append (as-string lecture-name) "-" "TOPBAR" "-" "slide" "-" (as-string slide-name)))

; the name of the frame which contains the main slide contents and the top navigation bar
(define (filename-of-main-frame lecture-name slide-name)
  (string-append (as-string lecture-name) "-" "FRAME" "-" "slide" "-" (as-string slide-name)))

; the name of the exercise manager control pane - teacher only 
(define (em-control-name lecture-name)
  (string-append (as-string lecture-name) "-" "em"))

; the name of lecture-name's title page
(define (title-page-name lecture-name)
  (string-append (as-string lecture-name) "-" "title-page"))

; the name of lecture-name's abstract page
(define (abstract-page-name lecture-name)
  (string-append (as-string lecture-name) "-" "abstract-page"))

; the name of the default trail, parallel with a normal lecture, which can be generated automatically,
; depending on the variable trail-of-lecture?
(define (default-trail-name lecture-id)
  lecture-id "-" "trail")

; The fragment of a file path which distinguishes the note-source-directory and the HTML destination directory.
; As default, the html files are placed in a subdirectory of the source directory named 'html'.
; You can redefine this function after the leno software is loaded in order to provide for another html destination.
(define (relative-source-html-destination-path-fragment)
  "html/")

;; Copy the file in source-file-path (path relative to the note-source-directory) to a file in the destination-path in the
;; html destination directory (as determined by the function relative-source-html-destination-path-fragment).
;; The destination path is an optional second parameter, defaulted to the empty string.
;; The directories in destination-path is created if they do not exist.
;; The target file name is the same name as the source file, unless a optional third parameter explicitly
;; names the target file (name.extension).
;; .form (copy-source-to-destination source-file-path [destination-path destination-file-name])
(define (copy-source-to-destination source-file-path . optional-parameter-list)
  (let* ((real-destination-path (optional-parameter 1 optional-parameter-list ""))
         (target-file-name-par (optional-parameter 2 optional-parameter-list #f))
         (target-file-name (if target-file-name-par 
                               target-file-name-par  
                               (string-append (file-name-proper source-file-path) "." (file-name-extension source-file-path))))
        )
   (if (not (empty-string? real-destination-path))
       (ensure-directory-path-existence! (relative-source-html-destination-path-fragment) real-destination-path))
   (let ((source (string-append note-source-directory source-file-path))
         (target (string-append (relative-source-html-destination-path-fragment) real-destination-path target-file-name)))
     (if (file-exists? target) (delete-file target))
     (copy-file source target))))



; This function determines the placement of the generated html files relative to note-source-directory.
(define (destination-path name)
 (let* ((name-string (as-string name))
        (lgt (+ (string-length name-string) (string-length target-extension) 1)))
  (if (> lgt preferred-maximum-filename-length)
      (display-warning (string-append "The filename " name-string " is longer than the preferred maximum ("
                                      (as-string preferred-maximum-filename-length) " chars). Actual length: " (as-string lgt))))
  (string-append note-source-directory  (relative-source-html-destination-path-fragment) name-string "." target-extension)))

(define (source-path name)
 (let* ((name-string (as-string name)))
  (string-append note-source-directory  name-string "." target-extension)))

(define (html-file name)
  (string-append name "." "html"))

; relative final path to an external file from the html directory
(define (external-html-file final-path)
  (string-append "external-html/" final-path))

(define relative-applet-path "./applets/")

; -----------------------------------------------------------------------------
; Locally addapted html version 1 functions.
; Must be named ...-LN


(define (img-LN file-name help-text . optional-parameter-list)
 (let ((width (optional-parameter 1 optional-parameter-list #f)))
  (if width
   (html4:img 'src (image-file file-name) 'alt help-text 'border 0 'width width)
   (html4:img 'src (image-file file-name) 'alt help-text 'border 0))))

(define (no-frames-button self-url)
  (a-tag-target self-url (img-LN "no-frames.gif" (text-choice "Bryd ud af mulig frame system" "Exit possible frame set")) "_top"))  ; only allowed _top



; -----------------------------------------------------------------------------

; url functions. All urls in current directory:

(define (front-index-url)
  "index.html")

(define (slide-url lecture-id slide-id)
  (string-append (slide-name lecture-id slide-id) ".html"))

(define (slide-show-and-speak-url lecture-id slide-id number)
  (string-append (show-and-speak-slide-name lecture-id slide-id number) ".html"))

(define (note-url lecture-id slide-id)
  (string-append (note-name lecture-id slide-id) ".html"))

(define (book-url lecture-id . slide-id1)
  (let ((slide-id (if (null? slide-id1) #f (car slide-id1))))
    (if slide-id
        (string-append (book-name lecture-id)  ".html" "#" (as-string slide-id))
        (string-append (book-name lecture-id)  ".html"))))

(define (contents-url lecture-id)
  (string-append (as-string lecture-id)  ".html"))

(define (word-index-url lecture-id)
  (string-append (word-index-name lecture-id) ".html"))

(define (all-word-index-url lecture-id)
  ; a fixed file produced via note-index.laml
  (string-append "note-index.html"))

; Return an URL of an exercise formulation identified by lecture-id, page-id, and exercise-number.
; Presentation-kind is either the symbol 'slide or 'note.
(define (exercise-formulation-url lecture-id page-id presentation-kind exercise-number)
  (html-file (exercise-name lecture-id page-id presentation-kind exercise-number)))

; Return an URL of an exercise formulation identified by lecture-id and the exercise-id.
; This function finds the page and the exercise-number on the page via the internally generated -.exc files.
; Thus, this function assumes that the -.exc file of lecture-id exists. If not, this function
; returns "???" and issues a warning.
; presentation-kind is an optional parameter which defaults to the symbol 'note. Other possible value 'slide.
; Does never address an exercise manager frameset, but always the exercise formulation.
(define (exercise-formulation-url-given-id lecture-id exercise-id . presentation-kind)
 (let* ((presentation-kind-1 (if (not (null? presentation-kind)) (car presentation-kind) 'note))
        (exc-file-name (exercise-idx-file-name lecture-id))
        (lecture-exc-info (if (file-exists? exc-file-name)
                              (file-read exc-file-name)
                              '()))
        (exc-info (find-in-list 
                     (lambda (e) (eq? (third (car e)) exercise-id))
                     lecture-exc-info)))
  (if exc-info
      (let ((ids (first exc-info))
            (title (second exc-info))
            (p-numbers (third exc-info))
            (solution-status (fourth exc-info))
           )
        (let* ((lec-id (first ids))
               (page-id (second ids))
               (sl-number (fourth ids))
               (main-number (car p-numbers))
               (sub-number (cadr p-numbers)))
         (html-file ((if exercise-manager-support? exercise-name exercise-name) lec-id page-id presentation-kind-1 sl-number))))
      (begin
         (display-warning (string-append "Cannot find exercise " (as-string exercise-id) " in lecture " (as-string lecture-id) ". "
                                         "Using dummy URL"))
         "???"))))


(define (exercise-solution-url lecture-id page-id exercise-number)
  (html-file (exercise-solution-name lecture-id page-id exercise-number)))

(define (local-html-url file-name)
  ; html url in current directory
  (string-append file-name ".html"))



(define about-laml-url "leno-help-and-about.html")  ; generated from this source file





; Interface function, used directly i LAML source file:
; OBSOLETE

; (define (inline-from-file file-name . mark)
;   ; Read the contens of file-name, such as a program, and return the text read.
;   ; If a second mark parameter is given, just read between (and excluding) the marks.
;   (if (null? mark)
;       (read-text-file file-name)
;       (read-text-file-between-marks file-name mark)))
; 
; (define (external-from-file file-name id title . mark)
;   ; Read the contents of file-name, such as a program. Write it to a html file
;   ; (derived from unique id parameter, a symbol).
;   ; Title names the program (string).
;   ; and return a link (a-tag) to it.
;   ; If a second mark parameter is given, just read between (and excluding) the marks.
;  (let ((progr-text 
;             (if (null? mark)
;                 (read-text-file file-name)
;                 (read-text-file-between-marks file-name mark)))
;        (name-of-program-file (program-name lecture-id id))
;      )
;    (write-text-file
;      (program-slide
;         (con "Program " title)
;         (program-text (pre progr-text)))
;      (destination-path name-of-program-file))
;   
;    (a-tag (string-append name-of-program-file ".html") title) ))

; -----------------------------------------------------------------------------

; Constants

(define yellow-1 (make-color 255 255 160))
(define purple-1 (make-color 204 126 250)) 
(define purple-2 (make-color 183 73 248))

(define slide-font-size 5)
(define slide-background-color white)
(define tabular-slide-color (make-color 228 160 143))
(define tabular-note-color tabular-slide-color)
(define tabular-book-color white)
(define title-color blue)

(define note-font-size-left 3)  ; font size in left part
(define note-font-size-right 2) ; font size in right part
(define note-background-color white)
(define note-foreground-color blue)

(define book-header-foreground-color black)
(define book-title-foreground-color blue)
(define book-foreground-color black)
(define book-background-color white)
(define book-font-size 3)

(define syntax-frame-color (make-color 243 226 50))  ;  before: (245 232 135) (248 245 165)
(define synopsis-frame-color green1)


; -----------------------------------------------------------------------------
; Variables to be assigned once or more

(define lecture-number #f)  ; default: do not show lecture number 
(define previous-lecture #f)  ; default: do not show previous lecture
(define next-lecture #f)  ; default: do not show next lecture
(define word-index '())  ; a list of index-elements. An element is of the form (word url)

; ----------------------------------------------------------------------
; Word indexing:

(define (add-words-to-index words book-url slide-url kind)
 ; make all the words in words (a list of strings) refer to url
 ; kind is a symbol, such as 'index, 'title, 'concept, etc
 (let ((reference-list 
         (map (lambda (word) (list word book-url slide-url kind)) words)))
   (set! word-index (append word-index reference-list))))

; Return the full path of an idx file for id.
; Id defaults to the value of the global varible lecture-id
(define (word-index-file-name . id)
 (let ((id-1 (if (null? id) (as-string lecture-id) (as-string (first id)))))
   (string-append note-source-directory "internal/" id-1 ".idx")))

; ----------------------------------------------------------------------

; We collect cross references in a file per lecture
; in order to ease spotting of wrong references

; Return the full path of an crs file for id.
; Id defaults to the value of the global varible lecture-id
(define (cross-ref-file-name . id)
 (let ((id-1 (if (null? id) (as-string lecture-id) (as-string (first id)))))
   (string-append note-source-directory "internal/" id-1 ".crs")))

; ----------------------------------------------------------------------


(define book-port 'nil)

; set global variables lecture-title, lecture-author-info, lecture-abstract, and lecture-date to the information in the parameters.
(define (lecture-intro title author-list . abstract)
 (let ((abstract-1 (if (null? abstract) "" (car abstract))))
  (set! lecture-title title)
  (set! lecture-author-info author-list)
  (set! lecture-abstract abstract-1)
))

(define (lecture-intro title author-list . optional-parameter-list)
 (let ((abstract (optional-parameter 1 optional-parameter-list ""))
       (date (optional-parameter 2 optional-parameter-list ""))
      )
  (set! lecture-title title)
  (set! lecture-author-info author-list)
  (set! lecture-abstract abstract)
  (set! lecture-date date)
))

(define (leno-welcome)
 (display-message 
  (string-append 
    "Welcome to LENO (version "
    leno-version
    ") and the LAML software, featuring the exact HTML4.0 loose mirror." )))



(define (begin-notes)
 (leno-welcome)

 (ensure-directory-existence! note-source-directory "internal")

 ; only make html directory in the simple case where it resides as a subdirectory in the note-source-directory
 (if (equal? "html/" (relative-source-html-destination-path-fragment))
     (ensure-directory-existence! note-source-directory "html"))

 (ensure-directory-existence! (string-append note-source-directory (relative-source-html-destination-path-fragment)) "images")
 (ensure-directory-existence! (string-append note-source-directory (relative-source-html-destination-path-fragment)) "javascript")
 (ensure-directory-existence! (string-append note-source-directory (relative-source-html-destination-path-fragment)) "graphics")
 (ensure-directory-existence! (string-append note-source-directory (relative-source-html-destination-path-fragment) "graphics/") "small")
 (ensure-directory-existence! (string-append note-source-directory (relative-source-html-destination-path-fragment)) "lecturer-photos")


 (if help-and-about-page? (make-leno-help-page))

 (let ((book-file (destination-path (book-name lecture-id))))

  (if (equal? lecture-title "") (display-warning "Remember that (begin-notes) must come after (lecture-intro ...)"))
  (if (and lecture-number (number? lecture-number))  ; a the lecture number has been set
      (calculate-previous-lecture! lecture-number current-lecture))
  (if (and lecture-number (number? lecture-number))  ; a the lecture number has been set
      (calculate-next-lecture! lecture-number current-lecture))

  (if (file-exists? book-file) (delete-file book-file))
  (set! book-port (open-output-file (destination-path (book-name lecture-id))))
  
  (write-string-to-port   ; as of now, no alternative without javascript key event handling
     (pre-page-with-keypress-script 
      (con (text-choice "Forelsningsnoter" "Lecture notes") ": " lecture-title)
      '()

      javascript-loading
      (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
      (js-call "lenoNavigate" 
		(map string-it-single 
		     (list (if previous-lecture (book-url previous-lecture) "")
			   (if next-lecture (book-url next-lecture) "") 
			   (contents-url lecture-id)
                           "")))

      white black black black
      mouse-advancement
      )
    book-port)

  ; write author, affiliation, and abstract to bookport:
  (if (not (equal? lecture-abstract ""))
   (write-string-to-port
    (con 
     (font-1 7 book-title-foreground-color 
        (if (and lecture-number (number? lecture-number) (> (length lecture-list) 1))
            (b (con (text-choice "Kapitel" "Chapter") " " (as-string lecture-number) (br) lecture-title))
            (con (b lecture-title)))) (p)

     (con
       (font-size 5 (brl lecture-author-info)) (br)
       (font-size 4 lecture-date))

     (p) (hr-1) (p)
     (table-1 0 '(180 12 500) (make-list 3 book-background-color) 
       (list (list (con (font-1 4 book-title-foreground-color (text-choice "Sammendrag" "Abstract")) (br)
                        (font-size 1 
                         (con-space
                          (if previous-lecture (a-tag (book-url previous-lecture) (text-choice "Forrige lektion" "Previous lecture")) "")
                          (if next-lecture (a-tag (book-url next-lecture) (text-choice "Nste lektion" "Next lecture")) "") (br)
                          (a-tag (all-word-index-url lecture-id) (text-choice "Stikord" "Index"))
                          (a-tag "#REFERENCES" (text-choice "Referencer" "References"))
                          (a-tag (contents-url lecture-id) (text-choice "Indhold" "Contents"))
                        )))
                   "" (i (font-1 3 black lecture-abstract)) )))
     (p)
    )
    book-port))
  )

  ; The lecture-list data structure from the course plan facility, or '()
  (set! lecture-list-from-course-plan
   (if course-dir
    (let* ((internal-lecture-list-file (string-append course-dir "internal/lecture-list.lsp"))
           (lecture-list-file-exits? (file-exists? internal-lecture-list-file)))
      (if lecture-list-file-exits?
          (display-message "The lecture-list data structure from the course plan has been read")
          (display-message "The lecture-list data structure could not be located - only a problem if using the exercise manager"))
      
      (if lecture-list-file-exits?
          (file-read internal-lecture-list-file)
          '()))
     '()))

  (display-message (string-append "PROCESSING THE LECTURE: " lecture-title))

  (display-message (string-append "Exercise model: " (as-string used-exercise-model)))
          
)


;----------------------------------------------------------------------

; page sequencing administration:

; format of aux file:
; ("lecture title" (slide-title-string slide-id-symbol section-boolean)*)

; Return the full path of the aux file for id.
; Id defaults to the value of the global varible lecture-id
(define (aux-file-name . id)
 (let ((id-1 (if (null? id) (as-string lecture-id) (as-string (first id)))))
   (string-append note-source-directory "internal/" id-1 ".aux")))

(define note-page-list '())   ; for collection of note page ids in this run
(define note-title-list '())
(define remembered-old-page-list '())  ; to facilitate that the note page list from previous run is only read once


; cannot be a variable because it - in that case - is read before the file name is known.
(define (old-note-page-list)  
  ; note page ids from previous run
  ; Please notice the caching in remembered-old-page-list
  (cond ((not (null? remembered-old-page-list)) remembered-old-page-list)
        ((file-exists? (aux-file-name)) (let ((onpl (prepare-aux (file-read (aux-file-name)))))
                                          (set! remembered-old-page-list onpl)
                                          onpl))
        (else '())))

(define (prepare-aux lst)
  ; return the note-page-list, i.e. a list of slide-id symbols
  ; lst starts with lecture-title and then has a strings of (title slide-id section-boolean) tripples
  (map cadr (cdr lst)))

(define page-number 0) ; The number of the current note page. Assigned later.
(define page-id 'nil)  ; the name of the current note page. Assigned later.
(define page-title 'nil) ; the title of the current note page. Assigned later.
(define current-exercise-id 'nil) ; the id of an exercise - symbol. Assigned when we meet an exercise.
(define current-show-and-speak-specification '()) ; the show and speak clause of the current-page

(define (previous-page)
 ; uses the global variable page-number to return the name of the previous page.
 ; returns #f in case we are located at the first page.
 (let ((old-length (length (old-note-page-list))))
  (cond ((or (< page-number 1) (> page-number old-length)) #f) 
        ((= 1 page-number) #f)
        (else (list-ref (old-note-page-list) (- page-number 2))))))

(define (next-page)
 ; uses the global variable page-number to return the name of the next page.
 ; returns #f in case we are located at the last page.
 (let ((old-length (length (old-note-page-list))))
  (cond ((or (< page-number 1) (> page-number old-length)) #f)
        ((= old-length page-number) #f)
        (else (list-ref (old-note-page-list) page-number)))))


(define (current-page)
 ; uses the global variable page-number to return the name of the current page.
 (let ((old-length (length (old-note-page-list))))
  (cond ((or (< page-number 1) (> page-number old-length)) #f) 
        (else (list-ref (old-note-page-list) (- page-number 1))))))

(define (total-number-of-slides)
  (length (old-note-page-list)))


; -----------------------------------------------------------------------------
; Support for html saving programs, read from the source

; Numbering pr. notepage. We use identical numbering on slides, notes, and books.
(define program-number 1)
(define exercise-number 1)
(define image-number 1)

(define (reset-page-element-numbers) 
  (set! next-exercise-number next-exercise-number-0)
  (set! program-number 1)
  (set! exercise-number 1)
  (set! image-number 1))

; number is the number of the program, relative to the externally presented program on this page.
(define (save-slide-program prog-text file-name context-url show-and-speak-context-url number)
 (let ((program-show-and-speak-clause (filter (speak-select-number 'program-part number) current-show-and-speak-specification)))
  (write-text-file
   (program-slide
      context-url
      "Program"
      (pre prog-text))
   (destination-path file-name))

  ; @a show-and-speak program slide:
  (if (and show-and-speak? (= 1 (length program-show-and-speak-clause))) ; @b
      (let* ((the-clause (first program-show-and-speak-clause))
             (clause-number (speak-clause-number the-clause))
             (clause-time (speak-clause-time the-clause))
             (clause-next-name (speak-clause-next-name the-clause))
            )
       (write-text-file
	(show-and-speak-program
	 show-and-speak-context-url
	 "Program"
         (con 
           (background-speaker-sound  (speak-name lecture-id page-id 'program-part clause-number))
  	   (pre prog-text)
         )
         (html-file clause-next-name)
         clause-time
         number
        )
	(destination-path (program-name lecture-id page-id 'show clause-number)))       
       )
   )
 )
)

(define (save-note-program prog-text file-name context-url)
 (write-text-file
   (program-note
      context-url
      "Program"
      (pre prog-text))
   (destination-path file-name)))


(define (save-book-program prog-text file-name context-url)
 (write-text-file
   (program-book
      context-url
      "Program"
      (pre prog-text))
   (destination-path file-name)))

; OBSOLETE - see hereafter
; asumes that the title is the first element on a note page:
(define (title-of-elements elements)
  ; return the title string from the elements of a slide
  (car (element-contents (car elements))) )

; more general version of title-of-elements.
; does not assume any particular position of title
(define (title-of-elements elements)
  ; return the title string from the elements of a slide
 (let ((section-title-element (find-element 'section-title elements))
       (title-element (find-element 'title elements)))
  (cond (section-title-element (car (element-contents section-title-element)))
        (title-element (car (element-contents title-element)))
        (else "No title"))))

(define (find-element kind element-list)
  ; return the first element of kind in element-list.
  ; If no such element is found, return #f
  (cond ((null? element-list) #f)
        ((eq? kind (element-tag (car element-list))) (car element-list))
        (else (find-element kind (cdr element-list)))))


; extraction of keywords (index-words and concept names) to the meta tag:

; Return a list of strings, which are the extracted keywords in elements.
(define (extract-note-page-keywords elements)
  (cond ((null? elements) '())
        ((and (eq? 'index-words (element-tag (car elements))) (not (null? (element-contents (car elements)))))
            (append (element-contents (car elements)) (extract-note-page-keywords (cdr elements))))
        ((and (eq? 'concept-list (element-tag (car elements))) (not (null? (element-contents (car elements)))) 
            (append (concept-words-of-concept-list (car elements)) (extract-note-page-keywords (cdr elements)))))
        (else (extract-note-page-keywords (cdr elements)))))

; given a concept-list, return a list of 
(define (concept-words-of-concept-list a-concept-list)
  (let ((list-of-concepts (element-contents a-concept-list)))
    (map (lambda(concept) (concept-name (element-contents concept))) list-of-concepts)))
        


; -----------------------------------------------------------------------------

; Support for html saving exercises, read from the source

; The number of the next exercise in this lecture.
; This number is specific to a lecture, not to a single page.
; See also the variable exercise-number, which is page specific.
(define next-exercise-number 1)

; The start value of next-exercise-number on a note-page
; This variable is used to control exercise numbering accross slides, notes and book style
(define next-exercise-number-0 1)

(define (save-slide-exercise title text file-name context-url solution-url number)
 (let ((hier-num (if (and lecture-number (number? lecture-number))
                     (con (as-string lecture-number) "." (as-string number))
                     (as-string number)))
      )
                          
  (write-text-file
   (exercise-slide
      context-url
      (con-space (text-choice "Opgave" "Exercise") hier-num (br) title)
      text
      solution-url
      number
      title)
   (destination-path file-name))))

(define (save-note-exercise title text file-name context-url solution-url number)
 (let ((hier-num (if (and lecture-number (number? lecture-number))
                     (con (as-string lecture-number) "." (as-string number))
                     (as-string number))))
  (write-text-file
   (exercise-note
      context-url
      (con-space (text-choice "Opgave" "Exercise") hier-num (br) title)
      text
      solution-url
      number
      title
   )
   (destination-path file-name))))

; Save the HTML exercise frame file
(define (save-note-frame-exercise-file lecture-id page-id exercise-id exercise-title exercise-file-name relative-solution-url)
  (let* ((absolute-solution-url (course-absolute-url (string-append "html/noter/" relative-solution-url)))
         (frame-file-name (exercise-frame-name lecture-id page-id 'note exercise-number))
         (emu (exercise-manager-url "exercise-companion-frame.cgi"
                                   (list 'lecture-id 'exercise-id 'exercise-title 'activation-mode 'solution-url 'language) 
                                   (list  lecture-id exercise-id  exercise-title  'non-save absolute-solution-url language-preference))))
  (write-text-file
    (html4:frameset
            (con (html4:frame 'name "exercise-frame" 'src (html-file exercise-file-name) 'scrolling "yes")
                 (html4:frame 'name "exercise-manager-frame" 'src  emu 'scrolling "yes")
            )
            'rows "75%,25%" 'border 5 'bordercolor (rgb-string-list black))
    (destination-path frame-file-name))))


; Save the exercise solution.
(define (save-exercise-solution title solution-text solution-file-name context-url number)
 (let ((hier-num (if (and lecture-number (number? lecture-number))
                     (con (as-string lecture-number) "." (as-string number))
                     (as-string number))))
  (write-text-file
   (exercise-solution-note  
      context-url
      (con-space (text-choice "Opgavelsning" "Exercise solution") hier-num (br) title)
      solution-text
   )
   (destination-path solution-file-name))))


; -----------------------------------------------------------------------------
; cross reference support

; Cross reference constructors
; To be used in note pages.

(define (informal-reference title reference)
  ; both strings
  (list 'informal-reference title reference (list 'informal-reference)))

(define (internet-reference title url . location-hints)
 (let ((lh (if (not (null? location-hints)) (car location-hints) '())))
  (list 'internet-reference title url (cons 'internet-reference lh))))

(define (note-reference title lecture-id page-id . location-hints)
 (let ((lh (if (not (null? location-hints)) (car location-hints) '())))
  (list 'note-reference title lecture-id page-id (cons 'note-reference lh))))

; Cross reference selectors:
; To be used in this software.

(define (cross-ref-type record)
  ; returns a symbol
  (car record))

(define (cross-ref-title record)
  (cadr record))

(define (cross-ref-reference record)
  (if (eq? (cross-ref-type record) 'informal-reference)
      (caddr record)
      (error "No reference proper in this cross reference. Should be informal-reference to use this function")))

(define (cross-ref-url record)
  (if (eq? (cross-ref-type record) 'internet-reference)
      (caddr record)
      (error "No URL in this cross reference")))

(define (cross-ref-lecture-id record)
  (if (eq? (cross-ref-type record) 'note-reference)
      (caddr record)
      (error "No lecture id in this cross reference")))

(define (cross-ref-page-id record)
  (if (eq? (cross-ref-type record) 'note-reference)
      (cadddr record)
      (error "No page id in this cross reference")))

; Cross reference display procedures (for error messages):

(define (display-crs-entry crs-entry)
 (let ((type (cross-ref-type crs-entry)))
   (cond ((eq? type 'informal-reference) (display-informal-ref crs-entry))
         ((eq? type 'internet-reference) (display-internet-ref crs-entry))
         ((eq? type 'note-reference) (display-note-ref crs-entry))
         (else (error (string-append "display-crs-entry: Unknown cross reference type: " (as-string type)))))))

(define (display-informal-ref crs-entry)
  (display "An informal cross reference"))  ; put details in if necessary

(define (display-internet-ref crs-entry)
  (display "An internet reference"))        ; put details in if necessary

(define (display-note-ref crs-entry)
 (let ((title (cross-ref-title crs-entry))
       (lecture (cross-ref-lecture-id crs-entry))
       (page (cross-ref-page-id crs-entry)))
   (display (string-append "Target lecture: " (as-string lecture) "      " "Target page: " (as-string page) "      "))
   (display (string-append "Title: " title)) 
))


; Return the list of location hints of the record
(define (cross-ref-location-hints record)
 (let ((ctype (cross-ref-type record)))
  (cond ((eq? 'note-reference ctype)     (fifth record))
        ((eq? 'internet-reference ctype) (fourth record))
        ((eq? 'informal-reference ctype) (fourth record))
        (else '()))))
         
  


; -----------------------------------------------------------------------------
; The function which generates an appropriate formatter function for
; an cross reference record.

(define (generate-cross-reference-formatter url-function)
  ; given an url function (one of slide-url, note-url and book-url)
  ; the url function allows book-to-book references and slide-to-slide references.
  ; return a function which can format a cross reference record.
  ; Depends on the function cross-reference-location-hints, which is not supplied in this file.
  ; cross-reference-location-hints is normally defined in notes.scm together with the lectures.
  ; In the simple case, it just returns an empty string.
  ; The generated function returns a list of two elements: an url and the hint (both strings).
 (lambda (cross-ref-record)
  (let ((descr (cross-ref-title cross-ref-record))
        (type (cross-ref-type cross-ref-record))
        (loc-hint (cross-reference-location-hints (cross-ref-location-hints cross-ref-record)))
       )
   (cond ((eq? type 'internet-reference)
          (let ((url (cross-ref-url cross-ref-record)))
             (list (a-tag url descr) loc-hint)))
         ((eq? type 'note-reference)
          (let ((lect-id (cross-ref-lecture-id cross-ref-record))
                (page-id (cross-ref-page-id cross-ref-record))
               )
             (list (a-tag (url-function lect-id page-id) descr) loc-hint)))
         ((eq? type 'informal-reference)
          (let ((informal-ref (cross-ref-reference cross-ref-record)))
             (list (string-append descr ": " informal-ref) loc-hint)))
         (else (error "Problems in format-cross-ref. Second item is unknown"))))
 )
)

; Given that refs is a list of references, each a reference (url) and a hint
; Glue the references and hints together.
; Return a list of glued links and hints
(define (glue-ref-and-hint refs)
  (map (lambda (url-hint-pair) (string-append (car url-hint-pair) (cadr url-hint-pair))) refs))


; -----------------------------------------------------------------------------
; The note page:

(define (note-page id . elements)
   
 (if lecture-note-verbose-mode (begin (display (string-append (as-string lecture-id) ":" (as-string id) "  ")) ))

 (let ((title-element (title-of-elements elements))
       (long-slide? (find-element 'long-slide elements))
       (section-start? (turn-into-boolean (find-element 'section-title elements)))
       (element-keywords (extract-note-page-keywords elements))
       (show-and-speak-clause (find-element 'show-and-speak elements))
      )

  (set! note-page-list (cons id note-page-list))
  (set! page-number (+ page-number 1))
  (set! note-title-list (cons (list title-element id section-start? page-number) note-title-list))
  (set! page-id id) ; for convenient direct variable reference below
  (set! page-title title-element) ; for convenient direct variable reference below
  (set! lsp-contents-in-this-lecture (cons (make-lsp-page page-id elements) lsp-contents-in-this-lecture))

  (let ((the-next-page (next-page)))

	; take show-and-speak information of this page out in a global variable. A list of show-and-speak clauses
	(set! current-show-and-speak-specification
	      (normalize-speak (if show-and-speak-clause (element-contents show-and-speak-clause) default-show-and-speak-clause) 
			       lecture-id id
			       (if the-next-page 
				   (show-and-speak-slide-name lecture-id the-next-page 1)
				 (end-show-and-speak-page-name lecture-id))))

        ; add information to the variable speak-list-in-this-lecture
        (if show-and-speak? (add-to-internal-speak-entries current-show-and-speak-specification))

	(set! next-exercise-number-0 next-exercise-number) ; the start value on this page.

	(reset-page-element-numbers)	; @c ensure program/exercise/image numering pr. page pr. presentation-kind (slide, note, book)

					; make the standard slide
	(write-text-file
	 (standard-slide
	  title-element
	  (as-slide-text
	   (apply con
		  (map
		   (lambda (e)
		     (present-element
		      'slide-style
		      (element-tag e)
		      (element-contents e)) 
		     )
		   elements)))
	  long-slide?
	  element-keywords
	  (down-links elements lecture-id page-id 'slide) ;@h
	  )
	 (destination-path (if slide-header-as-frame? (slide-name-0 lecture-id id) (slide-name lecture-id id))))

					; If wanted, make the automatically progressing show and speak variationS of the slide:
	(if show-and-speak?		; @j
	    (let ((slide-show-and-speak-specs (filter (speak-select 'slide-part) current-show-and-speak-specification)))
              (set! show-and-speak-context #t)
	      (for-each 
	       (lambda (slide-spec)
		 (make-show-and-speak-slide slide-spec id elements))
	       slide-show-and-speak-specs)
              (set! show-and-speak-context #f)
            )
        )

	(if slide-header-as-frame?
	    (let ((navigation-filename (filename-of-top-navigation lecture-id id))
		  (frame-filename (filename-of-main-frame lecture-id id))
		  (slide-filename (slide-name-0 lecture-id id)))

					; WRITE FRAME:
	      (write-text-file
	       (html4:html
		(con (html4:head (html4:title "title"))
		     (html4:frameset 
		      (con (html4:frame 'name "leno:navigation" 'src (string-append navigation-filename ".html") 'scrolling "no"
					'noresize "" 'frameborder "0" 'framespace "0") 
			   (html4:frame 'name "leno:main" 'src (string-append slide-filename ".html") 'scrolling "auto" 'frameborder "0" 'framespace "0"))
		      'rows "45,*" 'frameborder "0" 'border "0")))
	       (destination-path frame-filename))      

					; WRITE TOP, HORIZONTAL NAVIGATION BAR
	      (write-text-file
	       (page "navigation"
		     (slide-header-topbar)
		     slide-background-color black black black)
	       (destination-path navigation-filename))        
	      )
	  )

	(reset-page-element-numbers)	; @d ensure program/exercise/image numering pr. page pr. presentation-kind (slide, note, book)
	(write-text-file
	 (standard-note 
	  title-element
	  (apply con
		 (map
		  (lambda (e)
		    (present-element
		     'note-style
		     (element-tag e)
		     (element-contents e)))
		  elements))
	  element-keywords
	  (down-links elements lecture-id page-id 'note) ;@i
	  )
	 (destination-path (note-name lecture-id id)))


	(reset-page-element-numbers)	; @e ensure program/exercise/image numering pr. page pr. presentation-kind (slide, note, book)
	(write-string-to-port
	 (apply con
		(map
		 (lambda (e)
		   (present-element
		    'book-style
		    (element-tag e)
		    (element-contents e)))
		 elements))
	 book-port)

	(if lecture-note-verbose-mode (begin (display " OK") (newline)))

    )))

; Constructor and selectors of entries in the lsp representation on internal lsp files.
(define make-lsp-page cons)
(define id-of-lisp-page car)
(define elements-of-lisp-page cdr)


(define (present-element style kind contents)
  (let ((processing-procedure (find-processor style kind)))
    (apply processing-procedure contents)))


(define (make-lecture-note-contents-page)
 (let* ((prev (if previous-lecture (contents-url previous-lecture) ""))
        (next (if next-lecture (contents-url next-lecture) ""))
        (down-links (list (slide-url lecture-id (first-slide-id lecture-id))
                          (note-url lecture-id (first-slide-id lecture-id))
                          (book-url lecture-id)))  ;@a
        (body (con 
               (index-page-header) (br)

               ; title and author info side by side with logo image.
               (table-3 0
                (list 752 200)
                  (list
                    (list
                      (h 3
                        (con 
                          (h 1 (con lecture-title))

                          (list-to-string
                            (map (lambda (e) (con e (br)))  (append lecture-author-info (list lecture-date)) )
                            ""
                          )))

                     (logo-img)))
                     "middle")

               (vertical-space 1)


               (a-tag (string-append (book-name lecture-id) ".html") 
                      (font-size 2 (text-choice "Forelsningsnote fra starten" "Lecture notes from the beginning")))
               (horizontal-space 12)

               (if show-and-speak?
                   (con (a-tag 
                          (slide-show-and-speak-url lecture-id (first-slide-id lecture-id) 1)  
                          (font-size 2 (text-choice "Indtalt forelsning fra starten" "Spoken lecture from the start")))
                        (horizontal-space 12))
                   "")

               (if lecture-title-page?
                   (a-tag
                      (html-file (title-page-name lecture-id))
                      (font-size 2 (text-choice "Forside" "Title page"))
                   )
                   "")
               (horizontal-space 12)

               (if lecture-title-page?
                   (a-tag
                      (html-file (abstract-page-name lecture-id))
                      (font-size 2 (text-choice "Sammendrag" "Abstract"))
                   )
                   "")
               (horizontal-space 12)

               (a-tag (string-append (book-name lecture-id) ".html" "#REFERENCES") 
                      (font-size 2 (text-choice "Referencer fra denne lektion" "References from this lecture")))
               (horizontal-space 12)

               (if (and exercise-index? (> (length lecture-exercise-list) 0))
                 (con (a-tag (string-append (exercise-index-name lecture-id) ".html") 
                             (font-size 2 (text-choice "Opgaver i denne lektion" "Exercises in this lecture")))
                      (horizontal-space 12))
                 "")

               (br)

               (if (and quiz-support? (> (length quiz-list) 0))
                   (con 
                     (a-tag (quiz-url "show-quiz.cgi" 
                                     (list 'quiz-filename 'activation-mode)
                                     (list (string-append note-source-directory "internal/" (as-string lecture-id) ".quiz") "present"))  
                           (font-size 2 (text-choice "Quiz om denne lektion" "Quiz about this lecture")))
                     (horizontal-space 12))
                   "") 


               (p)
 
               (table-1 1
                        '(440 70 70 165 165)
                        (make-list 5 slide-background-color)
                        (map2 
                         (lambda (e number) ; number not used...
                           (let ((slide-title (car e))
                                 (slide-id (cadr e))
                                 (slide-section-start? (caddr e)))
                             (list (con 
                                    (if slide-section-start?
                                        (font-color red (b slide-title))
                                      slide-title))
                                   (con (text-choice "Side " "Page ") (as-string number))
                                   (con 
                                      (a-tag (html-file (slide-name lecture-id slide-id)) "Slide") 
                                      (if show-and-speak?
                                         (con (horizontal-space 2)
                                              (if (file-exists? (sound-file-path (speak-name lecture-id slide-id 'slide-part 1)))
                                                  (a-tag (html-file (show-and-speak-slide-name lecture-id slide-id 1)) (img-LN "small-speaker.gif" "Show and speak slide"))
                                                  (img-LN "small-speaker-empty.gif" ""))

                                         )
                                         ""))
                                   (a-tag (string-append (note-name lecture-id slide-id) ".html") 
                                          (text-choice "Kommenteret slide" "Slide with comments")) 
                                   (a-tag (string-append (book-name lecture-id) ".html" "#" (as-string slide-id))
                                          (text-choice "Forelsningsnote" "Lecture notes"))
                                   )))

                         (reverse note-title-list) (number-interval 1 (length note-title-list)))) (p)

               (if show-and-speak? 
                   (con (a-tag (html-file (internal-show-and-speak-page-name lecture-id)) (font-size 1 "Intern 'show-and-speak' oversigt")) 
                        (p))
                   "")

               (when-generated)
               )))
    (write-text-file
     (if java-scripting
         (page-with-keypress-script
           (con lecture-title)
           '()
           body

          javascript-loading
          (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
          (js-call "lenoNavigate"   ;@b
                   (append
                     (map string-it-single 
                          (list prev
                                next 
                                (if front-index? (front-index-url) "")
                                ""))
                     (list (js-string-array down-links))))

           white black blue blue
           mouse-advancement
         )

       (page-1
        (con lecture-title)
        '()
        body
        white black blue blue
        ))
     (destination-path lecture-id))))


; -----------------------------------------------------------------------------
; word index stuff

(define (format-word-in-index index-element)
  ; an index element is of the form (word url)
 (a-tag (cadr index-element) (car index-element)))

(define (index-elements-leq? el1 el2)
  (string<=? (decapitalize-string (string-copy (car el1))) (decapitalize-string (string-copy (car el2))))) 

; There is a new version, makeing a word index of all sections until current-lecture
; (define (make-lecture-word-index-page)
;   ; write a page with the word index of this lecture
;   (write-text-file
;     (page 
;       (con lecture-title " Index")
;       (con 
;         (word-index-header) (br)
;         (h 1 (con "Index: " lecture-title))  (br)
; 
;        (indent-pixels 10
;          (brl
;           (map format-word-in-index
;                (sort-list word-index index-elements-leq?)))))
;       slide-background-color black black black )
;    (destination-path (word-index-name lecture-id))))

; -----------------------------------------------------------------------------

; make a cross reference contribution to the book port:
(define (make-cross-reference-section-in-book cross-ref-list)
 (write-string-to-port
  (let ((formatter-function (generate-cross-reference-formatter book-url)))
    (con (hr-1) (a-name "REFERENCES")
     (book-element 
       (font-1 4 book-title-foreground-color 
          (con  (text-choice "Samlede referencer" "Collected references") (br)
             (font-size 1 
              (con
               (a-tag (contents-url lecture-id) (text-choice "Indhold" "Contents") ) (space 1)
               (a-tag (all-word-index-url lecture-id) (text-choice "Stikord" "Index")) ))  ))
       (table-3 0 (list 420 80)
           (remove-duplicates (map formatter-function cross-ref-list))))
        (p)))
  book-port))

; make a source file listing contributin to the book port:
(define (make-source-file-listing list-of-source-files)
 (write-string-to-port
    (con (hr-1) (a-name "SOURCE-FILE-LIST")
     (book-element-unlimited
       (font-1 4 book-title-foreground-color 
         (con
          (text-choice "Kildefiler i denne lektion" "Source files in this lecture") (br)
          (font-size 1 
            (con
             (a-tag (contents-url lecture-id) (text-choice "Indhold" "Contents") ) (space 1)
             (a-tag (all-word-index-url lecture-id) (text-choice "Stikord" "Index")) (space 1)
             (a-tag "#REFERENCES" (text-choice "Referencer" "References")) ))) )
       (con
        (brl
          (map (lambda (f) (font-size 2 f)) (reverse (remove-duplicates list-of-source-files))))
        (p) )))
  book-port))

; Make an index page to be placed in the note source directory with useful links to the pages in the html directory.
; An optional parameter 'minimal (a symbol) will only generate a link to the lecture overview page. Use this for trails.
(define (make-source-level-index-page . optional-parameters)
 (let ((minimal? (if (null? optional-parameters) #f (eq? (car optional-parameters) 'minimal))))
  (let ((body 
         (con
          (h 1 (con lecture-title))
          (h 3
          (list-to-string
            (map (lambda (e) (con e (br))) (append lecture-author-info (list lecture-date)))
            ""
          )
          ) (p)

          (color-frame-width
            (i (font-color black lecture-abstract))
            grey2
            550)

          (p)

          (indent-pixels 10
            (con 
               (if lecture-title-page?
                   (con 
                     (a-tag (string-append (relative-source-html-destination-path-fragment) (title-page-name lecture-id) ".html") 
                            (text-choice "Forside" "Title page")) (p))
                   "")

               (if lecture-title-page?
                   (con 
                     (a-tag (string-append (relative-source-html-destination-path-fragment) (abstract-page-name lecture-id) ".html") 
                            (text-choice "Sammendrag" "Abstract")) (p))
                   "")

               (a-tag (string-append (relative-source-html-destination-path-fragment)  (as-string lecture-id) ".html") 
                      (text-choice "Oversigt over denne lektion" "Lecture overview")) (p)

               (if (not minimal?)
                   (con

                    (a-tag (string-append (relative-source-html-destination-path-fragment) (book-name lecture-id) ".html") 
                           (text-choice "Forelsningsnote fra starten" "Lecture notes from the beginning")) (p)

                    (a-tag (string-append (relative-source-html-destination-path-fragment) (book-name lecture-id) ".html" "#REFERENCES") 
                           (text-choice "Referencer fra denne lektion" "References from this lecture")) (p)
     
                    (if (and exercise-index? (> (length lecture-exercise-list) 0))
                      (a-tag (string-append (relative-source-html-destination-path-fragment) (exercise-index-name lecture-id) ".html") 
                             (text-choice "Opgaver i denne lektion" "Exercises in this lecture"))
                      "") (p)

                    (if (and quiz-support? (> (length quiz-list) 0))
                      (a-tag (quiz-url "show-quiz.cgi" 
                                       (list 'quiz-filename 'activation-mode)
                                       (list (string-append note-source-directory "internal/" (as-string lecture-id) ".quiz") "present"))  
                             (text-choice "Quiz om denne lektion" "Quiz about this lecture"))
                      "") (p)
     
                    (if trail-of-lecture?
                      (a-tag (string-append (relative-source-html-destination-path-fragment) (default-trail-name lecture-id) ".html")
                             (text-choice "Trail udgave af denne lektion" "Trail edition of this lecture"))
                      ""))
                   "")

                (vertical-space 1)

               ))
        (when-generated)
     )))
    (write-text-file
     (page-1
        (con lecture-title)
        '()
        body
        white black blue blue
        )
     (source-path lecture-id)))))


(define (make-lecture-title-page first-slide-url first-show-and-speak-url)
 (let ((body
         (con 
          (center
            (con
               (vertical-space 2)
               (font-1 7 black (con lecture-title))
               (vertical-space 2)
               (h 1 (em (car lecture-author-info))) (br)   ; author
               (h 2
                  (apply con
                         (map (lambda (e) (con e (br))) (cdr lecture-author-info)))
                  )
               (h3 lecture-date)

               (vertical-space 1) 
               (a-tag (html-file (abstract-page-name lecture-id)) (font-1 2 grey1 "Abstract")) (br)               
               (a-tag first-slide-url (font-1 2 grey1 "Start")) (br)
               (if show-and-speak?
                   (con (a-tag first-show-and-speak-url 
                              (font-1 2 grey1 (text-choice "Start indtalte slides" "Start spoken slides"))) (br))
                   "")
               (if trail-of-lecture?
                   (con (a-tag (html-file (filename-of-trail-frame (default-trail-name lecture-id) lecture-id (first-slide-id lecture-id)))
                               (font-1 2 grey1 "Trail start")) (br))
                   "")
               (vertical-space 1)
               (logo-img)
            )
          )
        ))) 
  (write-text-file
    (if java-scripting
      (page-with-keypress-script
         (as-string lecture-title) 
         '()
         body

         javascript-loading
         (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
         (js-call "lenoNavigate" 
                   (map string-it-single 
                        (list ""
                              (html-file (abstract-page-name lecture-id))  ; the abstract page
                              ""
                              "")))

         slide-background-color black black black
         mouse-advancement
      )

      (page-1
       (as-string lecture-title) 
       '()
       body
       slide-background-color black black black ))
    (destination-path (title-page-name lecture-id)))))

(define (make-lecture-abstract-page first-slide-url first-show-and-speak-url)
 (let ((body (con
	      (center
	       (con
		(vertical-space 2)
		(font-size 6 (b (text-choice "Sammendrag" "Abstract")))
		(vertical-space 2)
		(narrow
		 br			; does not matter
		 650
		 (font-size 5 (em (font-color black lecture-abstract)))
		 )
		(vertical-space 1)
		(a-tag first-slide-url (font-1 2 grey1 "Start")) (br)
                (if show-and-speak?
                    (con (a-tag first-show-and-speak-url 
                              (font-1 2 grey1 (text-choice "Start indtalte slides" "Start spoken slides"))) (br))
                    "")
		(if trail-of-lecture?
		    (con (a-tag (html-file (filename-of-trail-frame (default-trail-name lecture-id) lecture-id (first-slide-id lecture-id)))
				(font-1 2 grey1 "Trail start")) (br))
		    "")
		)
	       )
	      )))
  (write-text-file
    (if java-scripting
      (page-with-keypress-script
         (as-string lecture-title) 
         '()
         body

         javascript-loading
         (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
         (js-call "lenoNavigate" 
                   (map string-it-single 
                        (list ""
                              first-slide-url
                              ""
                              "")))

         slide-background-color black black black
         mouse-advancement
      )

      (page-1
       (as-string lecture-title) 
       '()
       body
       slide-background-color black black black ))
  (destination-path 
    (abstract-page-name lecture-id))))
)


(define (end-notes)

 (if (file-exists? (aux-file-name))
     (delete-file (aux-file-name)))
 
 ; generate new aux file
 (with-output-to-file (aux-file-name)
     (lambda () (write (cons lecture-title (reverse note-title-list)) )))  ; ealier note-page-list

 (if (> (length cross-refs-in-this-lecture) 0)
   (make-cross-reference-section-in-book
      (reverse cross-refs-in-this-lecture)))

 (if (and include-source-file-listing? (> (length list-of-source-files) 0))
   (make-source-file-listing
      list-of-source-files))

 (write-string-to-port
   (book-footer) book-port)

 (write-string-to-port
    (post-page-with-comments)
    book-port)
 
 (close-output-port book-port)

 ; make contents page of this lecture
 (make-lecture-note-contents-page)

 ; make word index file, in order to be able to collect a global word index.
 (if (file-exists? (word-index-file-name))
     (delete-file (word-index-file-name)))

 (with-output-to-file (word-index-file-name)
     (lambda () (write word-index)))


 ; make cross reference file in order collect all cross references in one place:
 (if (file-exists? (cross-ref-file-name))
     (delete-file (cross-ref-file-name)))

 (with-output-to-file (cross-ref-file-name)
     (lambda () (write cross-refs-in-this-lecture)))

 ; word index covering all sections until current-lecture
 (if word-index? 
   (if split-word-index-alphabetically? 
       (make-lecture-word-index-pages (all-index-words))
       (make-lecture-word-index-page (all-index-words))))

 ; requires that all cross reference files, -.crs files, in lecture set are defined:
 (if cross-references? (make-total-cross-references-page (all-cross-references)))

 (if exercise-index?
     (begin
       (make-all-exercise-page lecture-list (list "Opgaver" "Exercises") 
                                            exercise-formulation-entry all-exercises-name)
       (if (or reveal-exercise-solutions? reveal-all-solutions?)
           (make-all-exercise-page lecture-list (list "Opgaver og lsninger" "Exercises and solutions") 
                                            exercise-formulation-solution-entry all-exercises-and-solutions-name))
     ))

 ; a "secret", non-linked-to page with exercises and solutions.
 ; good to teaching assistents etc.

 (make-all-exercise-page lecture-list (list "Opgaver og lsninger" "Exercises and solutions") 
                                       exercise-formulation-solution-entry secret-all-exercises-and-solutions-name)


 ; make the pr. lecture exercise index
 (if exercise-index? (make-exercise-index lecture-exercise-list))

 ; save information about the exercises in this lecture
 (if exercise-index?
     (save-exercise-info lecture-exercise-list ))

 ; warn if it is too early to reveal exercise solutions:
 (if (and exercise-manager-support?)
     (if (> (current-time) (lecture-exercise-reveal-time lecture-id))
         (display-message "Exercise manager info: We revealed exercise solutions")
         (let* ((tm (lecture-exercise-reveal-time lecture-id))
                (day (weekday tm))
                (dt (date-time tm))
                (date (car dt))
                (time (cadr dt))
               )
           (display-warning (string-append "Can first reveal exercises " day ", " date ", " time)))))

 ; generate exercise manager control page (for teachers only):
 (if #t
     (make-exercise-manager-control-center lecture-id))


 ; make the overall exercise index, covering all lectures up to current-lecture
 ; must take place after saving the exercise info about the current lecture
 (make-overall-exercise-index)

 ; make index of all lectures - absolute top level page - in the index.html file
 (if front-index? (make-front-index))

 ; Copying the appropriate lenonavigate file from the software directory to the notes directory. 
 ; Depends on the variable mouse-advancement:
 (if (and java-scripting (eq? javascript-loading 'dynamic))
     (copy-text-file (string-append leno-software-directory "javascript/" 
                        (cond ((eq? mouse-advancement 'double-press) "lenonavigate-double.js")
                              ((eq? mouse-advancement 'single-press) "lenonavigate-single.js")
                              (else (error (string-append "end-notes: Cannot determine which lenonavigate to copy."))))
                     )
                     (string-append note-source-directory (relative-source-html-destination-path-fragment) "javascript/lenonavigate.js")
                     #t  ; overwrite if necessary
     )
 )

 ; Copying the images (icons) from the software directory to the notes directory:
 (if copy-image-files? 
      (begin
        (copy-files 
          leno-image-files
          (string-append leno-software-directory "images/")
          (string-append note-source-directory (relative-source-html-destination-path-fragment) "images/") )))

 ; Copying note specific icons
 ; The variable note-specific-image-files can be redefined in post-notes.scm, NOT in notes.scm
 (if copy-image-files? 
      (begin
        (copy-files 
          note-specific-image-files
          (string-append note-source-directory "images/")
          (string-append note-source-directory (relative-source-html-destination-path-fragment) "images/") )))

 ; Copying note graphics - user made illustrations to the the HTML graphics directory
 ; Copied to same directory as the leno image files - redefinition and overwriting is possible.
 (if copy-note-graphics?
      (begin
        (copy-files 
          note-specific-graphics-files
          (string-append note-source-directory "graphics/")
          (string-append note-source-directory (relative-source-html-destination-path-fragment) "graphics/") )))

 ; Copying note small graphics - user made illustrations to the the HTML small graphics directory
 (if copy-note-graphics?
      (begin
        (copy-files 
          note-specific-graphics-files
          (string-append note-source-directory "graphics/small/")
          (string-append note-source-directory (relative-source-html-destination-path-fragment) "graphics/small/") )))

 ; Copying lecturer graphics
 (if (and show-and-speak? copy-lecturer-photos?)
      (begin
        (copy-files 
          lecturer-photo-list
          (string-append note-source-directory "lecturer-photos/")
          (string-append note-source-directory (relative-source-html-destination-path-fragment) "lecturer-photos/") )))


 
 ; Check for page-id duplicates;
 (check-page-id-duplicates!)

 ; Check cross references in this lecture
 (display (string-append "Checking all note references in " (as-string lecture-id))) (newline)

 (let ((problem-references (check-crs-file lecture-id (all-page-info (map car lecture-sections)))))
   (if (not (null? problem-references))
       (begin
         (display "The following note references refer to unknown targets: ") (newline) 
         (for-each 
           (lambda (problem-ref)
             (display-crs-entry problem-ref) (newline))
           problem-references)
       )
       (display-message "All note cross references are OK")))

 (if trail-of-lecture?
   (begin
     (display-message 
       (string-append "Making trail which parallels the lecture - see " 
                      (string-append (relative-source-html-destination-path-fragment) (default-trail-name lecture-id) ".html")))

     ; Make trail of this lecture - provides for a convenient alternative navigation
      (note-trail-1 
       (as-symbol (default-trail-name lecture-id))
       (map (lambda (page-id) (slide-select lecture-id page-id)) (reverse note-page-list)))
   )
 )
 
 (if source-level-index-page? 
    (begin 
      (display-message (string-append "You can start browsing these lecture notes at " lecture-id "." target-extension)) 
      (make-source-level-index-page)))

 (if lecture-title-page? 
    (let ((first-slide-url (slide-url lecture-id (first-slide-id lecture-id)))
          (first-show-and-speak-url (slide-show-and-speak-url lecture-id (first-slide-id lecture-id) 1))
         )
      (make-lecture-title-page first-slide-url first-show-and-speak-url)
      (make-lecture-abstract-page first-slide-url first-show-and-speak-url)))


 (if (and quiz-support? (not (null? quiz-list)))
     (file-write
      (make-quiz-file
        lecture-id
        lecture-title
        (map2 internal-quiz-format (reverse quiz-list) (number-interval 1 (length quiz-list)))
      )
      (quiz-file-name)))


 (if show-and-speak?
     (write-text-file
       (end-show-and-speak-page)
       (destination-path (end-show-and-speak-page-name lecture-id))))


 ; make cross reference file in order collect all cross references in one place:
 (if (file-exists? (speak-file-name lecture-id))
     (delete-file (speak-file-name lecture-id)))


 ; Reverse speak-list-in-this-lecture:
 (set! speak-list-in-this-lecture (reverse speak-list-in-this-lecture))

 (with-output-to-file (speak-file-name lecture-id)
     (lambda () (write speak-list-in-this-lecture)))


 (if show-and-speak?
     (write-text-file
       (internal-show-and-speak-page speak-list-in-this-lecture)
       (destination-path (internal-show-and-speak-page-name lecture-id))))


 ; make full contents lsp file in order to save entire contents querrying purposes.
 (if (file-exists? (lsp-file-name))
     (delete-file (lsp-file-name)))


 (with-output-to-file (lsp-file-name)
     (lambda () (write (reverse lsp-contents-in-this-lecture))))

      
)

; Check for duplicated page ids
(define (check-page-id-duplicates!)
  (let ((duplicates (duplicates-by-predicate note-page-list eq?)))
    (if (not (null? duplicates))
        (display-warning (string-append "There are pages with duplicated ids in this lecture: " (as-string duplicates)))
        (display-message "There are no duplicated page ids in this lecture")
  )))




; -----------------------------------------------------------------------------
; Functions which html formats a piece of source program for slides, notes and books:

(define (program-slide context-url title contents . optional-parameter-list)  
 (let* ((program-number (optional-parameter 1 optional-parameter-list 1)) ; not used yet  ??
       )
  (let ((body  (con (program-header context-url (key-shortcut (text-choice "Tilbage til slide" "Back to slide") "u")) (vertical-space 1)
                    (indent-pixels 10 (font-size slide-font-size contents)))))
    (if java-scripting
      (page-with-keypress-script
         (as-string title) 
         '()
         body

         javascript-loading
         (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
         (js-call "lenoNavigate" 
                   (map string-it-single 
                        (list ""
                              ""
                              context-url
                              "")))

         slide-background-color black black black
         mouse-advancement
      )

      (page-1
       (as-string title) 
       '()
       body
       slide-background-color black black black )))))


(define (program-note context-url title contents)
  (let ((body  (con (program-header context-url (key-shortcut (text-choice "Tilbage til noter" "Back to notes") "u") ) (vertical-space 1)
                    (indent-pixels 10 (font-size note-font-size-left contents)))))
    (if java-scripting
      (page-with-keypress-script
         (as-string title) 
         '()
         body

         javascript-loading
         (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
         (js-call "lenoNavigate" 
                  (map string-it-single 
                       (list ""
                             ""
                             context-url
                             "")))

         slide-background-color black black black
         mouse-advancement
      )
      (page-1
        (as-string title) 
        '()
        body
        slide-background-color black black black))))

(define (program-book context-url title contents)
  (let ((body (con (program-header context-url (key-shortcut (text-choice "Tilbage til forelsningsnoter" "Back to lecture notes") "u")) (vertical-space 1)
                   (font-size book-font-size contents))))
    (if java-scripting
      (page-with-keypress-script
         (as-string title) 
         '()
         body

         javascript-loading
         (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
         (js-call "lenoNavigate" 
                  (map string-it-single 
                       (list ""
                             ""
                             context-url
                             "")))

         slide-background-color black black black
         mouse-advancement
     )
     (page-1
        (as-string title) 
        '()
        body
        slide-background-color black black black))))

; -----------------------------------------------------------------------------

(define (exercise-slide context-url title contents solution-url number exercise-title)
  (let ((body  (con (exercise-slide-header 
                       context-url 
                       (key-shortcut 
                         (text-choice "G til slide, hvor denne opgave er tilknyttet"
                                      "Go to the slide, where this exercise belongs") "u")
                       number
                       exercise-title
                    )
                    (br) (font-color blue (h 1 title)) (p) (hr-1) (p)
                    (indent-pixels 10 (font-size slide-font-size contents)) (p) (hr-1) (p)

                    (cond ((equal? solution-url "") (font-size 2 (text-choice "Der findes ingen lsning til denne opgave" "There is no solution to this exercise")))
                          ((and (do-reveal-exercise-solutions?) (not (equal? solution-url ""))) (a-tag solution-url (text-choice "Lsning" "Solution")))
                          (else ""))
                        
                    )))

    (if java-scripting
      (page-with-keypress-script
        (as-string title) 
        '()
         body

         javascript-loading
         (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
         (js-call "lenoNavigate" 
                  (map string-it-single 
                       (list ""
                             ""
                             context-url
                             "")))

         slide-background-color black black black
         mouse-advancement
      )
      (page-1
        (as-string title) 
        '()
         body

         slide-background-color black blue blue))))


(define (exercise-note context-url title contents solution-url number exercise-title)
  (let ((body  (con (exercise-note-header
                       context-url 
                       (key-shortcut 
                         (text-choice "G til annoteret slide, hvor denne opgave er tilknyttet"
                                      "Go to the notes, in which this exercise belongs") "u")
                       number
                       exercise-title
                    )
                    (br) (font-color blue (h 1 title)) (p) (hr-1) (p)
                    (indent-pixels 10 (font-size note-font-size-left contents)) (p) (hr-1) (p)

                    (cond ((equal? solution-url "") (font-size 2 (text-choice "Der findes ingen lsning til denne opgave" "There is no solution to this exercise")))
                          ((and (do-reveal-exercise-solutions?) (not (equal? solution-url ""))) (a-tag solution-url (text-choice "Lsning" "Solution")))
                          (else ""))
                )))
    (if java-scripting
      (page-with-keypress-script
        (as-string title) 
        '()
         body

         javascript-loading
         (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
         (js-call "lenoNavigate" 
                  (map string-it-single 
                       (list ""
                             ""
                             context-url
                             "")))

         slide-background-color black black black
         mouse-advancement
      )
      (page-1
        (as-string title) 
        '()
         body

         note-background-color black blue blue))))

; Similar to exercise-note, but here for solutions
(define (exercise-solution-note context-url title contents)
  (let ((body  (con (exercise-solution-header
                        context-url 
                       (key-shortcut 
                         (text-choice "G til annoteret slide, hvor denne opgave er tilknyttet"
                                      "Go to the notes, in which this exercise belongs") "u")
                       exercise-number
                       title
                    )
                    (br) (font-color blue (h 1 title)) (p) (hr-1) (p)
                    (indent-pixels 10 (font-size note-font-size-left contents)) (p) (hr-1) (p)
                )))
    (if java-scripting
      (page-with-keypress-script
        (as-string title) 
        '()
         body

         javascript-loading
         (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
         (js-call "lenoNavigate" 
                  (map string-it-single 
                       (list ""
                             ""
                             context-url
                             "")))

         slide-background-color black black black
         mouse-advancement
      )
      (page-1
        (as-string title) 
        '()
         body

         note-background-color black blue blue))))



; -----------------------------------------------------------------------------


(define (comma-separated-string string-list)
  (string-merge string-list (make-list (- (length string-list) 1) ", ")))



; Make a standard LENO slides with or without Javascript, depending on the variable java-scripting
(define (standard-slide title contents long? keywords-to-meta down-links)
 (let* ((meta-contribution (if (null? keywords-to-meta) 
                              '()
                              (list (list 'name "keywords" 
                                  'lang (meta-language language-preference)
                                  'content (comma-separated-string keywords-to-meta)))))
        (prev (if (previous-page) (previous-page) #f))
        (next (if (next-page) (next-page) #f))
        (body (con 
                 (slide-start-marker)
                 (if slide-header-as-frame?
                    "" 
                    (cond ((eq? slide-header? 'normal) (con (slide-header 'slide) (br)))
                          ((eq? slide-header? 'none) "")
                          ((eq? slide-header? 'minimal) (left-right-banner "" (minimal-slide-header)))
                          (else (error (string-append "Standard-slide: Unknown slide-header?: " (as-string slide-header?))))))
                 contents
                 (if slide-header-as-frame? "" (if long? 
                                                   (empty-slide-footer)     ; alternatively (long-slide-footer)
                                                   (empty-slide-footer)))
                 (slide-end-marker)))
        (body1 (if (> slide-page-offset 0) (indent-pixels slide-page-offset body) body))
       )
  (if java-scripting
   (page-with-keypress-script
    (as-string title)
    meta-contribution
    body1

    javascript-loading
    (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
    (js-call "lenoNavigate" 
      (append
       (map string-it-single 
         (list (if prev (slide-url lecture-id prev)  "")
               (if next (slide-url lecture-id next) "")
               (contents-url lecture-id)
               (note-url lecture-id (current-page))))
       (list (js-string-array down-links)) ))  ;@a

    slide-background-color black black black
    mouse-advancement
  )
  (page-1 
    (as-string title)
    meta-contribution
    body1
    slide-background-color black black black))))


(define (slide-end-marker)
  (a-name "slide-end"))

(define (slide-start-marker)
  (a-name "slide-start"))

; the header of a program slide. Contains a up navigation button
(define (program-header context-url explanation . optional-parameter-list)
 (let* ((next-in-show (optional-parameter 1 optional-parameter-list #f))
        (program-number (optional-parameter 2 optional-parameter-list 1))  ; not used yet
        (sound (speak-name lecture-id page-id 'program-part program-number))
       )
  (con 
     (if next-in-show    ; means show and speak
        (con
          (a-tag (html-file (program-name lecture-id page-id 'slide program-number)) 
	         (img-LN "atomspin.gif"  (text-choice "Stop afspilning med lyd" "Stop show with sound"))) 

          (space 2)
 
          (a-tag 
            next-in-show
            (img-LN "nav-right-red.gif" (key-shortcut (text-choice "Nste slide i dette show" "Next slide in show") "n")))

          (space 2))

        (con            ; non show and speak
         (if show-and-speak?
          (con
             (a-tag (html-file (program-name lecture-id page-id 'show program-number) ) 
   			     (img-LN "atomspin-freeze.gif" (text-choice "Afspil indtalte slides" "Play spoken slide show")))
             
             (space 2)
   
             (if (file-exists? (sound-file-path sound))
                 (a-tag (speak-url sound)
   	   		        (img-LN "speaker.gif" (text-choice "Afspil lyd p denne slide" "Play sound for this slide")))
                 (img-LN "speaker-empty.gif" ""))
            
             (space 2)
          )
          "")

          (a-tag context-url (img-LN "nav-up.gif" explanation)) 

        )
     )
)))


(define (exercise-slide-header context-url explanation number exercise-title)
  (con
    (if exercise-index? 
        (a-tag (html-file (exercise-index-name lecture-id)) 
               (img-LN "nav-up.gif" 
                       (text-choice "Opgaver i denne lektion" "Exercises in this lecture")))
        (img-LN "nav-up-empty.gif" "")) (space 2)

    (a-tag context-url (img-LN "nav-slide.gif" explanation)) (space 2)

    (if annotator-support?
            (let ((number-of-annotations-now (length (list-of-submitted-annotations "oop-exercises" (as-string current-exercise-id)))))
             (con
              (a-tag
               (annotator-url "annotator.cgi"
                  (list 'annotation-id 'detail-level 'activation-mode 'language 'informative-title 'back-url)
                  (list (encode-annotation-ids (list (as-string annotator-symbol) "exercises" (as-string current-exercise-id)))
                        "flat" "present-only" language-preference exercise-title 
                        (course-absolute-url (string-append "html/noter/" (html-file (exercise-name lecture-id page-id 'note number)))))
               )
               (img-LN 
                 (if (> number-of-annotations-now 0) "exclamation-red-ring.gif" "exclamation.gif")
                 (text-choice "Ls eller indsend kommentarer om denne opgave" "Read or submit annotations to this exercise")
               )
              )
              (space 2)))
            "") 

))


(define (exercise-note-header context-url explanation number exercise-title)
 (let ((annotator-url-contr 
       (if annotator-support?
            (let ((number-of-annotations-now (length (list-of-submitted-annotations "oop-exercises" (as-string current-exercise-id)))))
             (con
              (a-tag
               (annotator-url "annotator.cgi"
                  (list 'annotation-id 'detail-level 'activation-mode 'language 'informative-title 'back-url)
                  (list (encode-annotation-ids (list (as-string annotator-symbol)  "exercises" (as-string current-exercise-id)))
                        "flat" "present-only" language-preference exercise-title 
                        (course-absolute-url (string-append "html/noter/" (html-file (exercise-name lecture-id page-id 'note number)))))
               )
               (img-LN 
                 (if (> number-of-annotations-now 0) "exclamation-red-ring.gif" "exclamation.gif")
                 (text-choice "Ls eller indsend kommentarer om denne opgave" "Read or submit annotations to this exercise")
               )
              )
              (space 3)))
            "")))
  (if (frame-exercises?)
      (con
       (if exercise-index? 
	   (a-tag-target
                  (html-file (exercise-index-name lecture-id)) 
		  (img-LN "nav-up.gif" 
			  (text-choice "Opgaver i denne lektion" "Exercises in this lecture"))
                  "_top"
                  )
	 (img-LN "nav-up-empty.gif" "")) (space 3)
       (a-tag-target context-url (img-LN "nav-notes.gif" explanation) "_top")  (space 3)
       annotator-url-contr
       (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index"))) (space 3)
       (a-tag-target course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home")) "_top") (space 3)
       (if distance-education-support?  ; idafus
           (a-tag-target (idafus-url "student-part/contribution-frameset.cgi" (list "unit-id" "activity-id") (list idafus-unit-id current-exercise-id)) "IDAFUS" "idafus")
           "") (space 3)
      )
    (con
     (if exercise-index? 
	 (a-tag (html-file (exercise-index-name lecture-id)) 
		(img-LN "nav-up.gif" 
			(text-choice "Opgaver i denne lektion" "Exercises in this lecture")))
       (img-LN "nav-up-empty.gif" "")) (space 3)
     (a-tag context-url (img-LN "nav-notes.gif" explanation)) (space 3)
     annotator-url-contr
     (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index"))) (space 3)
     (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 3)
     (if distance-education-support?  ; idafus
         (a-tag-target (idafus-url "idafus.cgi" (list "unit-id" "activity-id") (list idafus-unit-id current-exercise-id)) "IDAFUS" "idafus")
         "") (space 3)
     )

)))

(define (exercise-solution-header context-url explanation number exercise-title)
 (let ((annotator-url-contr 
       (if annotator-support?
            (let ((number-of-annotations-now (length (list-of-submitted-annotations "oop-exercise-solutions" (as-string current-exercise-id)))))
             (con
              (a-tag
               (annotator-url "annotator.cgi"
                  (list 'annotation-id 'detail-level 'activation-mode 'language 'informative-title 'back-url)
                  (list (encode-annotation-ids (list (as-string annotator-symbol) "exercise-solutions" (as-string current-exercise-id)))
                        "flat" "present-only" language-preference exercise-title 
                        (course-absolute-url (string-append "html/noter/" (html-file (exercise-solution-name lecture-id page-id number)))))
               )
               (img-LN 
                 (if (> number-of-annotations-now 0) "exclamation-red-ring.gif" "exclamation.gif")
                 (text-choice "Ls eller indsend kommentarer om denne opgave lsning" "Read or submit annotations to the solution of this exercise")
               )
              )
              (space 3)))
            "")))
  (if (frame-exercises?)
      (con
       (if exercise-index? 
	   (a-tag-target 
                  (html-file (exercise-index-name lecture-id)) 
		  (img-LN "nav-up.gif" 
			  (text-choice "Opgaver i denne lektion" "Exercises in this lecture"))
                  "_top")
	 (img-LN "nav-up-empty.gif" "")) (space 3)
       (a-tag-target context-url (img-LN "nav-notes.gif" explanation) "_top")  (space 3)
       annotator-url-contr
       (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index"))) (space 3)
       (a-tag-target course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home")) "_top") (space 3)
      )
    (con
     (if exercise-index? 
	 (a-tag (html-file (exercise-index-name lecture-id)) 
		(img-LN "nav-up.gif" 
			(text-choice "Opgaver i denne lektion" "Exercises in this lecture")))
       (img-LN "nav-up-empty.gif" "")) (space 3)
     (a-tag context-url (img-LN "nav-notes.gif" explanation)) (space 3)
     annotator-url-contr
     (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index"))) (space 3)
     (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 3)
     ))))

; old and obsolete
(define (word-index-header)
   (a-tag (contents-url lecture-id) (img-0 (image-file "nav-up.gif"))))

(define (word-index-header)
   (if front-index?
      (a-tag (front-index-url) (img-LN "nav-up.gif" (text-choice "G til lektionsliste" "Navigate to list of lectures")) )
      (img-LN "nav-up-empty.gif" ""))  
)

(define (exercise-index-header)
 (con
   (a-tag (html-file overall-exercise-index-name) 
          (img-LN "nav-up.gif" (text-choice "G til oversigt over alle opgaver i noterne" 
                                            "Navigate to overview of all exercises in these notes"))
   ) (space 3)
   (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index"))) (space 3)
   (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 3)
 )
)

(define (all-exercise-page-header)
 (con
   (a-tag (html-file (exercise-index-name lecture-id)) 
               (img-LN "nav-up.gif" 
                       (text-choice "Index over opgaver i denne lektion" "Exercise index of this lecture")))
   (space 3)
   (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index"))) (space 3)
   (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 3)
  )
)

(define (overall-exercise-index-header)
 (con
   (a-tag (front-index-url) (img-LN "nav-up.gif" (text-choice "G til lektionsliste" "Navigate to list of lectures"))) (space 3)
   (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index"))) (space 3)
   (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 3)
 )
)

(define (front-index-header)
 (con
   (img-LN "nav-up-empty.gif" "") (space 2)

   (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 2)
    
   (if (not (equal? note-download-url ""))
       (a-tag note-download-url (img-LN "todisk.gif" (text-choice "Download noter" "Download notes (zip file)")))
       (space 3))   (space 2)

   (if word-index? 
       (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index")))
       (space 3))

   (space 2)

   (a-tag about-laml-url (img-LN "question.gif" (text-choice "Hjlp om disse noter" "Help page about these notes"))) (space 2)

   (if exercise-index? 
       (con (a-tag (html-file overall-exercise-index-name) (img-LN "think.gif" (text-choice "Opgave oversigt" "Exercise index"))) (space 2))
       (space 3))
   
   (no-frames-button (html-file top-level-note-file-name))

   (br)
 ))   
  

(define (index-page-header)
  (header-banner
   (con (if front-index? 
            (a-tag (front-index-url) (img-LN "nav-up.gif" 
                                             (key-shortcut (text-choice "G til lektionsliste" "Navigate to list of lectures") "u")))
            (img-LN "nav-up-empty.gif" ""))

        (space 2)
        (if previous-lecture
            (a-tag (contents-url previous-lecture)
                   (img-LN "nav-left.gif" (key-shortcut (text-choice "Forrige lektion" "Previous lecture") "p")) )
            (img-LN "nav-left-empty.gif" "")) (space 2)
        (if next-lecture
            (a-tag (contents-url next-lecture)  (img-LN "nav-right.gif" (key-shortcut (text-choice "Nste lektion" "Next lecture") "n")) )
            (img-LN "nav-right-empty.gif" "")) (space 2)
        (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 2)

        (if annotator-support?
            (let ((number-of-annotations-now (length (list-of-submitted-annotations "oop" (as-string lecture-id)))))
             (con
              (a-tag
               (annotator-url "annotator.cgi"
                  (list 'annotation-id 'detail-level 'activation-mode 'language 'informative-title 'back-url)
                  (list (encode-annotation-ids (list (as-string annotator-symbol)  (as-string lecture-id)))
                        "flat" "present-only" language-preference lecture-title 
                        (course-absolute-url (string-append "html/noter/" (html-file (book-name lecture-id)))))
               )
               (img-LN 
                 (if (> number-of-annotations-now 0) "exclamation-red-ring.gif" "exclamation.gif")
                 (text-choice "Ls eller indsend kommentarer om denne lektion" "Read or submit annotations to this lecture")
               )
              )
              (space 2)))
            "")

        (if word-index? 
            (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index")))
            (space 3))

        (space 2)
        (a-tag about-laml-url (img-LN "question.gif" (text-choice "Hjlp om disse noter" "Help page about these notes")))

        (space 2)
        (no-frames-button (html-file lecture-id))

        (br)
   )

   (if (and lecture-number (> (length lecture-list) 1))
       (b (con (text-choice "Lektion " "Lecture ") (as-string lecture-number) ))
       "")

   (list 360 600 280)

 ))


   
; Return a slide header banner. Context is either slide og show-and-speak (a symbol).
(define (slide-header context . optional-parameter-list)
  (let* ((next-in-show (optional-parameter 1 optional-parameter-list #f))
         (prev (previous-page))
         (next (next-page))
        )
    (header-banner
      (con
        (if show-and-speak?
            (con
             (cond ((eq? context 'slide)       
                      (a-tag (html-file (show-and-speak-slide-name lecture-id page-id 1)) 
			     (img-LN "atomspin-freeze.gif" (text-choice "Afspil indtalte slides" "Play spoken slide show"))))
		   ((eq? context 'show-and-speak)
		      (a-tag (html-file (slide-name lecture-id page-id)) 
				    (img-LN "atomspin.gif"  (text-choice "Stop afspilning med lyd" "Stop show with sound"))))
		   (else ""))
              (space 2))
            "")


        (if (and (eq? context 'show-and-speak) next-in-show)
            (con
             (a-tag 
               next-in-show
               (img-LN "nav-right-red.gif" (key-shortcut (text-choice "Nste slide i dette show" "Next slide in show") "n")))
             (space 2))
             "")

        (if (eq? context 'slide)
            (con
        
	     (a-tag (string-append (as-string lecture-id) ".html")
		    (img-LN  "nav-up.gif" (key-shortcut (text-choice "Lektionsindhold" "Lecture overview") "u"))) (space 2)

	     (cond ((eq? context 'slide)
		    (if prev (a-tag (string-append (slide-name lecture-id prev) ".html")
				    (img-LN "nav-left.gif" 
					    (key-shortcut (text-choice "Forrige slide i denne lektion" "Previous slide in this lecture") "p")))
		      (img-LN "nav-left-empty.gif" "")))
		   ((eq? context 'show-and-speak)
		    (if prev (a-tag (string-append (show-and-speak-slide-name lecture-id prev 1) ".html")
				    (img-LN "nav-left.gif" 
					    (key-shortcut (text-choice "Forrige slide i denne lektion" "Previous slide in this lecture") "p")))
		      (img-LN "nav-left-empty.gif" "")))
		   (else "")
		   )

	     (space 2)

	     (cond ((eq? context 'slide)       
		    (if next (a-tag (string-append (slide-name lecture-id next) ".html") 
				    (img-LN "nav-right.gif" (key-shortcut (text-choice "Nste slide i denne lektion" "Next slide in this lecture") "n")))
		      (img-LN "nav-right-empty.gif" "")))
		   ((eq? context 'show-and-speak)
		    (if next (a-tag (string-append (show-and-speak-slide-name lecture-id next 1) ".html") 
				    (img-LN "nav-right.gif" (key-shortcut (text-choice "Nste slide i denne lektion" "Next slide in this lecture") "n")))
		      (img-LN "nav-right-empty.gif" "")))
		   (else ""))

	     (space 2)

	     (a-tag (book-url lecture-id (current-page))
		    (img-LN "nav-book.gif" 
			    (text-choice "Forelsningsnoter - alle slides og noter sammen"
					 "Lecture notes - all slides and notes together")))
	     (space 2)
	     (a-tag (note-url lecture-id (current-page))
		    (img-LN "nav-notes.gif" (key-shortcut (text-choice "Annoteret slide" "Annotated slide") "t"))) (space 2)

	     (if word-index? 
		 (a-tag (all-word-index-url lecture-id) (img-LN "index.gif"(text-choice "Alfabetisk indeks" "Alphabetic index")))
	       (space 3)) (space 2)

	     (a-tag about-laml-url (img-LN "question.gif" (text-choice "Hjlp om disse noter" "Help page about these notes"))) (space 2)

	     (if annotator-support?
		 (let ((number-of-annotations-now (length (list-of-submitted-annotations "oop" (as-string lecture-id) (as-string page-id)))))
		   (con
		    (a-tag
		     (annotator-url "annotator.cgi"
				    (list 'annotation-id 'detail-level 'activation-mode 'language 'informative-title 'back-url)
				    (list (encode-annotation-ids (list (as-string annotator-symbol) (as-string lecture-id) (as-string page-id)))
					  "flat" "present-only" language-preference page-title 
					  (course-absolute-url (string-append "html/noter/" (html-file (note-name lecture-id page-id)))))
				    )
		     (img-LN 
		      (if (> number-of-annotations-now 0) "exclamation-red-ring.gif" "exclamation.gif")
		      (text-choice "Ls eller indsend kommentarer om denne side" "Read or submit annotations to this page")
		      )
		     )
		    (space 2)))
	       "") 

	     (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 2)


	     (if show-and-speak?
                 (let ((sound (speak-name lecture-id page-id 'slide-part 1)))
  		  (con
  		  (cond ((eq? context 'slide)
 
                           (if (file-exists? (sound-file-path sound))
                               (a-tag (speak-url sound)
               	   		     (img-LN "speaker.gif" (text-choice "Afspil lyd p denne slide" "Play sound for this slide")))
                                     (img-LN "speaker-empty.gif" ""))
        
                         )
 
 			(else ""))
 		  (space 2)))
	       "")

	     (space 2)

	     (if (= page-number 1) (con (no-frames-button (html-file (slide-name lecture-id page-id))) (space 2)) "")


					;        (a-tag "#slide-end" (img-LN "arrow-down.gif" (text-choice "Til nederste del af siden" "To bottom of slide"))) (space 2)
	     (font-1 2 white (as-string page-id)))  ; hidden - for copying by knowledgable users.
             ""
	  ))

     (if (and lecture-number (> (length lecture-list) 1))
       (b (con (text-choice "Lektion " "Lecture ") (as-string lecture-number) " - slide "
               (as-string page-number) " : " (as-string (total-number-of-slides))))
       (b (con 
;            (font-color slide-background-color (con (text-choice "Lektion - " "Lecture - ") (as-string 0))) ; suppress it
            "Slide " (as-string page-number) " : " (as-string (total-number-of-slides)) )))

     (list 360 700 280))))

(define (minimal-slide-header)
  (font-1 2 grey1 
	(con
	 (if lecture-number 
	     (con (text-choice "Lektion " "Lecture ") (as-string lecture-number) " - ")
	     "")
	 "Slide " (as-string page-number) " : " (as-string (total-number-of-slides))
	 )))


(define (header-banner left right layout-list)
 (left-right-banner left right))

;(define (header-banner left right layout-list)
; (table-3 0 layout-list 
;    (list
;       (list left "" right))))

(define (slide-header-topbar)
  (let* ((prev (previous-page))
         (next (next-page))
        )
    (table-3 0 (list 360 700 280)
     (list 
      (list
       (con 
        (a-tag-target (string-append (as-string lecture-id) ".html")
                        (img-LN  "nav-up.gif" (text-choice "Lektions indhold" "Lecture overview")) "_top") (space 2)
        (if prev (a-tag-target (string-append (slide-name lecture-id prev) ".html")
                        (img-LN "nav-left.gif" (text-choice "Forrige side" "Previous page")) "_top") (img-LN "nav-left-empty.gif" "")) (space 2) 
        (if next (a-tag-target (string-append (slide-name lecture-id next) ".html") 
                        (img-LN "nav-right.gif" (text-choice "Nste side" "Next page")) "_top") (img-LN "nav-right-empty.gif" "")) (space 2)
        (a-tag-target (string-append (slide-name-0 lecture-id (current-page)) ".html" "#slide-end")
                      (img-LN "arrow-down.gif" (text-choice "Til nederste del af siden" "To bottom of slide")) "main") (space 2)
        (a-tag-target (book-url lecture-id (current-page))
                        (img-LN "nav-book.gif" (text-choice "Forelsningsnoter - alle sider sammen" "Lecture notes - all slides and notes together")) "_top") (space 2)
        (a-tag-target (note-url lecture-id (current-page))
                        (img-LN "nav-notes.gif" (text-choice "annoteret slide" "annotated slide")) "_top") (space 2)
        (if word-index? 
           (a-tag-target (all-word-index-url lecture-id) (img-LN "index.gif"(text-choice "Alfabetisk indeks" "Alphabetic index")) "_top")
           (space 3))

        (space 2)
        (a-tag-target course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home")) "_top") (space 2)
        (font-1 2 white (as-string page-id))  ; hidden - for copying by knowledgable users.
       )
     ""
     (if lecture-number
       (b (con (text-choice "Lektion " "Lecture ") (as-string lecture-number) " - slide " (as-string page-number) " : " (as-string (total-number-of-slides))))
       (b (con (font-color slide-background-color (con (text-choice "Lektion - " "Lecture - ") (as-string 0)))  ; suppress it
               "Slide " (as-string page-number) " : " (as-string (total-number-of-slides)) )))     )))
  ))

(define (old-slide-footer)
  (let* ((dt (date-time (current-time)))
         (date (car dt))
         (time (cadr dt))
         (prev (previous-page))
         (next (next-page))
         (cur (current-page)))
    (con (vertical-space 1)
         (b (con "Slide " (as-string page-number))) (space 3)
         (if prev (a-tag (string-append (slide-name lecture-id prev) ".html") "Previous") "") (if prev (space 3) "")
         (if next (a-tag (string-append (slide-name lecture-id next) ".html") "Next") "") (space 3)
         (if cur (a-tag (string-append (note-name lecture-id (current-page)) ".html") "Notes") "") (space 3)
         (a-tag (string-append (book-name lecture-id) ".html" "#" (as-string page-id)) "Chapter tutorial") (space 3)
         (a-tag-target course-home-url "Course home" "_top") (space 3)
         (a-tag (string-append (as-string lecture-id) ".html") "Index") (space 3)
         (a-tag about-laml-url "About the production of this web")
         (br)
         (font-1 2 red (con (text-choice "Genereret: " "Generated: ") date ", " time)) )))

(define (long-slide-footer)
    (let* ((prev (previous-page))
         (next (next-page)))
    (table-3 0 (list 200 1000 225)
     (list 
      (list
       (con 
        (a-tag (string-append (as-string lecture-id) ".html")
                        (img-LN  "nav-up.gif" (text-choice "Lektions indhold" "Lecture overview") )) (space 2)
        (if prev (a-tag (string-append (slide-name lecture-id prev) ".html")
                        (img-LN "nav-left.gif" (text-choice "Forrige slide" "Previous slide")))(img-LN "nav-left-empty.gif" "")) (space 2) 
        (if next (a-tag (string-append (slide-name lecture-id next) ".html") 
                        (img-LN "nav-right.gif" (text-choice "Nste slide" "Next slide"))) (img-LN "nav-right-empty.gif" "")) (space 2)
        (a-tag "#slide-start" (img-LN "arrow-up.gif" (text-choice "Til verste del af slide" "To top of slide"))) (space 2)
        (a-tag (book-url lecture-id (current-page))
                        (img-LN "nav-book.gif" (text-choice "Forelsningsnoter - alle sider sammen" "Lecture notes - all slides and notes together"))) (space 2)
        (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home")))
       )
     ""
     (if lecture-number
       (b (con (text-choice "Lektion " "Lecture ") (as-string lecture-number) " - slide " (as-string page-number) " : " (as-string (total-number-of-slides))))
       (b (con (font-color slide-background-color (con (text-choice "Lektion - " "Lecture - ") (as-string 0))) ; suppress it
               "Slide " (as-string page-number) " : " (as-string (total-number-of-slides)) )))     )))
  ))

(define (empty-slide-footer) "")

(define (note-header)
  (let* ((prev (previous-page))
         (next (next-page)))
   (presentation-slice
    (left-right-banner
      (con 
            (a-tag (string-append (as-string lecture-id) ".html")
                             (img-LN  "nav-up.gif" (key-shortcut (text-choice "Lektions indhold" "Lecture overview") "u"))) (space 2)
            (if prev (a-tag (string-append (note-name lecture-id prev) ".html")
                        (img-LN "nav-left.gif" (key-shortcut (text-choice "Forrige side" "Previous page") "p"))) (img-LN "nav-left-empty.gif" "")) (space 2) 
            (if next (a-tag (string-append (note-name lecture-id next) ".html") 
                        (img-LN "nav-right.gif" (key-shortcut (text-choice "Nste side" "Next page") "n"))) (img-LN "nav-right-empty.gif" ""))  (space 2)
            (a-tag (book-url lecture-id (current-page))
                        (img-LN "nav-book.gif" (text-choice "Forelsningsnoter - alle sider sammen" "Lecture notes - all slides and notes together"))) (space 2)
            (a-tag (slide-url lecture-id (current-page))
                        (img-LN "nav-slide.gif" (key-shortcut (text-choice "slide" "slide") "t"))) (space 2)

            (a-tag about-laml-url (img-LN "question.gif" (text-choice "Hjlp om disse noter" "Help page about these notes"))) (space 2)

            (if annotator-support?
            (let ((number-of-annotations-now (length (list-of-submitted-annotations "oop" (as-string lecture-id) (as-string page-id)))))
             (con
              (a-tag
               (annotator-url "annotator.cgi"
                  (list 'annotation-id 'detail-level 'activation-mode 'language 'informative-title 'back-url)
                  (list (encode-annotation-ids (list (as-string annotator-symbol) (as-string lecture-id) (as-string page-id)))
                        "flat" "present-only" language-preference page-title 
                        (course-absolute-url (string-append "html/noter/" (html-file (note-name lecture-id page-id)))))
               )
               (img-LN 
                 (if (> number-of-annotations-now 0) "exclamation-red-ring.gif" "exclamation.gif")
                 (text-choice "Ls eller indsend kommentarer om denne side" "Read or submit annotations to this page")
               )
              )
              (space 2)))
            "")

            (if word-index? 
              (a-tag (all-word-index-url lecture-id) (img-LN "index.gif" (text-choice "Alfabetisk indeks" "Alphabetic index")))
            (space 3)) (space 2)
            (a-tag course-home-url (img-LN "nav-home.gif" (text-choice "Kurset's hjemmeside" "Course home"))) (space 2)
        )
     (if (and lecture-number (> (length lecture-list) 1))
       (b (con (text-choice "Lektion " "Lecture ") (as-string lecture-number) " - slide " (as-string page-number) " : " (as-string (total-number-of-slides))))
       (b (con "Slide " (as-string page-number) " : " (as-string (total-number-of-slides)) ))) )
    "")
  ))


(define (note-footer)
 (let* ((dt (date-time (current-time)))
        (date (car dt))
        (time (cadr dt))
        (prev (previous-page))
        (next (next-page))
        (cur (current-page)))
 (con (vertical-space 1)
   (b (con (text-choice "Side " "Page ") (as-string page-number))) (space 3)
   (if prev (a-tag (string-append (note-name lecture-id prev) ".html") (text-choice "Forrige" "Previous")) "") (if prev (space 3) "")
   (if next (a-tag (string-append (note-name lecture-id next) ".html") (text-choice "Nste" "Next")) "") (space 3)
   (if cur (a-tag (string-append (slide-name lecture-id (current-page)) ".html") "Slide") "") (space 3)
   (a-tag (string-append (book-name lecture-id) ".html" "#" (as-string page-id)) (text-choice "Forelsningsnoter" "Lecture notes")) (space 3)
   (a-tag course-home-url (text-choice "Kurset's hjemmeside" "Course home")) (space 3)  ; ???
   (a-tag (string-append (as-string lecture-id) ".html") (text-choice "Indeks" "Index")) (space 3)
   (a-tag about-laml-url (text-choice "Om frembringelsen af disse sider" "About producing this web") )
   (br) (font-1 2 red (con (text-choice "Genereret: " "Generated: ") date ", " time)) )))


(define (book-footer)
 (let* ((dt (date-time (current-time)))
        (date (car dt))
        (time (cadr dt)))
 (font-size 2
  (con 
   (vertical-space 1)
   (if (and lecture-number (number? lecture-number) (> (length lecture-list) 1))
       (i (con (text-choice "Kapitel" "Chapter") " " (as-string lecture-number) ": " lecture-title))
       (i  lecture-title))
   (br)  
   (a-tag course-home-url (text-choice "Kurset's hjemmeside" "Course home")) (space 5)
   (a-tag author-home-url (text-choice "Forfatteren's hjemmeside" "Author home")) (space 5)
   (a-tag about-laml-url (text-choice "Om frembringelsen af disse sider" "About producing this web")) (space 5)
   (if previous-lecture
       (a-tag (book-url previous-lecture) (text-choice "Forrige lektion (top)" "Previous lecture (top)"))
       (font-color white (text-choice "Forrige lektion (top)" "Previous lecture (top)"))) (space 5)
   (if next-lecture
       (a-tag (book-url next-lecture) (text-choice "Nste lektion (top)" "Next lecture (top)"))
       (font-color white (text-choice "Nste lektion (top)" "Next lecture (top)"))) (space 5)
   (if previous-lecture
       (a-tag (book-url previous-lecture "BOTTOM") (text-choice "Forrige lektion (bund)" "Previous lecture (bund)"))
       (font-color white (text-choice "Forrige lektion (bund)" "Previous lecture (bund)"))) (space 5)
   (if next-lecture
       (a-tag (book-url next-lecture "BOTTOM") (text-choice "Nste lektion (bund)" "Next lecture (bund)"))
       (font-color white (text-choice "Nste lektion (bund)" "Next lecture (bund)"))) (space 5)
   (br) (font-1 2 red (con (text-choice "Genereret: " "Generated: ") date ", " time))
   (a-name "BOTTOM") ))))




(define (standard-note title contents keywords-to-meta down-links)
 (let ((meta-contribution (if (null? keywords-to-meta) 
                              '()
                              (list (list 'name "keywords" 
                                  'lang (meta-language language-preference)
                                  'content (comma-separated-string keywords-to-meta)))))
       (body (con 
               (note-header)
               contents
               ; (note-footer)
             ))
       (prev (if (previous-page) (previous-page) #f))
       (next (if (next-page) (next-page) #f))
      )
   (if java-scripting
    (page-with-keypress-script
      (as-string title) 
      meta-contribution
      body

      javascript-loading
      (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
      (js-call "lenoNavigate" 
       (append
        (map string-it-single 
         (list (if prev (note-url lecture-id prev)  "")
               (if next (note-url lecture-id next) "")
               (contents-url lecture-id)
               (slide-url lecture-id (current-page))))
       (list (js-string-array down-links))))

      note-background-color black black black
      mouse-advancement
    )
    (page-1 
      (as-string title) 
      meta-contribution
      body
      note-background-color black black black))))


;-----------------------------------------------------------------------------

; keyword handling

; Element constructors:

(define possible-leno-elements 
  '(title  point  point  items  item  text  program  source-program  image  concepts  example  opposing  
    comment  syntax  slide-space  tabular  note-text  slide-text  cross-references  exercise  formulation
    solution  long-slide  index-words  image-series  section-title slide-image  concept-list  concept  
    applet-program  synopsis  synopsis-item  quotation  quiz  question  answers  answer  show-and-speak 
    lecturer-photos lecturer-photos-and-logo))


; Make an element in which the first element of rest is allowed to by an id symbol.
(define (make-element-optional-id tag rest)
  (cond ((null? rest) (make-element tag #f '()))
        ((symbol? (car rest)) (make-element tag (car rest) (cdr rest)))  
        ((not (symbol? (car rest))) (make-element tag #f rest))))

; Make an element in which the first element of rest is required to by an id symbol.
; The element will duplicate the id to both the id field and the first element of the contents.
(define (make-element-required-id tag rest)
  (cond ((null? rest) (error (string-append "An element with required id is not allowed to have empty rest: " (as-string tag))))
        ((symbol? (car rest)) (make-element tag (car rest) rest))
        (else (error (string-append "An element with required must have an id symbol as first constituent of rest: " (as-string tag))))))

(define make-old-style-element cons)



(define (make-element tag id contents)
  (list tag id contents))

(define element-tag car)
(define element-contents caddr)
(define element-id cadr)

(define (keyword-parameter key par-list)
 (let ((res (assq key par-list)))
   (if res (cdr res) "")))


(define (title . t) (make-element-optional-id 'title t))
(define (point . p) (make-element-optional-id 'point p))
(define (point . p) (make-element-optional-id 'point p))
(define (items . i) (make-element-optional-id 'items i))
(define (item . i) (make-element-optional-id 'item i))
(define (text . i) (make-element-optional-id 'text i))
(define (program . p) (make-element-optional-id 'program p))
(define (source-program . p) (make-element-optional-id 'source-program p))
(define (image . p) (make-element-optional-id 'image p))
(define (concepts . p) (make-element-optional-id 'concepts p))  ; now use concept-list
(define (example . p) (make-element-optional-id 'example p))
(define (opposing . p) (make-element-optional-id 'opposing p))
(define (comment . p) (make-element-optional-id 'comment p))
(define (syntax . p) (make-element-optional-id 'syntax p))
(define (slide-space . p) (make-element-optional-id 'slide-space p))
(define (tabular . p) (make-element-optional-id 'tabular p))
(define (note-text . p) (make-element-optional-id 'note-text p))
(define (slide-text . p) (make-element-optional-id 'slide-text p))
(define (cross-references . p) (make-element-optional-id 'cross-references p))
(define (exercise . p) (make-element-required-id 'exercise p))
(define (formulation . p) (make-element-optional-id 'formulation p))
(define (solution . p) (make-element-optional-id 'solution p))
(define (long-slide . p) (make-element-optional-id 'long-slide p))
(define (index-words . p) (make-element-optional-id 'index-words p))
(define (image-series . p) (make-element-optional-id 'image-series p))
(define (section-title . p) (make-element-optional-id 'section-title p))
(define (slide-image . p) (make-element-optional-id 'slide-image p))
(define (concept-list . p) (make-element-optional-id 'concept-list p))
(define (concept . p) (make-element-optional-id 'concept p))
(define (applet-program . p) (make-element-optional-id 'applet-program p))
(define (synopsis . p) (make-element-optional-id 'synopsis p))
(define (synopsis-item . p) (make-element-optional-id 'synopsis-item p))
(define (quotation . p) (make-element-optional-id 'quotation p))
(define (quiz . p) (make-element-optional-id 'quiz p))
(define (question . p) (make-element-optional-id 'question p))
(define (answers . p) (make-element-optional-id 'answers p))
(define (answer . p) (make-element-optional-id 'answer p))
(define (show-and-speak . p) (make-element-optional-id 'show-and-speak p))
(define (slide-part . p) (make-old-style-element 'slide-part p))              ; without possibility of id
(define (program-part . p) (make-old-style-element 'program-part p))
(define (exercise-part . p) (make-old-style-element 'exercise-part p))
(define (image-series-part . p) (make-old-style-element 'image-series-part p))
(define (lecturer-photos . p) (make-element-optional-id 'lecturer-photos p))
(define (lecturer-photos-and-logo . p) (make-element-optional-id 'lecturer-photos-and-logo p))
(define (elucidate . p) (make-element-optional-id 'elucidate p))
;-----------------------------------------------------------------------------

; dispatching function;

(define (find-processor style kind)
  ; return function given the symbols style and kind
 (cond ((eq? style 'slide-style)
        (cond ((eq? kind 'title) slide-style-title)
              ((eq? kind 'text) slide-style-text)
              ((eq? kind 'items) slide-style-items)
              ((eq? kind 'point) slide-style-point)
              ((eq? kind 'program) slide-style-program)
              ((eq? kind 'source-program) slide-style-source-program)
              ((eq? kind 'image) slide-style-image)
              ((eq? kind 'concepts) slide-style-concepts)
              ((eq? kind 'example) slide-style-example)
              ((eq? kind 'opposing) slide-style-opposing)
              ((eq? kind 'comment) slide-style-comment)
              ((eq? kind 'syntax) slide-style-syntax)
              ((eq? kind 'slide-space) slide-style-slide-space)
              ((eq? kind 'tabular) slide-style-tabular)
              ((eq? kind 'note-text) slide-style-note-text)
              ((eq? kind 'slide-text) slide-style-slide-text)
              ((eq? kind 'cross-references) slide-style-cross-references)
              ((eq? kind 'exercise) slide-style-exercise)
              ((eq? kind 'long-slide) empty-slide-element)
              ((eq? kind 'index-words) slide-style-index-words)
              ((eq? kind 'image-series) slide-style-image-series)
              ((eq? kind 'section-title) slide-style-section-title)
              ((eq? kind 'slide-image) slide-style-slide-image)
              ((eq? kind 'concept-list) slide-style-concept-list)
              ((eq? kind 'applet-program) slide-style-applet-program)
              ((eq? kind 'synopsis) slide-style-synopsis)
              ((eq? kind 'quotation) slide-style-quotation)
              ((eq? kind 'quiz) slide-style-quiz)
              ((eq? kind 'show-and-speak) slide-style-show-and-speak)
              ((eq? kind 'lecturer-photos) slide-style-lecturer-photos)
              ((eq? kind 'lecturer-photos-and-logo) empty-slide-element)  ; slide-style-lecturer-photos-and-logo
              ((eq? kind 'elucidate) slide-style-elucidate)
              (else (error (string-append "Cannot find slide processor function: " (as-string kind))))))
       ((eq? style 'note-style)
        (cond ((eq? kind 'title) note-style-title)
              ((eq? kind 'text) note-style-text)
              ((eq? kind 'items) note-style-items)
              ((eq? kind 'point) note-style-point)
              ((eq? kind 'program) note-style-program)
              ((eq? kind 'source-program) note-style-source-program)
              ((eq? kind 'image) note-style-image)
              ((eq? kind 'concepts) note-style-concepts)
              ((eq? kind 'example) note-style-example)
              ((eq? kind 'opposing) note-style-opposing)
              ((eq? kind 'comment) note-style-comment)
              ((eq? kind 'syntax) note-style-syntax)
              ((eq? kind 'slide-space) note-style-slide-space)
              ((eq? kind 'tabular) note-style-tabular)
              ((eq? kind 'note-text) note-style-note-text)
              ((eq? kind 'slide-text) empty-slide-element)
              ((eq? kind 'cross-references) note-style-cross-references)
              ((eq? kind 'exercise) note-style-exercise)
              ((eq? kind 'long-slide) empty-slide-element)
              ((eq? kind 'index-words) empty-slide-element)
              ((eq? kind 'image-series) note-style-image-series)
              ((eq? kind 'section-title) note-style-section-title)
              ((eq? kind 'slide-image) note-style-slide-image)
              ((eq? kind 'concept-list) note-style-concept-list)
              ((eq? kind 'applet-program) note-style-applet-program)
              ((eq? kind 'synopsis) note-style-synopsis)
              ((eq? kind 'quotation) note-style-quotation)
              ((eq? kind 'quiz) empty-slide-element)
              ((eq? kind 'show-and-speak) empty-slide-element)
              ((eq? kind 'lecturer-photos) empty-slide-element)
              ((eq? kind 'lecturer-photos-and-logo) empty-slide-element)
              ((eq? kind 'elucidate) note-style-elucidate)
              (else (error (string-append "Cannot find note processor function: " (as-string kind))))))
       ((eq? style 'book-style)
        (cond ((eq? kind 'title) book-style-title)
              ((eq? kind 'text) book-style-text)
              ((eq? kind 'items) book-style-items)
              ((eq? kind 'point) book-style-point)
              ((eq? kind 'program) book-style-program)
              ((eq? kind 'source-program) book-style-source-program)
              ((eq? kind 'image) book-style-image)
              ((eq? kind 'concepts) book-style-concepts)
              ((eq? kind 'example) book-style-example)
              ((eq? kind 'opposing) book-style-opposing)
              ((eq? kind 'comment) book-style-comment)
              ((eq? kind 'syntax) book-style-syntax)
              ((eq? kind 'slide-space) empty-slide-element)
              ((eq? kind 'tabular) book-style-tabular)
              ((eq? kind 'note-text) book-style-note-text)
              ((eq? kind 'slide-text) empty-slide-element)
              ((eq? kind 'cross-references) book-style-cross-references)
              ((eq? kind 'exercise) book-style-exercise)
              ((eq? kind 'long-slide) empty-slide-element)
              ((eq? kind 'index-words) empty-slide-element)
              ((eq? kind 'image-series) book-style-image-series)
              ((eq? kind 'section-title) book-style-section-title)
              ((eq? kind 'slide-image) empty-slide-element)
              ((eq? kind 'concept-list) book-style-concept-list)
              ((eq? kind 'applet-program) book-style-applet-program)
              ((eq? kind 'synopsis) book-style-synopsis)
              ((eq? kind 'quotation) book-style-quotation)
              ((eq? kind 'quiz) empty-slide-element)
              ((eq? kind 'show-and-speak) empty-slide-element)
              ((eq? kind 'lecturer-photos) empty-slide-element)
              ((eq? kind 'lecturer-photos-and-logo) empty-slide-element)
              ((eq? kind 'elucidate) book-style-elucidate)
              (else (error (string-append "Cannot find book processor function: " (as-string kind))))))
       (else (error "Cannot find slide or note or book ... style"))))




;-----------------------------------------------------------------------------

(define (as-slide-text txt)
  (font-size slide-font-size txt))

(define (note-text-left txt)
  (font-size note-font-size-left txt))

(define (note-text-right txt)
  (font-1 note-font-size-right note-foreground-color txt))

(define (book-text txt)
  (font-1 book-font-size book-foreground-color txt))

(define (expand-item i)
  ; return a triple (slide-item note-item sub-items)
 (cond ((string? i)                                                          
             (list i "" ""))
       ((and (pair? i) (eq? (element-tag i) 'item) (= (length (element-contents i)) 1))
             (list (car (element-contents i)) "" ""))
       ((and (pair? i) (eq? (element-tag i) 'item) (= (length (element-contents i)) 2))
             (list (car (element-contents i)) (cadr (element-contents i)) ""))
       ((and (pair? i) (eq? (element-tag i) 'item) (= (length (element-contents i)) 3))
           (list (car (element-contents i)) (cadr (element-contents i)) (caddr (element-contents i))))
       (else (error "Problems expanding slide or note item"))))

; extracts a slide item from i, and processes subitems recursively.
(define (slide-item i)
  (let* ((ei (expand-item i))
         (raw-sub-items (caddr ei)))
    (if (equal? "" (car ei))
        (display-warning "First parameter of an item is empty. Causes problems in some browsers"))
    (if (not (equal? raw-sub-items ""))
        (let ((sub-items (present-element 'slide-style  ; may in some contexts be note-style
                                          'items (element-contents raw-sub-items))))
           (con (car ei) (p) sub-items))
        (con (car ei) (p))
    )))

; includes item comments of level 1 and 2. Deeper item comments are ignored:    
(define (note-item i)  ; i may be a string or of the form (item "x" "y")
  (let* ((ei (expand-item i))
         (sub-comments (aggregate-comments (caddr ei))))
    (con (cadr ei) (p) sub-comments)))

(define (aggregate-comments itms)
  (cond  ((equal? "" itms) "")
         ((and (pair? itms) (eq? (car itms) 'items))
            (let* ((sub-items (element-contents itms))
                   (sub-items-1 (map expand-item sub-items)))
              (string-merge (map cadr sub-items-1) (make-list (length sub-items-1) (p)))))
         (else "")))

(define (program-extract program-file-name mark)
  ; Extract file portion based on file name and mark, which can be the empty string (extract entire file),
  ; a string (extract porition between identical start and end marks), or a list of length two, extract 
  ; string between and including potentially different start and end mark.

  (cond ((and (string? mark) (equal? mark "")) (read-text-file program-file-name))
        ((and (string? mark) (> (string-length mark) 0)) (read-text-file-between-marks program-file-name mark))
        ((and (pair? mark) (= (length mark) 2)) (read-text-file-including-marks program-file-name (car mark) (cadr mark)))
        (else (error "Problems in source program extraction"))))
                   
; -----------------------------------------------------------------------------      
; concept-list selectors:

(define concept-name car)
(define concept-description cadr)
(define concept-explanation caddr)

; -----------------------------------------------------------------------------      

; slide-style

(define (empty-slide-element . nt)
   "")

(define (slide-style-title . x)
 (let ((title (car x))
       (comment (if (> (length x) 1) (cadr x) "")))

  ; add title to index words:
  (if (not show-and-speak-context)
      (add-words-to-index (list title) (book-url lecture-id page-id) (slide-url lecture-id page-id) 'title))

  (con (font-1 7 title-color (b title)) (vertical-space 1))))


(define (slide-style-text . x)
 (let ((text (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
  (indent-pixels 10 (con (as-slide-text text) (vertical-space 1)))))

(define (slide-style-items . i)
  (ul-1 (map slide-item i)))

(define (slide-style-point . x)
 (let ((point (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
  (con (center-frame 30 (font-color red (as-slide-text point))) (vertical-space 1))))

(define (slide-style-program . x)
 (let ((program-text (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
  (indent-pixels 10 (con (as-slide-text (pre program-text)) (vertical-space 1)))))


(define (slide-style-source-program . x)
 ; Four required parameters: program-file-name, mark, color-description-triples, how-to-show
 (let* ((program-file-name (first x))
        (mark (second x))
        (colorizing (third x))
        (program-text (html-protect (program-extract program-file-name mark)))
        (colorized-program-text (colorize-substrings program-text colorizing)) 
        (how-to-show (fourth x))
        (comment (if (> (length x) 3) (fifth x) ""))
        (initial-sentence (first-sentence-in-string comment)))

  (set! list-of-source-files (cons program-file-name list-of-source-files))

  (if (eq? (car how-to-show) 'slide-inline)
      (center (box (con (as-slide-text (pre colorized-program-text)) (vertical-space 1)))) ; earlier: indent-pixels 15
      (let ((file-name (program-name lecture-id page-id 'slide program-number)) ;@a
            (this-number program-number)
           ) 
         (set! program-number (+ program-number 1)) ;@b
         (save-slide-program colorized-program-text file-name (slide-url lecture-id page-id) (slide-show-and-speak-url lecture-id page-id 1) this-number)
         (indent-pixels 10 
            (con
             (table-3 0 (list 100 900) 
               (list (list (a-tag (string-append file-name ".html") 
                                  (img-LN (program-icon-name language-preference 'large) program-file-name))
                           (font-color grey1 (b initial-sentence))))
               "middle")
             (vertical-space 1)))))))


; about the formatter third parameter to image: Either
; '(vertical picture)                 just show picture          DEFAULT
; '(vertical text)                    just show text
; '(vertical picture text)            show picuture above text
; '(vertical text picture)            show picture below text 
; '(horizontal text picture)          show picture to the right of text
; '(horizontal picture text)          show picture to the left of text
; only used in slide style.

(define (slide-style-image . x)
 (let ((image-file (car x))
       (comment (if (> (length x) 1) (cadr x) ""))
       (formatter (if (> (length x) 2) (caddr x) '(vertical picture)))
      )
  (if (not show-and-speak-context)
      (set! note-specific-graphics-files (cons image-file note-specific-graphics-files)))
  (cond ((eq? (car formatter) 'vertical) (vertical-slide-style-image image-file comment (cdr formatter)))
        ((eq? (car formatter) 'horizontal) (horizontal-slide-style-image image-file comment (cdr formatter)))
        (else (error "Problems in slide-style-image: First formatter element must be the symbol vertical or horizontal")))))

(define (vertical-slide-style-image image-file comment element-sequence)
  ;element sequence is a list of symbols: 'picture and/or 'text
 (con
  (apply
    string-append
    (map (lambda (formatting)
           (cond ((eq? formatting 'text) (con (center (as-slide-text comment)) (vertical-space 1)))
                 ((eq? formatting 'picture) (con (center (img-0 (string-append  "." "/" "graphics/" image-file))) (vertical-space 1)))
                 (else (error "Image formatter element must be either the symbol text or picture"))
           )
         )
         element-sequence
     ))
 ))

(define (horizontal-slide-style-image image-file comment element-sequence)
 (indent-pixels 10
 (con
   (cond ((equal? element-sequence '(picture text))
          (table-3 0 (list "47%" "6%" "47%")
             (list (list (center (img-0 (string-append  "." "/" "graphics/" image-file))) "" (as-slide-text comment))) "top"))
       ((equal? element-sequence '(text picture))
          (table-3 0 (list "47%" "6%" "47%")
             (list (list (as-slide-text comment) "" (center  (img-0 (string-append  "." "/" "graphics/" image-file))))) "top"))
       (else (error "Image formatter must be either (horizontal text picture) or (horizontal picture text)")))
   )))

(define (slide-style-example . x)
 (let ((the-example (car x))
       (about-the-example (if (> (length x) 1) (cadr x) "")))
   (indent-pixels 10
     (con (i (as-slide-text the-example)) (vertical-space 2)))))

(define (extra-space-after x) (con x (vertical-space 1)))


; Old colored dot version:
;(define (slide-style-concepts . x)
;  (con (indent-pixels 10 (bullet-list (map as-slide-text (map extra-space-after (map slide-item x))) 'large 'yellow))
;       (vertical-space 1)))

; html
(define (center-frame-color indentation color text)
  (center
   (narrow-with-pixels indentation
     (color-frame text color))))

; html
(define (make-color r g b) (list r g b))

(define concept-background  (make-color 6 22 96))

(define (slide-style-concepts . x)
  (con (center-frame-color 30 concept-background
         (apply string-append
             (map (lambda (x) (con (p) (font-color white x)))
                  (map as-slide-text (map slide-item x)))))
       (vertical-space 1)))



(define (slide-style-concept-list . x)
 ; x is a list of concept forms: ((concept . (- - -)) ...)
 (let ((real-concept-list (map element-contents x)))
  (if (not show-and-speak-context)
      (add-words-to-index (map concept-name real-concept-list) (book-url lecture-id page-id) (slide-url lecture-id page-id) 'concept))
  (con (center-frame-color 30 concept-background
         (apply string-append
             (map (lambda (x) (con (p) (font-color white x)))
                  (map as-slide-text  
                    (map emphasize-concept-name 
                         real-concept-list)))))
       (vertical-space 1))))

; Return the concept description of c, with emphasis of the concept name
(define (emphasize-concept-name c)
 (embed-substring 
  (concept-name c) 
  (embed-substring (capitalize-string-nd (concept-name c)) (concept-description c) em)
  em))


(define (slide-style-opposing . x)
 (con
    (center
      (table-1 0 (list 10 "*" 40 "*") (make-list 4 slide-background-color)
        (map (lambda (a1-a2) 
               (list "" (as-slide-text (slide-item a1-a2))
                        (img-0 (image-file "blank-pillar.gif")) (as-slide-text (con (note-item a1-a2) (p) ))))
             x)
      ))
  (vertical-space 1)
 )
)

(define (slide-style-comment . x)
   (let ((comment (car x)))
     (indent-pixels 10
       (i (as-slide-text (con (text-choice "Intern kommentar: " "Internal comment ") comment (vertical-space 1)))))))

; old non-centered
; (define (slide-style-syntax . x)
;    (let* ((syntax-form (car x))
;           (syntax-form-1 (string-append CR syntax-form))
;           (comment (if (> (length x) 1) (cadr x) "")))
;      (indent-pixels 10
;        (con (color-frame (pre (as-slide-text syntax-form-1)) syntax-frame-color) (vertical-space 1)))))

; centered:
(define (slide-style-syntax . x)
   (let* ((syntax-form (car x))
          (syntax-form-1 (string-append CR syntax-form))
          (comment (if (> (length x) 1) (cadr x) "")))
     (center
       (con (color-frame (pre (as-slide-text syntax-form-1)) syntax-frame-color) (vertical-space 1)))))


(define (slide-style-slide-space . x)
   (vertical-space 1))

(define (slide-style-tabular border column-widths list-of-list . comment)
  (let ((com (if (null? comment) "" (car comment))))
   (con
     (center
      (table-1 border
              column-widths
              (make-list (length column-widths) tabular-slide-color)
              (map (lambda (row) (map (lambda (el) (font-size slide-font-size el)) row)) list-of-list)))
    (vertical-space 1) )))

(define (slide-style-note-text nt)
   "")

(define (slide-style-slide-text st)
  (con
    (indent-pixels 10 (font-size slide-font-size st))
    (vertical-space 1)))

(define (slide-style-cross-references list-of-cross-refs)
 (let* ((hv (cond ((= (length list-of-cross-refs) 1) (text-choice "Henvisning" "Reference"))
                  ((> (length list-of-cross-refs) 1) (text-choice "Henvisninger" "References"))
                  ((< (length list-of-cross-refs) 1) (text-choice "Ingen henvisninger" "No references"))))
        (formatter-function (generate-cross-reference-formatter slide-url))
        (filtered-refs list-of-cross-refs)  ; before: (filter no-informal-references list-of-cross-refs )
        (formatted-refs-0 (map formatter-function filtered-refs)) ; gives a list or url and hint
        (formatted-refs (glue-ref-and-hint formatted-refs-0))
        (formatted-ref-string (ul-1 (map (lambda (r) (font-size 2 r)) formatted-refs)))
       )
  (if (not show-and-speak-context)
      (set! cross-refs-in-this-lecture (append list-of-cross-refs cross-refs-in-this-lecture)))
  (if (> (length filtered-refs) 0)
   (con
    (indent-pixels 10
      ; cross references at right hand side of slide:
      (table-3 0 (list 1200 200)
       (list (list "" formatted-ref-string)))

    )
    (vertical-space 1))
   "")
  )
)



(define (no-informal-references cross-ref-record)
  ; true for all but informal references
  (not (eq? (cross-ref-type cross-ref-record) 'informal-reference)))


(define (slide-style-exercise id-symbol title formulation-clause . solution-clause)
  (let* ((formulation-text (car (element-contents formulation-clause)))
         (solution-clause-1 (if (not (null? solution-clause)) (car solution-clause) #f))
         (solution-text (if solution-clause-1 (car (element-contents solution-clause-1)) ""))
         (file-name (exercise-name lecture-id page-id 'slide exercise-number))
         (link-file-name ((if exercise-manager-support? exercise-frame-name  exercise-name) lecture-id page-id 'slide exercise-number))
         (solution-url (if solution-clause-1 (exercise-solution-url lecture-id page-id exercise-number) "")))
    (set! current-exercise-id id-symbol)
    (if (not show-and-speak-context)
        (set! lecture-exercise-list 
              (cons 
                (list id-symbol title page-id exercise-number formulation-text next-exercise-number solution-text)
                lecture-exercise-list)))

    ; Add exercise title to the word index:
    (if (not show-and-speak-context)
        (add-words-to-index (list (string-append title (text-choice " (opgave)" " (exercise)")))
                            (book-url lecture-id page-id) (slide-url lecture-id page-id) 'index))

    (save-slide-exercise title formulation-text file-name (slide-url lecture-id page-id)
                         solution-url next-exercise-number)

    (set! exercise-number (+ 1 exercise-number))
    ; solution only saved in note-style-exercise
    (set! next-exercise-number (+ 1 next-exercise-number))
    (indent-pixels 10 
                   (con
                    (table-3 0 (list 100 900) 
                             (list (list (a-tag (string-append link-file-name ".html")
                                                (img-LN (exercise-icon-name language-preference 'large) (text-choice "G til opgave" "Go to exercise")))
                                         (font-color grey1 (b title))))
                             "middle")
                    (vertical-space 1)))))


(define (slide-style-index-words . words)
; collect index words and return ""
 (if (not show-and-speak-context)
     (add-words-to-index words (book-url lecture-id page-id) (slide-url lecture-id page-id) 'index))
 "")  

; -----------------------------------------------------------------------------

; slide style image series:

(define (slide-style-image-series series-title img-subtitle-list how-to-show-list)
  (let ((how-to-show-slide (car how-to-show-list))
        (image-file-names (map car img-subtitle-list)))
    (for-each 
      (lambda (fn) 
        (set! note-specific-graphics-files (cons fn note-specific-graphics-files)))
      image-file-names)
    (cond ((eq? how-to-show-slide 'slide-inline) (slide-style-image-series-inline series-title img-subtitle-list))
          ((eq? how-to-show-slide 'slide-external) (slide-style-image-series-external series-title img-subtitle-list))
          (else (error "Slide-style-image-series: Problems in how to show")))))

(define (slide-style-image-series-inline series-title img-subtitle-list)
 (apply string-append
  (map slide-style-image (map car img-subtitle-list))))

(define (slide-style-image-series-external series-title img-subtitle-list)
 (let* ((numbers (number-interval 1 (length img-subtitle-list)))
        (file-name-list (map2 (lambda (dummy sub-number)
                                (image-name lecture-id page-id 'slide image-number sub-number))
                            img-subtitle-list numbers))
        (file-name-list-show (map2 (lambda (dummy sub-number)
                                (image-name lecture-id page-id 'show image-number sub-number))
                            img-subtitle-list numbers))
        (icon-element (a-tag (local-html-url (car file-name-list)) 
                             (img-LN  (image-series-icon-name language-preference 'large) 
                                      (text-choice "G til billedserie" "Navigate to image series"))))
        
        (initial-sentence (first-sentence-in-string series-title))
        (this-image-number image-number)
       )
  (set! image-number (+ 1 image-number))
  (map3 (lambda (img-subtitle file-name number)
         (save-slide-image (car img-subtitle) (cadr img-subtitle)
          file-name (slide-url lecture-id page-id)
          (img-relative-url file-name-list (- number 1)) (img-relative-url file-name-list (+ number 1))
          this-image-number number
         )

         (save-slide-image-show-and-speak (car img-subtitle) (cadr img-subtitle)
          file-name (slide-show-and-speak-url lecture-id page-id 1)
          (img-relative-url file-name-list-show (- number 1)) (img-relative-url file-name-list-show (+ number 1)) 
          this-image-number number
         )

        )
       img-subtitle-list file-name-list numbers)
  (con (indent-pixels 10 (image-slide-presentation icon-element initial-sentence)) (vertical-space 1))
 ))

(define (image-slide-presentation icon-element series-title)
 (table-3 0 (list 110 900) 
    (list (list icon-element (font-color grey1 (b series-title))))
    "middle"))

(define (img-relative-url file-name-list n)
  ; return an url made out of element n of file-name-list
  ; if n is outside range, return #f
 (let ((lgt (length file-name-list)))
  (cond ((and (>= n 1) (<= n lgt)) (local-html-url (list-ref file-name-list (- n 1))))
        (else #f))))

(define (save-slide-image img-file img-text dest-file-name context-url prev-url next-url . optional-parameter-list)
 (let* ((number (optional-parameter 1 optional-parameter-list 1))
        (sub-number (optional-parameter 2 optional-parameter-list 1))
       )
  (write-text-file
   (image-slide
      context-url prev-url next-url
      "Image in series"
      img-text img-file
      number sub-number)
   (destination-path dest-file-name))))

(define (image-slide context-url prev-url next-url header title image-file number sub-number)
  (let ((body  (con (image-header context-url prev-url next-url #f number sub-number) (vertical-space 1)
                    (indent-pixels 10 
                      (con (font-size slide-font-size title) (vertical-space 2)
                           (img-0 (string-append  "." "/" "graphics/" image-file)))))))
    (if java-scripting
      (page-with-keypress-script
        (as-string header) 
        '()
        body

        javascript-loading
        (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
        (js-call "lenoNavigate" 
                 (map string-it-single 
                      (list (if prev-url prev-url "")
                            (if next-url next-url "")
                            context-url
                            "")))

        slide-background-color black black black
        mouse-advancement
      )
      (page-1
        (as-string header) 
        '()
        body

        slide-background-color black black black))))

(define (image-header context-url prev-url next-url . optional-parameter-list)
 (let* ((next-in-show (optional-parameter 1 optional-parameter-list #f))
        (number (optional-parameter 2 optional-parameter-list 1))
        (sub-number (optional-parameter 3 optional-parameter-list 1))
        (sound (speak-name lecture-id page-id 'image-series-part number sub-number))
       )
  (con 
   (if next-in-show ; means show and speak
        (con
          (a-tag (html-file (image-name lecture-id page-id 'slide number sub-number)) 
	         (img-LN "atomspin.gif"  (text-choice "Stop afspilning med lyd" "Stop show with sound"))) 

          (space 2)

          (a-tag 
            next-in-show
            (img-LN "nav-right-red.gif" (key-shortcut (text-choice "Nste slide i dette show" "Next slide in show") "n")))
          (space 2)
        )

        (con 
          (if show-and-speak? 
              (con
                (a-tag (html-file (image-name lecture-id page-id 'show number sub-number) ) 
		 	          (img-LN "atomspin-freeze.gif" (text-choice "Afspil indtalte slides" "Play spoken slide show")))
                (space 2))
               "")

          (a-tag context-url
                 (img-LN "nav-up.gif" (key-shortcut (text-choice "G t niveau op" "Navigate one level up") "u")))              (space 2)
          (if prev-url
              (a-tag prev-url (img-LN "nav-left.gif" (key-shortcut (text-choice "G til forrige billede" "Navigate to previous image") "p")))
              (img-LN "nav-left-empty.gif" ""))                                                     (space 2) 
          (if next-url
              (a-tag next-url (img-LN "nav-right.gif" (key-shortcut (text-choice "G til nste billede" "Navigate to next image") "n"))) 
              (img-LN "nav-right-empty.gif" ""))                                                     (space 2)

          (if show-and-speak?
              (if (file-exists? (sound-file-path sound))
                  (a-tag (speak-url sound)
   	   		            (img-LN "speaker.gif" (text-choice "Afspil lyd p denne slide" "Play sound for this slide")))
                  (img-LN "speaker-empty.gif" ""))
              "")
        )
   )

   )
 )
)


; -----------------------------------------------------------------------------

(define (slide-style-section-title title)
  (con (vertical-space 5)
       (center (font-1 7 red title))))


; intended for repetition of an image on a slide:

(define (slide-style-slide-image image-file)
  (con (center (img-0 (string-append  "." "/" "graphics/" image-file))) (vertical-space 1)))


(define (slide-style-applet-program class-file codebase explanation width height)
  (let ((class-file-1 (string-append relative-applet-path class-file)))
    (center (html4:applet "" 'code class-file 'codebase codebase 'height height 'width width))))


(define (slide-style-synopsis . items)
  (let* ((slide-relevant-items (map (lambda (i) (car (element-contents i))) items))
         (formatted-slide-relevant-items (map (lambda (e) (font-rise e (+ 1 slide-font-size))) (map upcase-string slide-relevant-items)))
        )
    (con 
      (indent-pixels 10 (center (color-frame (bullet-list formatted-slide-relevant-items 'large-rised 'yellow) synopsis-frame-color)))
      (vertical-space 1))
  ))

(define start-quote "\"")
(define end-quote "\"")

(define (slide-style-quotation . x)
 (let ((quotation (car x))
       (comment (if (> (length x) 1) (cadr x) ""))
      )
  (con (indent-pixels 10 (narrow-with-pixels 100
           (i (string-append (img-0 (image-file "left-quote.gif")) (as-slide-text quotation) (img-0 (image-file "right-quote.gif")) ))))
       (vertical-space 1))))

(define (slide-style-quiz question answer-list)
  (if (not show-and-speak-context)
      (set! quiz-list 
       (cons
         (make-leno-quiz-entry question answer-list (course-absolute-url (string-append "html/noter/" (note-url lecture-id page-id))))
         quiz-list)))

  "" ; leave no trace of quiz in the slide
)

(define (slide-style-show-and-speak . rest)
  ; We extract this information early and use it imperatively
  "")

; The url of a lecturer photo composed by img-name (including extension) and the constant lecturer-photo-url-prefix.
(define (lecturer-photo-url img-name)
  (string-append lecturer-photo-url-prefix img-name))

; Return an actual list of photos from photo-list, starting at start.
; The returned list will lgt long. Takes photos cyclically from photo-list.
; Start is a number between 0 and (- (length photo-list) 1) that specify where in the photo list to start
(define (actual-photo-list photo-list start lgt)
  (actual-photo-list-1 photo-list start lgt 0 '()))

; start: where in the photo-list to start
; lgt: How many elements to return
; n: the actual length of res
; res: the resulting list  
(define (actual-photo-list-1 photo-list start lgt n res)
  (if (= n lgt)
      (reverse res)
      (actual-photo-list-1 
        photo-list 
        (if (= start (- (length photo-list) 1)) 0 (+ start 1))
        lgt
        (+ n 1)
        (cons (list-ref photo-list start) res))))

; Slide presentation of lecturer photos. 
; First parameter is the start photo - first is number 0.
; The second parameter is the number of photos to show in a row.
(define (slide-style-lecturer-photos . rest)
  (let ((start-photo (optional-parameter 1 rest))
        (number-of-photos (optional-parameter 2 rest)))
   (if (and show-and-speak? show-and-speak-context)
    (con 
     (vertical-space 1)
     (center
      (table-1 0
	       (make-list number-of-photos lecturer-photo-width)
	       (make-list number-of-photos slide-background-color)
	       (list
		(map 
		 (lambda (image-name) (html4:img 'src (lecturer-photo-url image-name) 'alt "" 'width (- lecturer-photo-width 20)))
		 (actual-photo-list lecturer-photo-list start-photo number-of-photos)
		 )
		)
	       "middle"
	       )))
     "")))


; Slide presentation of lecturer photos. 
; As a contrast to lecture-photos, this function gives a fixed presentation of two photos with
; the logo in between. The logo is assumed to be part of the lecture specific images.
; First parameter is the start photo - first is number 0.
(define (slide-style-lecturer-photos-and-logo . rest)
  (let* ((start-photo-0 (optional-parameter 1 rest))
         (start-photo (remainder start-photo-0 (length lecturer-photo-list)))
         (number-of-photos 3)
         (photo-1-name (list-ref lecturer-photo-list start-photo))
         (photo-2-name (list-ref lecturer-photo-list (if (= start-photo (- (length lecturer-photo-list) 1)) 0 (+ 1 start-photo))))
         (photo-1 (html4:img 'src (lecturer-photo-url photo-1-name) 'alt ""))
         (photo-2 (html4:img 'src (lecturer-photo-url photo-2-name) 'alt ""))
         (logo (logo-img))
         (logo-width 150)
         (space-width 80)
        )
   (if (and show-and-speak?
       ;     show-and-speak-context
       )
    (con 
     (vertical-space 2)
     (center
      (table-1 0
               (list lecturer-photo-width space-width logo-width space-width lecturer-photo-width)
	       (make-list (+ number-of-photos 2) slide-background-color)
	       (list
                 (list photo-1 "" logo "" photo-2)
	       )
	       "middle"
	       )))
     "")))

(define (slide-style-elucidate . rest)
 (let ((e-title (first-sentence-in-string (first rest)))
       (e-url (second rest))
       (e-target (if (>= (length rest) 3) (third rest) elucidator-default-target))
      )
  (indent-pixels 
     10 
     (con
      (table-3 0 (list 100 900) 
	(list (list (if elucidator-default-target
                        (a-tag-target 
                           e-url
			   (img-LN (elucidator-icon-name language-preference 'large) 
                                   (text-choice "Forklar dette program i separat browser vindue" 
                                                "Elucidate this program in a separate browser window"))
                           elucidator-default-target)
                        (a-tag 
                           e-url
			   (img-LN (elucidator-icon-name language-preference 'large) 
                                   (text-choice "Forklar dette program" 
                                                "Elucidate this program"))))
		    (font-color grey1 (b e-title))))
	       "middle")
      (vertical-space 1)))))





; -----------------------------------------------------------------------------
; NOTE-STYLE

(define slide-area-width 450) 
(define slide-note-separation 50)
(define note-area-width 450)

(define (presentation-slice x y)
  (table-1 0 (list slide-area-width slide-note-separation note-area-width)
             (make-list 3 note-background-color)
    (list (list x "" y))))


; -----------------------------------------------------------------------------

(define (note-style-title . x)
 (let ((title (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
   (presentation-slice 
     (con (font-1 5 title-color (b title)) (p))
     (con (note-text-right comment) (p)))
 ))

(define (note-style-text . x)
 (let ((text (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
   (presentation-slice 
     (con (indent-pixels 10 (note-text-left text)) (p))
     (con (note-text-right comment) (p)))))


(define (note-style-items . i)
  (presentation-slice
     (con (note-text-left (ul-1 (map slide-item i))) (p))
     (con 
      (note-text-right 
       (string-merge
                (map note-item i)
                (make-list (length i) (p))))
       (p))))


(define (note-style-point . x)
 (let ((point (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
  (presentation-slice
     (con (note-text-left (center-frame 30 (font-color red (note-text-left point)))) (p))
     (con (note-text-right comment) (p)))
))



(define (note-style-program . x)
 (let ((program-text (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
  (presentation-slice
     (con (indent-pixels 10 (note-text-left (font-size 2 (pre program-text)))) (p))
     (con (note-text-right comment) (p)))
))

(define (note-style-source-program . x)
 (let* ((program-file-name (first x))
        (mark (second x))
        (colorizing (third x))
        (program-text (html-protect (program-extract program-file-name mark)))
        (colorized-program-text (colorize-substrings program-text colorizing)) 
        (how-to-show (fourth x))
        (comment (if (> (length x) 3) (fifth x) ""))
        (initial-sentence (first-sentence-in-string comment))
       )
  (if (eq? (car how-to-show) 'slide-inline)
      (presentation-slice
         (con (indent-pixels 15 (note-text-left (font-size 2 (pre colorized-program-text)))) (p))
         (con (note-text-right comment) (p)))
      (let ((file-name (program-name lecture-id page-id 'note program-number))) ;@a
         (set! program-number (+ program-number 1)) ;@b
         (save-note-program colorized-program-text file-name (note-url lecture-id page-id))  ; program saved again,
                                                                                             ; under another name, in another size
         (presentation-slice
          (con
           (table-3 0 (list 100 390) 
               (list (list (a-tag (string-append file-name ".html") (img-LN (program-icon-name language-preference 'small) program-file-name))
                           (note-text-left (font-color grey1 (b initial-sentence)))))
               "middle") (p))
           (con (note-text-right comment) (p)))
  ))))

(define (note-style-image . x)
 (let ((image-file (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
    (presentation-slice
     (con (center (img-0 (string-append  "." "/" "graphics/small/" image-file))) (p))
     (con (note-text-right comment) (p)))))

;(define (note-style-concepts . x)
;  (apply note-style-items x))

; (define (note-style-concepts . i)
;   (presentation-slice
;      (con (note-text-left (bullet-list (map note-text-left (map slide-item i)) 'large 'yellow)) (p))
;      (con 
;       (note-text-right 
;        (string-merge
;                 (map note-item i)
;                 (make-list (length i) (p))))
;        (p))))


(define (note-style-concepts . i)
  (presentation-slice
     (con (note-text-left 
            (center-frame-color 30 concept-background
             (apply string-append
               (map (lambda (x) (con (p) (font-color white x)))
                    (map note-text-left (map slide-item i)))))) (p))
     (con 
      (note-text-right 
       (string-merge
                (map note-item i)
                (make-list (length i) (p))))
       (p))))



(define (note-style-concept-list . x)
 (let ((real-concept-list (map element-contents x)))
  (presentation-slice
     (con (note-text-left 
            (center-frame-color 30 concept-background
             (apply string-append
               (map (lambda (x) (con (p) (font-color white x)))
                    (map note-text-left (map emphasize-concept-name real-concept-list)))))) (p))
     (con 
      (note-text-right 
       (string-merge
                (map concept-explanation real-concept-list)
                (make-list (length real-concept-list) (p))))
       (p)))))

(define (note-style-example . x)
 (let ((the-example (car x))
       (about-the-example (if (> (length x) 1) (cadr x) "")))
   (presentation-slice 
     (con (indent-pixels 10 (i (note-text-left the-example))) (p))
     (con (note-text-right about-the-example) (p)))
   ))

(define (note-style-opposing . x)
 (presentation-slice
   (table-1 0 (list "*" 40 "*") (make-list 3 slide-background-color)
      (map (lambda (a1-a2) (list (note-text-left (slide-item a1-a2)) "" (note-text-left (note-item a1-a2)))) x))
   ""))

(define (note-style-comment . x)
   (let ((comment (car x)))
   (presentation-slice 
     (con (text-choice "Intern kommentar: " "Internal comment")  (i (note-text-left comment)) (p))
     "")))


(define (note-style-syntax . x)
 (let* ((syntax-form (car x))
        (syntax-form-1 (string-append CR syntax-form))
        (comment (if (> (length x) 1) (cadr x) "")))
  (presentation-slice
     (con (indent-pixels 10 (color-frame (pre (font-size 2 syntax-form-1)) syntax-frame-color)) (p))
     (con (note-text-right comment) (p)))
))

(define (note-style-slide-space . x)
   "")

(define (note-style-tabular border column-widths list-of-list . comment)
  (let ((com (if (null? comment) "" (car comment))))
   (presentation-slice
    (con
     (table-1 border
             column-widths
             (make-list (length column-widths) tabular-note-color)
             (map (lambda (row) (map (lambda (el) (font-size (- note-font-size-left 1) el)) row)) list-of-list)) (p))
    (con (note-text-right com) (p)))))

(define (note-style-note-text nt)
  (let ((text "")
        (comment nt))
   (presentation-slice 
     text
     (con (note-text-right comment) (p)))))

(define (note-style-cross-references list-of-cross-refs)
 (let* ((hv (cond ((= (length list-of-cross-refs) 1) (text-choice "Henvisning" "Reference"))
                  ((> (length list-of-cross-refs) 1) (text-choice "Henvisninger" "References"))
                  ((< (length list-of-cross-refs) 1) (text-choice "Ingen henvisninger" "No references"))))
        (formatter-function (generate-cross-reference-formatter note-url))
        (filtered-refs list-of-cross-refs)  ; before: (filter no-informal-references list-of-cross-refs )
        (formatted-refs-0 (map formatter-function filtered-refs))
        (formatted-refs (glue-ref-and-hint formatted-refs-0))
        (formatted-ref-string (ul-1 (map (lambda (r) (font-size 1 r)) formatted-refs)))
       )
 (presentation-slice 
   (if (> (length filtered-refs) 0)
    (con
      ; cross references at right hand side of slide:
      (table-3 0 (list 300 180)
        (list (list "" formatted-ref-string)))
     (vertical-space 1))
    "")
   (p) )
  )
) 


(define (note-style-exercise id-symbol title formulation-clause . solution-clause)
  (let* ((formulation-text (car (element-contents formulation-clause)))
         (solution-clause-1 (if (not (null? solution-clause)) (car solution-clause) #f))
         (solution-text (if solution-clause-1 (car (element-contents solution-clause-1)) ""))
         (formulation-file-name (exercise-name lecture-id page-id 'note exercise-number))
         (formulation-link-file-name ((if exercise-manager-support? exercise-frame-name  exercise-name) lecture-id page-id 'note exercise-number))
         (solution-file-name (exercise-solution-name lecture-id page-id exercise-number))
         (secret-solution-file-name (exercise-secret-solution-name lecture-id page-id exercise-number))
         (solution-url (if solution-clause-1 (exercise-solution-url lecture-id page-id exercise-number) ""))
        )

    (set! current-exercise-id id-symbol)

    (if exercise-manager-support?
        (save-note-frame-exercise-file lecture-id page-id id-symbol title formulation-file-name solution-url))

    (if distance-education-support?  ; idafus support
        (make-idafus-activity! id-symbol title formulation-text solution-text))

    (save-note-exercise title formulation-text formulation-file-name (note-url lecture-id page-id)
                        solution-url next-exercise-number)

    ; always save solution file. Hard to find because of password ingredient in name. 
    ; Links are only made to this file in case we want to reveal solutions.
    (save-exercise-solution title solution-text solution-file-name (note-url lecture-id page-id)
                                next-exercise-number)

    ; always store the 'secret' solutions
    (save-exercise-solution title solution-text secret-solution-file-name (note-url lecture-id page-id)     
                                next-exercise-number) 

    (set! exercise-number (+ 1 exercise-number))

    (set! next-exercise-number (+ 1 next-exercise-number))
    (presentation-slice
       (table-3 0 (list 100 390) 
		  (list (list (a-tag (string-append formulation-link-file-name ".html")
				     (img-LN (exercise-icon-name language-preference 'small) (text-choice "G til opgave" "Go to exercise")))
			      (font-1 note-font-size-left grey1 (b title))))
		  "middle")
       "")
))

(define (note-style-image-series series-title img-subtitle-list how-to-show-list)
  (let ((initial-sentence (first-sentence-in-string series-title)))
   (set! image-number (+ 1 image-number))
   (presentation-slice
     (con (font-1 note-font-size-left grey1 (b (con initial-sentence (text-choice " (se slide)" " (see slide)")) )) (p))
     "")))

(define (note-style-section-title title)
 (presentation-slice
  (con (vertical-space 2)
       (center (font-1 5 red title)))
   ""))


(define (note-style-slide-image image-file)
 (presentation-slice
     (con (center (img-0 (string-append  "." "/" "graphics/small/" image-file))) (p))
     (con (note-text-right "") (p))))

(define (note-style-applet-program class-file codebase explanation width height)
  (presentation-slice
     (con (center (html4:applet "" 'code class-file 'codebase codebase 'height height 'width width)) (p))
     (con (note-text-right explanation) (p))))


(define (note-style-synopsis . items)
  (let* ((slide-relevant-items (map (lambda (i) (car (element-contents i))) items))
         (explanation-relevant-items  (map extract-synopsis-explanation items))
         (explanation-relevant-items-1 (filter (lambda(e) (not (equal? "" e))) explanation-relevant-items))
         (formatted-slide-relevant-items (map (lambda (e) (font-rise e (+ 1 note-font-size-left))) (map upcase-string slide-relevant-items)))
        )
   (presentation-slice
     (con 
       (indent-pixels 10  (center (color-frame (bullet-list formatted-slide-relevant-items 'small 'yellow) synopsis-frame-color)))
       (p)
     )
     (con 
      (note-text-right 
       (string-merge
                explanation-relevant-items-1
                (make-list (length explanation-relevant-items-1) (p))))
       (p)))))

; extract the explanation component "y" of a synopsis item:  (synopsis-item "x" "y")
; in case the list is of lenght 2, return the empty string.
(define (extract-synopsis-explanation i)
 (let ((contents (element-contents i)))
   (if (>= (length contents) 2)
       (cadr contents)
       "")))


(define (note-style-quotation . x)
 (let ((quotation (car x))
       (comment (if (> (length x) 1) (cadr x) ""))
      )
 (presentation-slice
  (con (indent-pixels 10 (narrow-with-pixels 50
           (i (string-append (font-rise start-quote note-font-size-left) (note-text-left quotation) (font-rise end-quote note-font-size-left)))))
       (p))
  (con (note-text-right comment) (p)))))

(define (note-style-elucidate . rest)
 (let ((e-title (first-sentence-in-string (first rest)))
       (e-full-expl (first rest))
       (e-url (second rest))
       (e-target (if (>= (length rest) 3) (third rest) elucidator-default-target))
      )
    (presentation-slice
       (table-3 0 (list 100 390) 
		  (list (list (a-tag e-url
			         (img-LN (elucidator-icon-name language-preference 'small) 
                                         (text-choice "G til elucidator" "Go to elucidator")))
			      (font-1 note-font-size-left grey1 (b e-title))))
		  "middle")
       (note-text-right e-full-expl))))

; -----------------------------------------------------------------------------      

; BOOK-STYLE
; indfr kald af book-text i stedet for font

(define (book-style-title . x)
 (let ((title (car x))
       (body (if (> (length x) 1) (cadr x) ""))
       (annotator-url
          (if annotator-support?
              (annotator-url "annotator.cgi"
                  (list 'annotation-id 'detail-level 'activation-mode 'language 'informative-title 'back-url)
                  (list (encode-annotation-ids (list (as-string annotator-symbol) (as-string lecture-id) (as-string page-id)))
                        "flat" "present-only" language-preference page-title 
                        (course-absolute-url (string-append "html/noter/" (html-file (note-name lecture-id page-id)))))
               )
              ""))
       )
   (con 
    (a-name page-id)
    (table-1 0 '(180 12 500) (make-list 3 book-background-color) 
      (list (list (con (font-1 4 book-title-foreground-color title) (br)
                       (font-size 1 
                         (con (a-tag (slide-url lecture-id page-id) "Slide") (space 1)
                              (a-tag (note-url lecture-id page-id) "Note") (space 1)
                              (a-tag (contents-url lecture-id) (text-choice "Indhold" "Contents") ) (space 1)
                              (a-tag (all-word-index-url lecture-id) (text-choice "Stikord" "Index")) (br)
                              (a-tag "#REFERENCES" (text-choice "Referencer" "References")) (space 1)
                              (if annotator-support? (a-tag annotator-url (text-choice "Kommenter" "Comment")) "")
                         )))
                  ""
                  (font-1 3 black body))))
    (p))))


(define (book-style-text . x)
 (let ((text (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
   (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list "" "" (con (font-1 3 black text) (br)
                             (font-1 3 black comment)))))
    (p)) ))


(define (book-style-items . i)
 (con
   (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
     (list (list "" "" (con (frame-width (ul-1 (map slide-item i)) 490) (p)
                            (string-merge
                             (map note-item i)
                             (make-list (length i) (p))
                        )))))
   (p)))


(define (book-style-point . x)
 (let ((point (car x))
       (body (if (> (length x) 1) (cadr x) "")))
   (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list ""
                  ""
                  (con (frame-width (font-1 3 red point) 490) (p) (font-1 3 black body)))))
    (p))))

(define (book-style-program . x)
 (let ((program-text (car x))
       (comment (if (> (length x) 1) (cadr x) "")))
   (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list (font-1 2 book-header-foreground-color
                          (i (con (u "Program") ": " comment)))
                  ""
                  (con (font-1 3 black (pre program-text))))))
    (p))))

(define (book-style-source-program . x)
  (let* ((program-file-name (first x))
        (mark (second x))
        (colorizing (third x))
        (program-text (html-protect (program-extract program-file-name mark)))
        (colorized-program-text (colorize-substrings program-text colorizing))
        (how-to-show (fourth x))
        (comment (if (> (length x) 3) (fifth x) "")))
    (if (eq? (cadr how-to-show) 'book-inline)
        (con
         (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
                  (list (list (font-1 2 book-header-foreground-color
                                    (i (con (u "Program") ": " comment)))
                              ""
                              (con (font-1 2 black (pre colorized-program-text))))))
         (p))
      (let ((file-name (program-name lecture-id page-id 'book program-number)))
        (set! program-number (+ program-number 1))
        (save-book-program colorized-program-text file-name (book-url lecture-id page-id))
        (con
         (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
                  (list (list (font-1 2 book-header-foreground-color
                                    (i (con (u "Program") ": " comment)))
                              ""
                              (con (font-1 3 black (a-tag (string-append file-name ".html") 
                                                        (img-LN (program-icon-name language-preference 'small) 
                                                                program-file-name)))))))
         (p))
        ))))


(define (book-style-image . x)
 (let ((image-file (car x))
       (comment (if (> (length x) 1) (cadr x) "")))

   (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list (i (font-1 2 book-header-foreground-color (con (u (text-choice "Figur" "Figure")) ". " comment)))
                  ""
                  (center (img-0 (string-append  "." "/" "graphics/small/" image-file))))))
    (p))))




(define (book-style-concepts . i)
  (con
    (table-1 0 '(180 12 500) (make-list 3 book-background-color)
      (map (lambda (e) (list (font-1 2 book-header-foreground-color (b (con (u (text-choice "Begreb" "Concept")) ": " (slide-item e))))
                             ""
                             (note-item e))) i)
    )
    (p)))


(define (book-style-concept-list . i)
 (let ((real-concept-list (map element-contents i)))
  (con
    (table-1 0 '(180 12 500) (make-list 3 book-background-color)
      (map (lambda (e) (list (font-1 2 book-header-foreground-color (b (con (u (con-space (text-choice "Begrebet" "The concept")
                                                                                        (concept-name e))) ": " (concept-description e))))
                             ""
                             (concept-explanation e)))
            real-concept-list)
    )
    (p))))


; (define (book-style-example . x)
;  (let ((the-example (car x))
;        (about-the-example (if (> (length x) 1) (cadr x) "")))
;    (con
;     (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
;       (list (list (font-1 2 book-header-foreground-color (con (u "Eksempel") ". " the-example))
;                   ""
;                   (con (font-1 3 black about-the-example)))))
;     (p))))

(define (book-style-example . x)
 (let ((the-example (car x))
       (about-the-example (if (> (length x) 1) (cadr x) "")))
   (con
     (book-element
       (font-1 2 book-header-foreground-color (con (u "Eksempel") ". " the-example))
       (font-1 3 black about-the-example))
     (vertical-space 1))))


(define (book-style-opposing . x)
  (con
   (table-1 0 '(180 12 500)  (make-list 3 book-background-color)
          (list  
            (list  "" 
                   ""
                   (table-1 0 (list 200 40 200) (make-list 3 book-background-color)
                            (map (lambda (a1-a2) (list (book-text (slide-item a1-a2)) "" (book-text (note-item a1-a2)))) x)))))
   (p)))

(define (book-style-comment . x)
 (let ((comment (car x)))
   (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list (i (b (text-choice "Intern kommentar: " "Internal comment")))
                  ""
                  (con  (i (note-text-left comment)) (vertical-space 1)))))
    (p))))


(define (book-style-syntax . x)
 (let* ((syntax-form (car x))
        (syntax-form-1 (string-append CR syntax-form))
        (comment (if (> (length x) 1) (cadr x) "")))
   (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list (font-1 2 book-header-foreground-color
                          (i (con (u "Syntax") ": " comment)))
                  ""
                  (con (color-frame (pre (font-size 2 syntax-form-1)) syntax-frame-color)))))
    (p))))


(define (book-style-tabular border column-widths list-of-list . comment)
  (let ((com (if (null? comment) "" (car comment))))
   (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list (font-size 2 (i (con (u (text-choice "Tabel" "Table")) ". " com)))
                  ""
                  (con  
                      (table-1 border
                               column-widths
                               (make-list (length column-widths) tabular-book-color)
                               (map (lambda (row) (map (lambda (el) (font-size (- book-font-size 1) el)) row)) list-of-list))

                      (vertical-space 1)))))
    (p))))


(define (book-style-note-text nt)
  (let ((text "")
        (comment nt))
   (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list "" "" (font-1 3 black comment))))
    (p))))



(define (book-style-cross-references list-of-cross-refs)
 (let* ((hv (cond ((= (length list-of-cross-refs) 1) (text-choice "Henvisning" "Reference"))
                  ((> (length list-of-cross-refs) 1) (text-choice "Henvisninger" "References") )
                  ((< (length list-of-cross-refs) 1) (text-choice "Ingen henvisninger" "No references"))))
        (formatter-function (generate-cross-reference-formatter book-url))
        (formatted-refs-0 (map formatter-function list-of-cross-refs))
        (formatted-refs (glue-ref-and-hint formatted-refs-0))
        (formatted-ref-string (ul-1 (map (lambda (r) (font-size 2 r)) formatted-refs)))
       )
  (con
    (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list (color-frame-width (con (u (i (font-size 2 hv))) formatted-ref-string) grey2 180)
                  ""
                  "")))
    (p))))


(define (book-style-exercise id-symbol title formulation-clause . solution-clause)
  (let* ((formulation-text (car (element-contents formulation-clause)))
         (solution-clause-1 (if (not (null? solution-clause)) (car solution-clause) #f))
         (solution-text (if solution-clause-1 (car (element-contents solution-clause-1)) "")))
    (set! exercise-number (+ 1 exercise-number))
    (let* ((num next-exercise-number)
	   (hier-num (if (and lecture-number (number? lecture-number))
			 (con (as-string lecture-number) "." (as-string num))
		       (as-string num))))
      (set! next-exercise-number (+ 1 next-exercise-number))
      ; solution only saved in note-style-exercise
      (con
       (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
		(list (list (font-size 2 (con (u (con (text-choice "Opgave" "Exercise") " " (as-string hier-num))) ". " title))
			    "" 
			    (font-1 3 black formulation-text))))
       (p)))))



(define (book-style-image-series series-title img-subtitle-list how-to-show-list)
  (let ((how-to-show-slide (cadr how-to-show-list)))
    (cond ((eq? how-to-show-slide 'book-inline) (book-style-image-series-inline series-title img-subtitle-list))
          ((eq? how-to-show-slide 'book-external) (book-style-image-series-external series-title img-subtitle-list))
          (else (error "Book-style-image-series: Problems in how to show")))))

(define (book-style-image-series-inline series-title img-subtitle-list)
 (let ((initial-sentence (first-sentence-in-string series-title)))
  (set! image-number (+ 1 image-number))
  (con
   (book-element (i (font-1 2 book-header-foreground-color (con (u (text-choice "Billedserie:" "Image series:")) " " initial-sentence)))
                 (con (b (font-1 3 black series-title)) (p)))
   (apply string-append
    (map3 present-book-style-image 
          (map car img-subtitle-list)
          (map cadr img-subtitle-list)
          (number-interval 1 (length img-subtitle-list)) )))))

(define (book-style-image-series-external series-title img-subtitle-list)
 ; in essence, just link to the slide image series
 (let* ((numbers (number-interval 1 (length img-subtitle-list)))
        (file-name-list (map2 (lambda (dummy sub-number)
                                (image-name lecture-id page-id 'book image-number sub-number))
                            img-subtitle-list numbers))
        (icon-element (a-tag (local-html-url (car file-name-list)) 
                                             (img-LN  (image-series-icon-name language-preference 'small) 
                                                     (text-choice "G til billedserie" "Navigate to image series"))))
       )
  (set! image-number (+ 1 image-number))
  (map3 (lambda (img-subtitle file-name number)
         (save-slide-image (car img-subtitle) (cadr img-subtitle)
          file-name (book-url lecture-id page-id)
          (img-relative-url file-name-list (- number 1)) (img-relative-url file-name-list (+ number 1)) 
           
          )
         )
       img-subtitle-list file-name-list numbers)
  (con 
   (book-element
     (i (font-1 2 book-header-foreground-color (con (u (text-choice "Billedserie:" "Image series:")) " " series-title))) icon-element)
   (p))))

                 

(define (present-book-style-image image-file subtitle number)
  (con
   (book-element
     (i (font-1 2 book-header-foreground-color (con (u (con (text-choice "Billed nr. " "Image no. ") (as-string number))) ". " subtitle)))
     (center (img-0 (string-append  "." "/" "graphics/small/" image-file))))
   (vertical-space 1))
)


(define (book-style-section-title title)
  (con  (hr-1)
    (a-name page-id)
    (book-element (font-1 4 red title)
                  "")
        (hr-1)  ))

(define (book-style-applet-program class-file codebase explanation width height)
 (con
   (book-element
     (i (font-1 2 book-header-foreground-color (con (u "Applet") ". " explanation)))
     (center (html4:applet "" 'code class-file 'codebase codebase 'height height 'width width)))
   (vertical-space 1)))

(define (book-style-synopsis . items)
 (let* ((slide-relevant-items (map (lambda (i) (car (element-contents i))) items))
        (explanation-relevant-items  (map extract-synopsis-explanation items))
        (explanation-relevant-items-1 (filter (lambda(e) (not (equal? "" e))) explanation-relevant-items))
        (formatted-slide-relevant-items (map book-text slide-relevant-items))
       )
 (con
   (book-element
     ""
     (con (color-frame-width (bullet-list formatted-slide-relevant-items 'small 'yellow) synopsis-frame-color 490))
   ) 
   (p)
   (book-element
     ""  
     (font-1 book-font-size book-foreground-color
       (string-merge
          explanation-relevant-items-1
          (make-list (length explanation-relevant-items-1) (p)))))
   (vertical-space 1))))

; should be used generally:


(define (book-style-quotation . x)
 (let ((quotation (car x))
       (comment (if (> (length x) 1) (cadr x) ""))
      )
 (book-element
  ""
  (con (center 
         (narrow-with-pixels 18
           (i (string-append (font-rise start-quote book-font-size) (note-text-left quotation) (font-rise end-quote book-font-size)))))
       (p) 
       comment (p)))))

(define (book-style-elucidate . rest)
 (let ((e-title (first-sentence-in-string (first rest)))
       (e-full-expl (first rest))
       (e-url (second rest))
       (e-target (if (>= (length rest) 3) (third rest) elucidator-default-target))
      )
    (book-element
       e-full-expl
       (table-3 0 (list 100 390) 
		  (list (list (a-tag e-url
			         (img-LN (elucidator-icon-name language-preference 'small) 
                                         (text-choice "G til elucidator" "Go to elucidator")))
			      (font-1 note-font-size-left grey1 (b e-title))))
		  "middle"))))



(define (book-element left-contribution right-contribution)
 ; return a horizontal slize of a book style contribution
 (table-1 0 '(180 12 500)  (make-list 3 book-background-color) 
      (list (list left-contribution
                  ""
                  right-contribution))))

; A variant of book-element with an right-contribution column of unlimited width
(define (book-element-unlimited left-contribution right-contribution)
 ; return a horizontal slize of a book style contribution
 (table-1 0 '(180 12 *)  (make-list 3 book-background-color) 
      (list (list left-contribution
                  ""
                  right-contribution))))
 
; -----------------------------------------------------------------------------

; Experimental program page
; 
; (define (program-page id program-file mark)
;   (let* ((progr-text (read-text-file-between-marks program-file mark)))
;     (write-text-file
;       (standard-slide 
;         "Program"
;         (program-text (pre progr-text))
;         #f)
;       (destination-path (string-append "program-" (as-string id)))
; )))
; 
; (define program-font-size 4)
; 
; (define (program-text txt)
;   (font-size program-font-size txt))


; -----------------------------------------------------------------------------
; Functions for generation of top level index page

; Return the id of the first slide. Take the information from the stored -.aux file.
(define (first-slide-id lecture-id)
  ; find first slide id from aux file
  (let ((aux-file (aux-file-name lecture-id)))
    ; first element is lecture title string
    ; take the second element, the slide-id, of the next element
    (if (file-exists? aux-file)
        (cadr (car (cdr (file-read aux-file))))
        "") ))

; Return the id of the first trail slide given the trail-list and trail-id.
(define (first-trail-slide-id trail-id trail-list)
  (if (not (null? trail-list))
      (letrec ((trail-entry-lecture-id first)
               (trail-entry-slide-id second))
        (filename-of-trail-frame trail-id (trail-entry-lecture-id (car trail-list)) (trail-entry-slide-id (car trail-list))))
      ""  ; Leads to linking error. alternative (error ...) here
  ))

; Extract slide title from the information in the aux file
(define (slide-title lecture-id page-id)
  (let ((entry (find-original-slide-info lecture-id page-id)))
    (if entry (car entry) "Title")))

(define (front-index-entry id title this-number current-number)
  (let ((fs-text (text-choice "Frste slide" "First slide"))
        (first-slides-id (first-slide-id id)))
    (append 
     (list title 

          (string-append (text-choice "Lektion" "Lecture") " " (as-string this-number))

          (if (<= this-number current-number)
              (a-tag (contents-url id) (text-choice "Oversigt" "Overview"))
            (text-choice "Oversigt" "Overview"))
              
          (if (<= this-number current-number)
              (if (equal? "" first-slides-id) fs-text (a-tag (slide-url id first-slides-id) fs-text))
            fs-text)

          (if (<= this-number current-number)
              (a-tag (book-url id) (text-choice "Forelsningsnote" "Lecture notes"))
            (text-choice "Forelsningsnote" "Lecture notes")))
      (if exercise-index?
          (list 
            (if (<= this-number current-number)
                (if (> (length (exercise-info-list id)) 0)
                    (a-tag (html-file (exercise-index-name id)) (text-choice "Opgaver" "Exercises"))
                    "-")
              (text-choice "Opgaver" "Exercises"))
          )
          '())
)))


; Make and write the top level front page index.
; Provide for keyboard navigation to first 'row' in table.
(define (make-front-index)
					
  (let* ((w1 420)
	 (w5 70)
	 (w2 70)
	 (w3 90)
	 (w4 120)
         (w6 (if exercise-index? 70 0))
	 (w-total (+ w1 w2 w3 w4 w5 w6)))
   (let* ((body 
	   (con 
	    (front-index-header)
	    (h 1 notes-title)
            (if notes-subtitle (h 2 notes-subtitle) "")
	    (h 3
	       (con 
		(list-to-string 
                  (map (lambda (e) (con e (br))) (append lecture-author-info (list lecture-date)))
                  ""
                )
		)
	       )

	    (if (not (equal? note-abstract "")) (con (indent-pixels 20 (color-frame-width (em note-abstract) grey2 (- w-total 40))) (p)) "")

            (if (not (null? (lecture-wide-exercise-list)))
                (a-tag (html-file overall-exercise-index-name) 
                       (font-size 2 (text-choice "Alle opgaver i dette materiale" "All exercises in this material")))
                "") 

            (p)

	    (table-1 1
		     (append (list w1 w5 w2 w3 w4) (if exercise-index? (list w6) '()))
		     (make-list (if exercise-index? 6 5) slide-background-color)
		     (map4 front-index-entry lecture-list
			   lecture-titles
			   (number-interval 1 (length lecture-list))
			   (make-list (length lecture-list) current-lecture)  )) (p)

	    (when-generated)
	    ))
          (first-lecture-id (car lecture-list))
          (down-links (list (contents-url first-lecture-id)
                            (slide-url first-lecture-id (first-slide-id first-lecture-id))
                            (book-url first-lecture-id)))
          )
      (write-text-file
       (if java-scripting
	   (page-with-keypress-script
	    notes-title
	    '()
	    body

	    javascript-loading
	    (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
	    (js-call "lenoNavigate" 
		     (append
		      (map string-it-single 
			   (list ""
				 "" 
				 ""
                                 ""))
		      (list (js-string-array down-links))))

	    white black blue blue
            mouse-advancement
         )

	 (page-1
	  notes-title
	  '()
	  body
	  white black blue blue
	  ))
 
      (destination-path top-level-note-file-name)))))






; ---------------------------------------------------------------------------------------------------------------
; Functions for generation of note index (stikordsregister) from idx files.

; Collect all index words from relevant idx files.
; This function is roboust for non-existing idx files.
(define (all-index-words)
    (accumulate-right append '()
              (map (lambda (f) (if (file-exists? f) (file-read f) '()))
                   (map (lambda (f) (word-index-file-name f))  
                        (front-sublist lecture-list current-lecture)))))


(define (format-word-in-index index-element)
  ; an index element is of the form (word url)
 (if (= 3 (length index-element))
     (con (em (car index-element)) (horizontal-space 5) "(" (a-tag (cadr index-element) "Note") " " (a-tag (caddr index-element) "Slide") ")")
     (con (em (car index-element)) (horizontal-space 5) "(" (a-tag (cadr index-element) "Note") ")")))


(define (format-word-in-index index-element)
  ; an index element is of the form (word slide-url), (word note-url slide-url) or a string (initial letter)

 (cond ((string? index-element)  ; initial letter
           (con (p) (a-name (downcase-string index-element)) (font-size 5 (b index-element))))
  
       ((and (pair? index-element) (= 4 (length index-element)))
        (let ((kind (cadddr index-element))
              (term (car index-element)))
          (con (cond ((eq? kind 'title) term) ((eq? kind 'concept) (b term)) (else (i term)))
               (horizontal-space 5)
               "(" (a-tag (cadr index-element) "Note")  " " (a-tag (caddr index-element) "Slide") ")")))

       ((and (pair? index-element) (= 3 (length index-element)))  ; partically obsolete
        (let ((kind 'index)
              (term (car index-element)))
          (con (i term)
               (horizontal-space 5)
               "(" (a-tag (cadr index-element) "Note")  " " (a-tag (caddr index-element) "Slide") ")")))

       ((and (pair? index-element) (= 2 (length index-element))) ; obsolete
        (con (em (car index-element)) (horizontal-space 5) "(" (a-tag (cadr index-element) "Note") ")"))
       
       (else (error "format-word-index: Unrecognized index element"))

      ))

(define (about-the-word-index)
 (center
  (color-frame 
    (em 
      (text-choice
       (con-par "I det alfabetiske indeks er kursive ord egentlige indeksord,
              ikke-kursiverede ord er slideoverskrifter, og fede ord er begreber
              som er defineret i noterne." 
              "Via nedenstene listning af alfabetet kan man navigere til
              det nskede ord's begyndelsesbogstav." )
       (con-par "In this alphabetic index the words in italic are proper index words,
                 non-italic words are section headings, and words in bold face are concepts
                 defined in these notes."
                "In the alphabet listing below you can navigate to the desired initial
                 letter of a word"
       )
      )
    )
    grey2 )))

(define (make-lecture-word-index-pages index-list)
  ; write an index page for each letter in the alphabet
 (let* ((alphabetic-predicate (string-starting-with-predicate
                                          (list "a" "b" "c" "d" "e" "f" "g" "h" "i" "j" "k" "l" "m" "n" "o" 
                                                "p" "q" "r" "s" "t" "u" "v" "w" "x" "y" "z" "" "" ""
                                                "A" "B" "C" "D" "E" "F" "G" "H" "I" "J" "K" "L" "M" "N" "O" 
                                                "P" "Q" "R" "S" "T" "U" "V" "W" "X" "Y" "Z" "" "" "")))
        (alphabetic-index-list (filter (lambda (entry)
                                         (alphabetic-predicate (car entry)))
                                       index-list))
        (splitted-index-list (split-index (sort-list alphabetic-index-list index-elements-leq?)))
        (alphabet (map downcase-string (map first-letter-of (map caar splitted-index-list))))
       )

  ; Make overall index page:
  (write-text-file
    (page-1 
      (con lecture-title (con-space " Index:" notes-title))
      '()
      (con 
        (word-index-header) (br)
        (h 1 (con-space "Index:" notes-title))
        (h 3 (list-to-string (append lecture-author-info (list lecture-date)) ", ")) (p)
        (about-the-word-index) (p)
        (alphabetic-link-array-1 file-name-of-word-index alphabet) (p)

       (when-generated)
      )
      slide-background-color black black black )
   (destination-path file-name-of-word-index))

   ; Make individual index pages: 
   (map2 (lambda (index-list letter)
	   (make-single-letter-index index-list letter alphabet))
	 splitted-index-list
	 alphabet)

 )
)

; Generate a predicate which accepts a string starting with a letter in char-list.
; Char-list is either a list of single letter strings or chars
(define (string-starting-with-predicate char-list)
 (let ((char-list-1 (map as-string char-list)))
  (lambda (str)
   (if (empty-string? str)
       #f
      (let ((first-char (as-string (string-ref str 0))))
        (member first-char char-list-1))))))

(define (first-letter-of x)
  (as-string (string-ref (as-string x) 0)))

; Split the total index list alphabetically.
; The input list is supposed to be sorted alphabetically.
(define (split-index index-list)
  (sublist-by-predicate
    index-list
    (lambda (cur prev n) 
       (not (eq? (string-ref (as-string (decapitalize-string-nd (car cur))) 0)
                 (string-ref (as-string (decapitalize-string-nd (car prev))) 0))))))


(define (make-single-letter-index index-list letter alphabet)
  (write-text-file
   (page (string-append "Note index: letter " letter)
         (con
          (h 1 (con-space (text-choice "Indeks:" "Index:") notes-title))
          (h 2 (string-append (text-choice "Startbogstav: " "First letter: ") (as-string letter)))

          (alphabetic-link-array-1 file-name-of-word-index alphabet letter) (p)

          (indent-pixels 10
            (brl
              (map format-word-in-index index-list)))

          )
          white black black black
   )
   (destination-path (string-append file-name-of-word-index  "-"  (downcase-string letter))))
)  
     
(define (make-lecture-word-index-page index-list)
  ; write a page with the word index of this lecture
  (write-text-file
    (page-1 
      (con lecture-title (con-space " Index:" notes-title))
      '()
      (con 
        (word-index-header) (br)
        (h 1 (con-space "Index:" notes-title))
        (h 3 (apply con-space (append lecture-author-info (list lecture-date)))) (p)
        (about-the-word-index) (p)
        (alphabetic-link-array) (p)

       (indent-pixels 10
         (brl
          (map format-word-in-index
               (merge-lists
                 (sort-list index-list index-elements-leq?)
                 (list "A" "B" "C" "D" "E" "F" "G" "H" "I" "J" "K" "L" "M" "N" "O" 
                        "P" "Q" "R" "S" "T" "U" "V" "W" "X" "Y" "Z" "" "" "")
                 (lambda (e1 e2) (string<=? (decapitalize-string  (string-copy e2)) (decapitalize-string (string-copy  (car e1)))))
               )

          ))
       )
       (when-generated)
      )
      slide-background-color black black black )
   (destination-path file-name-of-word-index)))

;; Return a string which tells about the generating computer system.
;; Default: the empty string.
(define (generating-system)
 "")


(define (when-generated)
 (let* ((tm (current-time))
        (day (weekday tm))
        (dt (date-time tm))
        (date (car dt))
        (time (cadr dt)))
  (font-1 2 red (con (text-choice "Genereret: " "Generated: ") (capitalize-string-nd day) " " date ", " time (br)
                   (generating-system)))))




; return a total concatented list of all lecture note pages on idx format:
; (title-string idsymbol is-title-boolean page-number)
(define (all-idx)
 (accumulate-right
   append
   '()
   (map
    (lambda (lecture-id)
        (let* ((aux-file (aux-file-name lecture-id))
               (aux-contents (file-read aux-file)))
      (cdr aux-contents)))
    (front-sublist lecture-list current-lecture))))


; -----------------------------------------------------------------------------

; returns a string which provides for tracing of the
; underlying software and sources:
(define (file-and-directory-identification)
 (apply string-append
  (map format-key-value-pairs
   (list
     (list "LAML source file" (string-append note-source-directory lecture-id "." "laml"))
     (list "Scheme system" scheme-system)
     (list "Scheme library directory" the-library)
     (list "Style Scheme file" (string-append leno-software-directory "lecture-notes.scm"))
   ))))

(define (format-key-value-pairs el)
  (let ((key (car el))
        (val (cadr el)))
    (string-append (as-string key) ": " (as-string val) "; ")))

; a comment with tracing information.
; inserted on every generated laml page
(define (tracing-comment)
  (html-comment (file-and-directory-identification)))


; ---------------------------------------------------------------------------------------------------
; TRAIL STUFF:

(define lecture-trail-list '()) ; a list of two-element lists:
                                  ; such as ((gui litterature) (gui andre-komponenter))

(define trail-length 0) 

(define (slide-select lecture-id slide-id)
  (cons 'slide-select (list lecture-id slide-id)))

; User level trail function. Convenient syntactic top-level form.
; trail-id is a symbol identifying the trail.
; elements is a list of slide-select forms (mainly syntax). See the slide-select function.
; Generates, as a side-effect, a simple top-level index file
(define (note-trail trail-id . elements)
  (note-trail-1 trail-id elements)
  (if source-level-index-page? 
    (begin 
      (display-message (string-append "You can start browsing these lecture notes at " lecture-id "." target-extension)) 
      (make-source-level-index-page 'minimal)))

  ; Make trail-specific title and abstract page with proper continuation
  (if lecture-title-page? 
    (begin 
      (make-lecture-title-page (html-file (first-trail-slide-id trail-id lecture-trail-list)) "???")
      (make-lecture-abstract-page  (html-file (first-trail-slide-id trail-id lecture-trail-list)) "???")))
  )


; A programmatic variant of note-trail. Takes two regular parameter. Easier to call from a program.
(define (note-trail-1 trail-id elements)
  (let ((trail-list (map (lambda (e) (list (second e) (third e))) elements)))
   (set! lecture-trail-list trail-list)
   (set! trail-length (length trail-list))
   (make-trail trail-id trail-list)
   (make-trail-front-index trail-id (if (null? trail-list) #f (first (car trail-list))))
))

(define (slide-name-url-1 trail-id lecture-id slide-id)
  (if (and (eq? lecture-id 'nil) (eq? slide-id 'nil))
      ""
      (string-append (filename-of-trail-frame trail-id lecture-id slide-id) ".html")))

(define (filename-of-trail-navigation trail-id lecture-id slide-id)
  (string-append (as-string trail-id) "-TB-" (slide-name lecture-id slide-id)))

(define (filename-of-trail-frame trail-id lecture-id slide-id)
  (string-append (as-string trail-id) "-TF-" (slide-name lecture-id slide-id)))


(define (make-trail trail-id trail-list)
  ; trail-list is a list of pairs (lecture-id slide-id)
  (map5
    (lambda (e trail-id prev next current-number) 
       (make-trail-page trail-id (car e) (cadr e) (apply slide-name-url-1 (cons trail-id prev)) (apply slide-name-url-1 (cons trail-id next)) current-number)
    )
    trail-list
    (make-list (length trail-list) trail-id)
    (cons (list 'nil 'nil) trail-list)                ; previous list - first element has no previous
    (append (cdr trail-list) (list (list 'nil 'nil))) ; next list - last element has no next
    (number-interval 1 trail-length)
))



(define (make-trail-page trail-id lecture-id slide-id previous-page-url next-page-url current-trail-number)
  (let* ((slide-filename (slide-name lecture-id slide-id))
         (title (slide-title lecture-id slide-id))
         (navigation-filename (filename-of-trail-navigation trail-id lecture-id slide-id))
         (frame-filename (filename-of-trail-frame trail-id lecture-id slide-id))
         (trail-index-url (string-append (as-string trail-id) ".html"))
         (this-page-url (slide-name-url-1 trail-id lecture-id slide-id))
         (script (list (string-append leno-software-directory "javascript/") "lenonavigate.js"))
         (script-clause 
              (cond ((eq? javascript-loading 'static) (html4:script (read-text-file (string-append (car script) (cadr script)))))
                    ((eq? javascript-loading 'dynamic) (html4:script "" 'src (string-append "javascript/" (cadr script))))
                    (else (error "page-with-keypress-script in html-v1: problems determining type of script loading"))))
        )

     (if lecture-note-verbose-mode
         (display-message (string-append "Trail page " (as-string trail-id) ":" (as-string lecture-id)
                                          ":"  (as-string slide-id) " OK")))
     (write-text-file
      (if java-scripting
        (html4:html
         (con (html4:head (html4:title title))
              script-clause
              (con
               (html4:frameset 
                (con (html4:frame 'name "leno:navigation" 'src (string-append navigation-filename ".html")
                                 'scrolling "no" 'noresize "" 'frameborder "0" 'framespace "0") 
                     (html4:frame 'name "leno:main" 'src (string-append slide-filename ".html")
                                 'scrolling "auto" 'frameborder "0" 'framespace "0"))
                'cols "50,*" 'frameborder "0" 'border "0" 
                'onKeyPress  (js-call "lenoTrailframeNavigate" 
                                      (map string-it-single 
                                           (list previous-page-url
                                                 next-page-url
                                                 trail-index-url)))
                )
              )
              ))
         (html4:html
          (con (html4:head (html4:title title))
               (html4:frameset 
                (con (html4:frame 'name "leno:navigation" 'src (string-append navigation-filename ".html")
                                 'scrolling "no" 'noresize "" 'frameborder "0" 'framespace "0") 
                     (html4:frame 'name "leno:main" 'src (string-append slide-filename ".html")
                                 'scrolling "auto" 'frameborder "0" 'framespace "0"))
                'cols "50,*" 'frameborder "0" 'border "0" 
                )
               )))
      (destination-path frame-filename))

   (let ((body (center (con
                        (font-size 2 (b (con (as-string current-trail-number) ":" (as-string trail-length)))) (p)
                        (a-tag-target trail-index-url (img-LN "nav-contents-frame.gif" 
                                                              (text-choice "Oversigt over dette spor" "Overview of this trail")) "_top") (br)
                        (if (equal? previous-page-url "")
                            (img-LN "nav-up-frame-empty.gif" "")
                          (a-tag-target previous-page-url (img-LN "nav-up-frame.gif" 
                                                                  (text-choice "Forrige slide i dette spor" "Previous slide in this trail")) "_top")) (br)

                        (a-tag-target this-page-url (img-LN "nav-current-frame.gif" 
                                                            (text-choice "Nuvrende slide i dette spor" "Current slide in this trail")) "_top") (br)


                        (if (equal? next-page-url "")
                            (img-LN "nav-down-frame-empty.gif" "")
                          (a-tag-target next-page-url (img-LN "nav-down-frame.gif" 
                                                              (text-choice "Nste slide i dette spor" "Next slide in this trail")) "_top"))
                        ))))
     (write-text-file
      (if java-scripting
           (page-with-keypress-script
            "navigation"
            '()
            body

            javascript-loading
            (list (string-append leno-software-directory "javascript/") "lenonavigate.js")
            (js-call "lenoTrailbarNavigate" 
                                 (map string-it-single 
                                       (list previous-page-url
                                             next-page-url
                                             trail-index-url)))

            slide-background-color black black black
            mouse-advancement
          )

          (page "navigation"
                body
                slide-background-color black black black))
      (destination-path navigation-filename)))
  )
)


; make and write the top level front page index for trails
; surrounding-lecture-id is the lecture id of the first slide in the trail.
(define (make-trail-front-index trail-id surrounding-lecture-id)
  (write-text-file
   (page-1
    notes-title
    '()
    (con 
     (index-page-header) (br)
     (h 1 lecture-title)
     (h 3
       (con 
        (list-to-string
         (map (lambda (e) (con e (br))) (append lecture-author-info (list lecture-date)))
         ""
        )
       )
     ) (p)

     ; guiding text with possible link to containg index:
     (let ((containing-index-url 
             (if (and (= (length lecture-list) 1) surrounding-lecture-id)
                 (html-file (index-name surrounding-lecture-id))
                 #f)))
      (cond ((> (length lecture-list) 1)
              (em (text-choice "Disse slides er et spor, som er lagt ned over et antal lektioner i samlingen af forelsningsnoter"
                               "These slides is a trail imposed on a number of lectures in a collection of lecture notes")))
            ((and (= (length lecture-list) 1) containing-index-url)
              (em (text-choice (con "Disse slides er et spor, som er lagt ned over " (a-tag containing-index-url "en strre samling af slides og forelsningsnoter") )
                               (con "These slides form a trail imposed on " (a-tag containing-index-url "a larger collection of slides and lecture notes") ))))
            ((= (length lecture-list) 1)
              (em (text-choice "Disse slides er et spor, som er lagt ned over en strre samling af slides og forelsningsnoter"
                               "These slides form a trail imposed on a larger collection of slides and lecture notes")))
            (else ""))
     ) (horizontal-space 24)

     (if lecture-title-page?
         (a-tag
	  (html-file (title-page-name lecture-id))
	  (text-choice "Forside af spor" "Trail title page")
	  )
	 "")
     (horizontal-space 12)

     (if lecture-title-page?
	 (a-tag
 	  (html-file (abstract-page-name lecture-id))
	  (text-choice "Sammendrag af spor" "Trail abstract")
	 )
	"")
     (p)

     (table-1 1
        '(400 70 90 390)
        (make-list 4 slide-background-color)
        (map2 
          (lambda (lectureid-slideid number) ; number not used...
            (let* ((original-slide-id (cadr lectureid-slideid))
                   (original-lecture-id (car lectureid-slideid))
                   (slide-descr (find-original-slide-info original-lecture-id original-slide-id))
                   (original-chapter-title (find-original-chapter-title original-lecture-id))
                   (slide-title (car slide-descr))
                   (slide-section-start? (caddr slide-descr))
                   (the-page-number (if (= 4 (length slide-descr)) (fourth slide-descr) "-"))
                  )
               (list (if slide-section-start?
                         (font-color red (b slide-title))
                         slide-title)
                     (con (text-choice "Side " "Page ") (as-string number))
                     (a-tag-target 
                        (string-append (filename-of-trail-frame trail-id original-lecture-id original-slide-id) ".html")
                        "Trail slide"
                        "_top")
                     (con original-chapter-title (con ", " (text-choice "side " "page ") (as-string the-page-number)))

               )))

          lecture-trail-list (number-interval 1 (length lecture-trail-list)))) (p)

     (when-generated)
   )
   white black blue blue)
   (destination-path (as-string trail-id)))
)

(define (find-original-slide-info lecture-id slide-id)
  ; lookup the record in the aux-file
  (let ((aux-file (aux-file-name lecture-id)))
    (if (file-exists? aux-file)
        (let* ((aux-contents (file-read aux-file))
               (res (find-in-list 
                      (lambda (el) (eq? (cadr el) slide-id))
                      (cdr aux-contents))))
          (if res res (error (string-append "find-original-slide-info: Did not find " (as-string slide-id)
                                            " in aux file of lecture " (as-string lecture-id)))))
        (error (string-append "find-original-slide-info: Did not find aux file of " (as-string lecture-id))))))

(define (find-original-chapter-title lecture-id)
  (let ((aux-file (aux-file-name lecture-id)))
    (if (file-exists? aux-file)
        (let ((aux-contents (file-read aux-file)))
           (car aux-contents))
        "???")))



; ----------------------------------------------------------------------------------------

;;; Trail utility functions. 
;;; A trail is definition of a sequence of existing lecture pages from different lectures in a collection.
;;; In a trail it is possible to select slides from different chapters, and to adjust the sequencing among these.
;;; A trail can be defined very conveniently by simple mentioning the lecture-id and page-id of each slide, we want
;;; to include in the trail.<p>
;;; 
;;; The main function in this utility is total-trail. This function makes a total trail of all the slides in the
;;; lecture set. Bring the trail description into a text editor, and delete unwanted slides, and reorder them as appropriate.
;;; This facility uses the philosophy that it is always easier to delete something existing than writing somthing new. <p>
;;;
;;; Usage: Se the next section of this documentation.
 

;; Return a full trail of the lecture with lecture-id
(define (full-trail lecture-id)
  (let* ((aux-file (aux-file-name lecture-id))
         (aux-contents (file-read aux-file)))
   (accumulate-right 
      (lambda (x y) (string-append x CR  y))
      ""
      (map trace-entry-pretty-print (map (lambda (entry) (list 'slide-select lecture-id  (cadr entry))) (cdr aux-contents))))))

(define (trace-entry-pretty-print entry)
  (string-append "(" (as-string (car entry)) " " "'" (as-string (cadr entry)) " " "'" (as-string (caddr entry)) ")"))

;; Return a full trail of all slides in all lectures in the lecture-list
(define (total-trail)
  (accumulate-right
    (lambda (x y) (string-append x CR y))
    ""
    (map full-trail (front-sublist lecture-list current-lecture))))


; -----------------------------------------------------------------------------
; Return a list of all cross references in this set of lectures
; Requires that a prefix, lectures until current-lecture, has  been processed
(define (all-cross-references)
  ; collect all cross references from -.crs files
    (accumulate-right append '()
              (map file-read 
                   (map (lambda (f) (cross-ref-file-name f))  ; before: (string-append note-source-directory f ".crs")
                        (front-sublist lecture-list current-lecture)))))


; make a separate page with cross references
; presumably, depending on the parameter, with all cross references in these notes
(define (make-total-cross-references-page total-cross-ref-list)
 (let ((formatter-function (generate-cross-reference-formatter slide-url)))
  (write-text-file
    (page-1 
      (con lecture-title (con-space "Cross references:" notes-title))
      '()
      (con
        (h 1  (con-space "Cross references:" notes-title))
        (brl
          (map book-text (glue-ref-and-hint (map formatter-function total-cross-ref-list)))))
      slide-background-color black black black)
   (destination-path "REFERENCES"))))


; -----------------------------------------------------------------------------

(define (display-warning message)
  (if lecture-note-verbose-mode
      (begin (display (string-append "Warning: " message)) (newline))))



; ---------------------------------------------------------------------------------------------------------------

;;; Utility functions for interactive processing of lectures notes. 
;;; Here we provide for Scheme functions which are able to process one or more lecture notes. The functions
;;; laml-process-all and laml-process-all-1 are useful for programmatic processing of all lectures in a set of notes.<p>
;;; 
;;; Practical procedure:
;;; <ul>
;;;   <li> Start up and interactive LAML and Scheme session from the directory where the lecture notes sources are located, for instance
;;;        by calling M-x run-laml-interactively from Emacs. 
;;;   <li> Define the prepare-interactive-processing (see below) function in your scheme system by loading it from lecture-notes.scm. 
;;;   <li> Call the function prepare-interactive-processing (without parameters). This will load the necessary software for you.
;;;   <li> Finally call the function laml-process-all without parameters, or activate other utility functions such as 
;;;        (check-all-note-references) or (total-trail).
;;; </ul>

;; Load this function in order to prepare processing of lecture notes. This function loads the necessary software.
;; As a precondition, assume that this function is called from a context where LAML is started up, for instance
;; via run-laml-interactively via Emacs.
(define (prepare-interactive-processing)
 (let ((note-dir (startup-directory)))
   (load (string-append laml-dir "laml.scm"))
   (if (file-exists? (string-append note-dir "notes.scm"))
       (load (string-append note-dir "notes.scm"))
       (display-messag "Cannot find notes.scm")
   )
   (laml-style "lecture-notes/lecture-notes")
   (if (file-exists? (string-append note-dir "post-notes.scm"))
       (load (string-append note-dir "post-notes.scm"))
       (display-messag "Cannot find post-notes.scm")
   )))


;; Process a single lecture, identified with the symbol section-name, n times.
;; Recall that a lecture must be processed at least twice in order to settle cross references.
(define (laml-process section-name . n)
  ; proces the laml files n times
 (let ((n-times (if (null? n) 1 (car n))))
  (laml (string-append (as-string section-name) ".laml"))
  (if (> n-times 1)
      (laml-process section-name (- n-times 1)))))

;; Process all lectures in section list n times
(define (laml-process-list section-list . n)
  ; laml process all functions in section-list
  (let ((n-times (if (null? n) 1 (car n))))
    (map (lambda (s) (laml-process s n-times)) section-list)))

;; Process all lectures in lecture-list two times. 
;; This povides for a total regeneration given that lecture-list and current-lecture are
;; defined in the file notes.scm. The definition of these variables normally takes places in notes.scm
(define (laml-process-all)
 (laml-process-list (front-sublist lecture-list current-lecture) 2))

;; Process all lectures in lecture-list once.
;; This function is similar to laml-process-all, but it only process each lecture once.
(define (laml-process-all-1)
 (laml-process-list (front-sublist lecture-list current-lecture) 1))

; ---------------------------------------------------------------------------------------------------------------
;;; Utility for checking note cross references. 
;;; It is possible to make cross references from one note page to another via a cross-references clause.
;;; This utility checks that all cross references of type note-reference has a well-defined target in the current
;;; lecture notes. The check depends on the information in the aux files (with an entry pr. slide) and the crs files
;;; (with an entry pr. cross reference). This utility does not check internet-references. Informal references cannot
;;; by checked, or course.
;;; The top level function of this utility is check-all-note-references.
;;; We also list a set of other useful functions, which is used internally in check-all-note-references.
;;; The execuction of the check procedure is now integrated in LENO such that the checking is done during
;;; the processing of each lecture. Be aware that some forward references may result in unnecessary warnings.

;; Return a list of all pages on the form (lecture-id page-title-string page-id-symbol whether-section-or-not page-number-in-section).
;; Lecture-list is a list of lecture-ids (strings) to consider.
;; You can use this function on (map car lecture-sections) to get a complete list of slide pages.
(define (all-page-info lecture-list)
  (accumulate-right
    append
    '()
    (map (lambda (lecture)
           (let* ((aux-file (string-append note-source-directory "internal/" (as-string lecture) ".aux"))
                  (pages (if (file-exists? aux-file) 
                             (cdr (file-read aux-file))
                             '()
                         )
                  )
                 )
             (map (lambda (p) (cons (as-symbol lecture) p)) pages))
         )
         lecture-list)))

; check a single note reference on the form (note-reference "Title" lecture-id page-id), as found in -.crs files
; against the information in the aux files. The list of all information in the aux files must be passed
; as the second parameter to this function. The function all-page-info returns this information.
; Return either #t or #f
(define (check-a-note-reference note-ref aux-info)
  (let ((res (member-by-predicate note-ref aux-info
                                  (lambda (nr aux)
                                    (let ((nr-lecture (cross-ref-lecture-id nr))
                                          (nr-page (cross-ref-page-id nr)))
                                      (and (eq? nr-lecture (first aux)) (eq? nr-page (third aux))))))))
   (if res #t #f)))

; Check a specific lecture for cross reference problems regarding note-references.
; Return those entries in a crs files which cause problems (undefined references).
; Only note-references are handled in this version.
; The list of all information in the aux files must be passed as the second parameter to this function.
; The function all-page-info returns this information.
(define (check-crs-file lecture aux-info)
  (let* ((crs-contents (file-read (cross-ref-file-name lecture))) ; before:  (string-append note-source-directory (as-string lecture) ".crs")
         (crs-contents-note-refs (filter (lambda (nr) (eq? 'note-reference (car nr))) crs-contents)))
    (filter
      (lambda (nr)
        (let ((check (check-a-note-reference nr aux-info)))
          (not check)))
      crs-contents-note-refs)))

; Check all lectures in lecture list of note-references, as done by check-crs-file
; Return a list of references which cause problems. Not used.
(define (check-crs-files lecture-list aux-info)
  (accumulate-right
    append
    '()
    (map (lambda (f) (check-crs-file f aux-info)) lecture-list)))

;; Check all note references in the lectures in lecture-sections.
;; Report on problems found on standard output.
;; This function can conveniently be called after the activation of laml-process-all.
;; See directions of use in the neighborhood of laml-process-all.
(define (check-all-note-references)
 (let* ((lectures (map car lecture-sections))
        (aux-info (all-page-info lectures)))
  (display "For each lecture, we return a list of unresolved note-references")
  (display #\newline)
  (for-each
    (lambda (lecture)
       (display (string-append (as-string lecture) ": "))
       (display (as-string (check-crs-file lecture aux-info)))
       (display #\newline) (display #\newline) )
    lectures)))


; ---------------------------------------------------------------------------------------------------------------

; Return text followed with keyboard shortcut information
(define (key-shortcut text shortcut-letter-string)
  (if java-scripting
      (string-append text CR (text-choice "Tastaturgenvej: " "Keyboard shortcut: ")
                     (string-it-single shortcut-letter-string))
      text))

; ---------------------------------------------------------------------------------------------------------------

; Help and about page:

(define (make-leno-help-page)
 (let ((kn-email "normark@cs.auc.dk")
       (kn-www "http://www.cs.auc.dk/~normark/")
       (down-shortcuts (font-size 2 "A number in the interval 1..9")))
  (write-text-file
    (page-1 
      "LENO Help Page"
      '()
      (con-par
       (h 1 "The LENO Help and About page")

       (narrow p 750

         "The LENO system is made to support the authoring of lecture notes, organized
         in a number of chapters (or lectures). The top-level page refers to each lecuture
         in the material. Each lecture, in turn, refers to a number of pages."
         
         "As an important characteristics of LENO, each page can be shown
         in three different views:"
   
         (ul-1 (list       
         "A slide view"
         "An annotated slide view"
         "An aggregated lecture view"))
         
         (con-space "In " (em "slide view") " the primary information on a page is shown using
         a large font, hereby making it attractive to present the information
         from browser via a projector in an auditorium.")
         
         (con-space "In the " (em "annotated slide view") " the primary information is shown with
         a number of annotations, which are associated with the individual
         constituents of a slides. As in slide view, a single page is shown
         in isolation from all other pages, but links to the previous and 
         the next page exists.")
         
         (con-space "An " (em "aggregated lecture view") " shows the primary slide information
         and the annotations of all pages in a lecture. Thus, in this view, the pages 
         of a lecture are all aggregated into a single 'lecture page'.
         The information contents of this view is the same as the sum of
         the information of the all annotated slides in a single lecture.")

         (con "In addition, LENO supports generation of an " (em "automatically progressing slide show with the teacher's speaker sound") ".
          For this to work, the author needs to record the speaker sound and prepare the sequencing and timing
          of the individual pages in the show.
          An automatically progressing slide show with speaker sound is started from the lecture overview page,
          with one of the small speaker icons or from
          one of the textually anchored links just above the note page table. The slide show brings you through selected slide pages, 
          programs, and image series. Notice that some of the slide pages my be visited more than once (such as before and
          after an external program page or image series - with different speaker sounds). The speaker sound is streamed to
          your browser, and currently it relies on RealPlayer from " (a-tag "http://www.real.com") ". For setup see for instance
          " (a-tag "http://video.auc.dk/" "Aalborg University's video pages") ".
         ")
         
         "The navigation icons used in LENO should be relatively straightforward to
         understand. Nevertheless, here we present an overview of the icons
         together with a brief explanation:"
       )

       (table-3
         1
         (list 100 150 500)
         (list
          (map b (list "Icon" "Keyboard shortcut" "Explanation"))
          (list (img-LN "nav-up.gif" "") "u" "Go up one strutural level towards the top-level page") 
          (list (img-LN "nav-left.gif" "") "p" "Go to the previous page. The icon is also used to navigate
                                                from one lectures to the previous lecture.") 
          (list (img-LN "nav-right.gif" "") "n, CR" 
                                                 (string-append "Go to the next page. The icon is also used to navigate
                                                 from one lectures to the next lecture and other similar purposes."
                                                 (cond ((eq? mouse-advancement 'double-press) 
                                                          "This navigation can also be activated by a double click on the background (Internet Explorer only).")
                                                        ((eq? mouse-advancement 'single-press) 
                                                          "This navigation can also be activated by a single click on the background (Internet Explorer only).")
                                                        (else ""))
                                                 ) )
          (list (img-LN "todisk.gif" "") (em "no shortcut") "Go to a download page, which allows access to
                                             a zip file with all the files making up the set set of lectures.") 
          (list (img-LN "index.gif" "") (em "no shortcut") "Go to a page with an alphabetic index of the lecture notes
                                            covering all lectures.") 
          (list (img-LN "question.gif" "") (em "no shortcut") "Go to this page") 
          (list (img-LN "nav-home.gif" "") (em "no shortcut") "Go to the page designated as the home page of these lecture notes.") 
          (list (img-LN "nav-book.gif" "") (em "no shortcut") "Go to particular page in the aggregated lecture view") 
          (list (img-LN "nav-notes.gif" "") "t" "Go to the annotated slide view from the slide view.") 
          (list (img-LN "nav-slide.gif" "") "t" "Go to the slide view from the annotated slide view.") 
;          (list (img-LN "arrow-down.gif" "") (em "no shortcut") "Go to the bottom of the current page.") 
;          (list (img-LN "arrow-up.gif" "") (em "no shortcut") "Go to the top of the current page.") 
          (list (img-LN  "exclamation.gif" "") (em "no shortcut") "Go to the readers comments on this page. Also allows you to post your own comments.
                                                                   This is a link to an annotation server which is external to LENO.") 
          (list (img-LN  "exclamation-red-ring.gif" "") (em "no shortcut") "As above - but there is at least one existing comment to this page.") 
          (list (img-LN  "no-frames.gif" "") (em "no shortcut") "If the current page is within a frame set, then break out from it. If not, nothing happens.") 


          (list (img-LN (program-icon-name 'english 'small) "") down-shortcuts "Go to a source program") 
          (list (img-LN (exercise-icon-name 'english 'small)  "") down-shortcuts "Go to an exercise") 
          (list (img-LN (image-series-icon-name 'english 'small) "") down-shortcuts "Go to an image series") 
          (list (img-LN (elucidator-icon-name 'english 'small) "") (em "no shortcut") "Go to an elucidator, which explains a program") 
          
          (list (img-LN "atomspin.gif" "") (em "no shortcut") "Symbolizes an automatic slide show, possibly with speaker sound.
                                                               By clicking the symbol the automatic slide show stops.") 
          (list (img-LN "atomspin-freeze.gif" "") (em "no shortcut") "Symbolizes a stopped slide show.
                                                                      By clicking this symbol the automatic slide with possible 
                                                                      speaker sound show starts.")
          (list (img-LN "nav-right-red.gif" "") (em "no shortcut") "Go to the next page in an automatically progressing slide show
                                                                    (with speaker sound). Accross a number of pages, 
                                                                     these arrow symbols trace the 'dynamic
                                                                     chain' of a slide show as opposed to the yellow arrow symbols
                                                                     that navigate the static page structures.")

          (list (img-LN "speaker.gif" "") (em "no shortcut") "Plays the speaker sound of a single slide page.")
          (list (img-LN "small-speaker.gif" "") (em "no shortcut") "A symbol shown in a lecture index which links to a particular
                                                                    place in an automatic slide show.")

          (list (img-LN "nav-contents-frame.gif" "") "U" "Go to the table of contents of a trail") 
          (list (img-LN "nav-up-frame.gif" "") "P" "Go to the previous slides in a trail") 
          (list (img-LN "nav-current-frame.gif" "") (em "no shortcut") "Go to the current slide in a trail") 
          (list (img-LN "nav-down-frame.gif" "") "N, Space" "Go to the next slide in a trail") 

         )
       )

       (narrow p 750

         "The last four, red icons are used in the LENO trail facility. Using a LENO trail it is
          possible to define a sequence of slides from selected slides in a number of sections. The
          trail determines the selection and the sequence of slides. This is useful if you want to present
          a subset of your slides for some purpose, and if you don't want to deal with multiple copies (which is usually a bad solution).
          The LENO trail facilities is realized via use of HTML frames. The red icons from above
          are all shown in a frame of its own (in the leftmost margin), the trail navigation frame. Notice that
          you can navigate freely in the slide trail while maintaining the context of the trail."
  
          "The keyboard shortcuts only work in Internet Explorer 4.0 and higher (from Microsoft).
           The keyboard shortcuts of programs, exercises, and image series are integers in the range 1..9, corresponding
           to the sequence of these on a slide or annotated slide."
  
          (con-space "The collection of html WWW pages, which constitute a set of lecture notes, are generated from a source
           file written in the programming language Scheme. Scheme is a language
           in the Lisp family of languages. We use Scheme as a markup language.
           In a Scheme-based language it is easy to define your own markup
           elements by means of abstraction. The underlying system, called LAML
           (Lisp Abstracted Markup Language) is described in further detail in"
           (a-tag "http://www.cs.auc.dk/~normark/laml/" "The LAML home page") ".")
    
           (con-space "Kurt Nrmark" (br) "Aalborg University" (br) kn-email (br) (a-tag kn-www))

      )

      )

      white black black black)
   (destination-path "leno-help-and-about"))))


; ---------------------------------------------------------------------------------------------------
; Pre-scanning of a note page for programs, images, and exercises which requires down-links.

(define (down-links note-page-elements lecture-id page-id presentation-kind)
  (let ((down-elements (down-link-elements note-page-elements)))
    (map 
      (lambda (down-el)
        (let ((kind (car down-el))
              (num (cadr down-el)))
          (local-html-url
           (if (eq? kind 'images)
               (page-element-name lecture-id page-id presentation-kind kind num 1)
               (page-element-name lecture-id page-id presentation-kind kind num)))))
      down-elements)))


; Return a list of image/exercise/program elements found on the note page with note-page-elements.
; The elements of the result is of the form (kind number). Kind is one of the symbols program, images, and exercises.
; Number is a positive integer describing the number of kind on the notepage.
(define (down-link-elements note-page-elements)
 (add-down-link-seq-numbers
   (filter symbol?
    (map down-link-entry note-page-elements))))

(define (add-down-link-seq-numbers lst)
  (reverse (add-down-link-seq-numbers-1 lst 1 1 1 '())))

; Add sequence numbers to the program/exercise/images symbols.
; pn, en, and in are counters (next numbers)
(define (add-down-link-seq-numbers-1 lst pn en in res)
  (cond ((null? lst) res)
        ((eq? (car lst) 'program) (add-down-link-seq-numbers-1 (cdr lst) (+ 1 pn) en in (cons (list 'program pn) res)))
        ((eq? (car lst) 'exercise) (add-down-link-seq-numbers-1 (cdr lst) pn (+ 1 en) in (cons (list 'exercise en) res)))
        ((eq? (car lst) 'images) (add-down-link-seq-numbers-1 (cdr lst) pn en (+ in 1) (cons (list 'images in) res)))
        (else (error (string-append "add-down-link-seq-numbers-1: Unknown kind of tag: " (as-string (car lst)))))))

(define (down-link-entry note-page-element)
 (let ((kind (element-tag note-page-element))
       (contents (element-contents note-page-element))
      )
  (letrec ((external-program? (lambda (c) (eq? 'slide-external (car (fourth c)))))
           (external-images? (lambda (c) (eq? 'slide-external (car (third c)))))
          )
    (cond ((and (eq? kind 'source-program) (external-program? contents)) 'program)
          ((eq? kind 'exercise) 'exercise)
          ((and (eq? kind 'image-series) (external-images? contents)) 'images)
          (else #f)))))
    
; ---------------------------------------------------------------------------------------------------
; Exercise sheet:


(define (make-exercise-index lecture-exercise-list)
  ; write a page with a pr. lecture exercise index
  (write-text-file
    (page-1 
      (con lecture-title " " (con-space (text-choice "Oversigt over opgaver" "Exercise index")))
      '()
      (con 
        (exercise-index-header) (br)
        (h 1 
         (con-space 
           (text-choice "Opgaver" "Exercises") (br)
           lecture-title))

        (a-tag (html-file (all-exercises-name lecture-id))
               (text-choice "Alle lektionen's opgaver p n side" "All exercises in this lecture on a single page"))
        (if (do-reveal-exercise-solutions?)
            (con (br) 
                 (a-tag (html-file (all-exercises-and-solutions-name lecture-id))
                                   (text-choice "Alle lektionen's opgaver og lsninger p n side"
                                                "All exercises and solutions in this lecture on a single page")))
            "")
             (p)

        (table-3
          1
          (if (do-reveal-exercise-solutions?)  (list 100 400 130)  (list 100 400))
          (map exercise-index-entry (reverse lecture-exercise-list)))

       (p)

       
     (if (and exercise-manager-support?)
         (if (<= (current-time) (lecture-exercise-reveal-time lecture-id))
	   (let* ((tm (lecture-exercise-reveal-time lecture-id))
		  (day (weekday tm))
		  (dt (date-time tm))
		  (date (car dt))
		  (time (cadr dt))
		  )
	     (font-1 3 red (string-append "Lsningerne til opgaverne i denne lektion vil tidligst blive gjort tilgngelige " day ", " date " klokken " time)))
           "")
         "")  (p)


       (when-generated)
      )
      slide-background-color black blue blue)
   (destination-path  (exercise-index-name lecture-id))))

(define (exercise-index-entry entry)
  (let ((ex-id (first entry))
        (title (second entry))
        (page-id (third entry))
        (number-on-page (fourth entry))
        (number-in-lecture (sixth entry))
        (solution (seventh entry)))
   (let ((txt (b (string-append (text-choice "Opgave" "Exercise") " " (as-string lecture-number) "." (as-string number-in-lecture))))
         (ex-link (a-tag (string-append 
                           ((if exercise-manager-support? exercise-frame-name  exercise-name) lecture-id page-id 'note number-on-page) ".html") title))
         (sol-link (if (not (equal? "" solution))
                       (a-tag (html-file (exercise-solution-name lecture-id page-id number-on-page)) (text-choice "Lsning" "Solution"))
                       (em (font-size 2 (text-choice "Ingen tilgngelig lsning" "No solution available"))))))

   (if (do-reveal-exercise-solutions?)         
       (list txt ex-link sol-link)
       (list txt ex-link) ))))




; ---------------------------------------------------------------------------------------------------------------
; The overall exercise index

(define (make-overall-exercise-index)
; Write a page with an overall exercise index, covering all lectures.
; Take the information from the -.exc files in the internal directory.
; The index covers from lecture one to lecture current-lecture.
   (let ((external-exercise-entries
            (lecture-wide-exercise-list))
         )
    (write-text-file
     (page-1 
      (con lecture-title " " (con-space (text-choice "Oversigt over opgaver" "Exercise index")))
      '()
      (con 
       (overall-exercise-index-header) (br)
       (h 1 
	  (con-space 
           (text-choice "Opgaver" "Exercises") (br)
           notes-title))
              

       (table-3
	1
	(if (and reveal-all-solutions? (do-reveal-exercise-solutions?)) 
            (list 190 100 400 130)
            (list 190 100 400))
	(map overall-exercise-index-entry external-exercise-entries))

       (p)

       (font-size 2
        (em
         (text-choice "Evt. lsninger kan findes via den lektionsspecifikke opgave side (frste sjle)"
                      "Possible solutions can be found on the lecture specific exercise page (first column)"))) 

       (p)

       (when-generated)
       )
      slide-background-color black blue blue)
     (destination-path overall-exercise-index-name))))


(define (lecture-wide-exercise-list)
  (accumulate-right 
   append 
   '()
   (map (lambda (g) (if (file-exists? g) (file-read g) '()))
	(map (lambda (f) (exercise-idx-file-name f))
	     (front-sublist lecture-list current-lecture)))))

; A page with all exercises in a lecture together.
; Good for printing
(define (make-all-exercise-page lecture-list header-danish-english entry-function file-function)
  (write-text-file
    (page-1 
      (con lecture-title " - " (con-space (text-choice "Alle opgaver" "All exercises")))
      '()
      (con 
        (all-exercise-page-header) (br)
        (h 1 
         (con-space 
           (apply text-choice header-danish-english) (br)
           lecture-title)) 
 
        (p) (hr-1) (p)

        (accumulate-right 
          string-append ""
          (map entry-function (reverse lecture-exercise-list)))

       (p)

       (when-generated)
      )
      slide-background-color black blue blue)
   (destination-path (file-function lecture-id))))

; A single exercise entry, for the aggregation of all exercises in a single page.
(define (exercise-formulation-entry entry)
 (let* ((ex-id (first entry))
        (title (second entry))
        (page-id (third entry))
        (number-on-page (fourth entry))
        (body (fifth entry))
        (number-in-lecture (sixth entry))
        (solution (seventh entry))
        (solution-url (if (not (equal? "" solution)) (exercise-solution-url lecture-id page-id number-on-page) "")))
   (con (font-1 5 blue (b (con (as-string lecture-number) "." (as-string number-in-lecture) (horizontal-space 3) title)))
        (vertical-space 1)
        (indent-pixels 5
          (font-1 3 black body))
        (vertical-space 1)
        (if (and (do-reveal-exercise-solutions?) (not (equal? solution-url ""))) (a-tag solution-url (text-choice "Lsning" "Solution")) "")
        (p) (hr-1) (p))))

; A single exercise entry, for the aggregation of all exercises together with solutions in a single page.
(define (exercise-formulation-solution-entry entry)
 (let* ((ex-id (first entry))
        (title (second entry))
        (page-id (third entry))
        (number-on-page (fourth entry))
        (body (fifth entry))
        (number-in-lecture (sixth entry))
        (solution (seventh entry))
       )
   (con (font-1 5 blue (b (con (as-string lecture-number) "." (as-string number-in-lecture) (horizontal-space 3) title)))
        (vertical-space 1)
        (indent-pixels 5
          (con 
            (font-1 3 black body)))

        (if (not (equal? solution ""))
            (con
               (p)
               (font-1 4 blue (b (text-choice "Lsning" "Solution"))) (br)
               (indent-pixels 5
		  (font-1 3 red solution)))
            "")
        (p) (hr-1) (p))))

; The presentation of an exercise in the overall exercise table, covering all lectures
(define (overall-exercise-index-entry entry)
  (let ((ids (first entry))
        (title (second entry))
        (p-numbers (third entry))
        (solution-status (fourth entry))
       )
   (let* ((lec-id (first ids))
          (page-id (second ids))
          (sl-number (fourth ids))
          (main-number (car p-numbers))
          (sub-number (cadr p-numbers)))
    (let ((txt (if (= sub-number 1) 
               (let ((lecture-title (list-ref lecture-titles (- main-number 1))))
                 (a-tag (html-file (exercise-index-name lec-id)) lecture-title))
               (horizontal-space 1)))
          (ex-num (string-append (text-choice "Opgave" "Exercise") " " (as-string (car p-numbers)) "." (as-string (cadr p-numbers))))
          (ex-titl-link (a-tag (html-file ((if exercise-manager-support? exercise-frame-name  exercise-name) lec-id page-id 'note sl-number)) title))
          (sol (if (eq? solution-status 'solution)
                   (a-tag (html-file (exercise-solution-name lec-id page-id sl-number)) (text-choice "Lsning" "Solution"))
                   (em (font-size 2 (text-choice "Ingen tilgngelig lsning" "No solution available"))))))
     (if (and reveal-all-solutions? (do-reveal-exercise-solutions?)) 
         (list txt ex-num ex-titl-link sol)
         (list txt ex-num ex-titl-link))))))


; ---------------------------------------------------------------------------------------------------------------
; External exercise index on exc files in the internal directory.
; Format: list of ((lecture-id page-id exercise-id number-on-slide) title (lecture-number number-in-lecture))
; The first part contains enough information to form an exercise-url via the function exercise-name.
; (Notice that exercise-id is not used - this is a little strange, but it is a consequence of the
; note page (sub)element naming scheme as implemented by the function page-element-name.

; Return the full path of an exc file for id. 
; This is the file which contains info about exercercises in a given lecture
; Id defaults to the value of the global varible lecture-id
(define (exercise-idx-file-name . id)
 (let ((id-1 (if (null? id) (as-string lecture-id) (as-string (first id)))))
   (string-append note-source-directory "internal/" id-1 "." "exc")))

; Defines the format of a single entry in the saved exercise list
(define (make-external-exercise-entry lecture-exercise-list-entry)
  (let ((ex-id (first lecture-exercise-list-entry))
        (title (second lecture-exercise-list-entry))
        (page-id (third lecture-exercise-list-entry))
        (ex-numb-on-slide (fourth lecture-exercise-list-entry))
        (body (fifth lecture-exercise-list-entry))
        (ex-numb-in-lecture (sixth lecture-exercise-list-entry))
        (solution (seventh lecture-exercise-list-entry))
       )
   (list (list (as-symbol lecture-id) (as-symbol page-id) (as-symbol ex-id) ex-numb-on-slide)
         title
         (list lecture-number ex-numb-in-lecture)
         (if (equal? "" solution) 'no-solution 'solution))))


(define (save-exercise-info lecture-exercise-list)
 (let ((lecture-exercise-list-1 (map make-external-exercise-entry (reverse lecture-exercise-list))))
   (if (file-exists? (exercise-idx-file-name))
       (delete-file (exercise-idx-file-name)))

   (with-output-to-file (exercise-idx-file-name)
       (lambda () (write lecture-exercise-list-1)))))


; return the stored exercise info list (the list stored in a -.crs file).
(define (exercise-info-list lect-id)
  (let ((crs-file (exercise-idx-file-name lect-id)))
    (if (file-exists? crs-file)
        (file-read crs-file)
        '())))


(define (make-exercise-manager-control-center lecture-id)
  (write-text-file
    (page-1 
      (con lecture-title " - " "Exercise Manager Control")
      '()
      (con 
        (h 1 
          (con lecture-title (br) "Exercise Manager Control"))
 
        (p) (hr-1) (p)

       (a-tag (exercise-manager-url
                "exercise-companion-summary.cgi"
                (list 'lecture-id)
                (list lecture-id))
              "Statistik over velsesgang") (p)

       (a-tag (exercise-manager-url
                "exercise-companion-status.cgi"
                (list 'lecture-id)
                (list lecture-id))
              "Liste over alle indsendte bidrag") (p)

       (a-tag (exercise-manager-url
                "exercise-companion-status.cgi"
                (list 'lecture-id 'status-kind)
                (list lecture-id "problems"))
              "Liste over alle problemer i alle grupper") (p)

       (a-tag (exercise-manager-url
                "exercise-control-desk.cgi"
                (list 'lecture-id 'exercise-list)
                (list lecture-id  (list-to-string (map (compose as-string first) lecture-exercise-list) (as-string #\$)))
              )
              (b "Exercise Manager Control Desk")) (p)

       (p) (hr-1) (p)

       (when-generated)
      )
      slide-background-color black blue blue)
   (destination-path (em-control-name lecture-id))
 ))

; ---------------------------------------------------------------------------------------------------
; Show and speak functions

; Return a list of speak clause specifications.
; lecture-id and page-id is the id of the page which holds the speak clause specification.
; next-page-url is the name of the next page in the show
(define (normalize-speak clause-contents lecture-id page-id next-page-name)
 (let* ((clause-contents-list
          (cond ((and show-and-speak? (one-number-list? clause-contents)) (list (list 'slide 1 (car clause-contents))))
                ((and show-and-speak? (list? clause-contents)) clause-contents)
                (else '())))
        (clause-names (map (lambda (cc) (speak-clause-spec-to-name lecture-id page-id cc)) clause-contents-list))
        (next-clause-names (shift-clause-names clause-names next-page-name))
       )
   (map2
     (lambda (clause-prefix next-name)
       (let ((kind (first clause-prefix))
             (number (second clause-prefix))
             (time (third clause-prefix))
            )
         (make-speak-clause 
             kind number
             (cond ((number? time) (+ time additional-showing-time))
                   ((list? time) (map (lambda (t) (+ t additional-showing-time)) time))
                   (else (error "normalize-speak: time is expected to be either number of list of numbers")))
             next-name
         )
        )
     )
     clause-contents-list next-clause-names)))

; Is x a list with a single number?
(define (one-number-list? x)
 (and (list? x) (= 1 (length x)) (number? (car x))))

; Clause names is a list of either names, or non-empty list of names (image series part names).
; Shift these names in a special way, which reflects the next name in the sequence.
(define (shift-clause-names clause-names final-name)
  (cond ((null? clause-names) '()) ; Is only used if clause-names is empty. Not recursion basis.
        ((and (null? (cdr clause-names)) (string? (car clause-names)))
             (list final-name))    ; @a hereafter: at least two elements
        ((and (null? (cdr clause-names)) (list? (car clause-names)))  ; @i hereafter: at least two elements
             (list (shift-clause-names (car clause-names) final-name)))  
        ((and (string? (car clause-names)) (string? (cadr clause-names))) ; @b
           (cons (cadr clause-names) (shift-clause-names (cdr clause-names) final-name)))
        ((and (string? (car clause-names)) (list? (cadr clause-names)) (not (null? (cadr clause-names)))) ; @c
           (cons (car (cadr clause-names)) (shift-clause-names (cdr clause-names) final-name)))
        ((and (string? (car clause-names)) (list? (cadr clause-names)) (null? (cadr clause-names)))
           (error "shift-clause-names: An empty list encountered, corresponding to empty image series."))
        ((and (list? (car clause-names)) (not (null? (car clause-names))) (string? (cadr clause-names))) ; @d
           (cons (shift-clause-names (car clause-names) (cadr clause-names))
                 (shift-clause-names (cdr clause-names) final-name)))
        ((and (list? (car  clause-names)) (not (null? (car  clause-names))) 
              (list? (cadr clause-names)) (not (null? (cadr clause-names)))) ; @e
           (cons (shift-clause-names (car clause-names) (car (cadr clause-names)))
                 (shift-clause-names (cdr clause-names) final-name)))
        ((and (list? (car  clause-names)) (list? (cadr clause-names)) 
              (or (null? (car clause-names)) (null? (cadr clause-names))))
           (error "shift-clause-names: An empty list encountered, corresponding to empty image series."))
        (else (error "shift-clause-names: Should not happen"))))

           

; Given a speak-clause specification return the name of the page which presents the page and the speak.
; In cause the clause is an image series, return a list of names of all the pages in the series.
(define (speak-clause-spec-to-name lecture-id page-id spec)
 (let ((kind (first spec))
       (number (second spec))
       (time (third spec))
      )
   (cond ((eq? kind 'slide-part) (show-and-speak-slide-name lecture-id page-id number))
         ((eq? kind 'program-part) (program-name lecture-id page-id 'show number))
         ((eq? kind 'exercise-part) (exercise-name lecture-id page-id 'show number))
         ((and (eq? kind 'image-series-part) (list? time))
            (map 
              (lambda (n)
                 (image-name lecture-id page-id 'show number n))
              (number-interval 1 (length time))))
         (else (error (string-append "Problems in speak-clause-spec-to-name: " (as-string kind) ", " (as-string number)
                                     ", " (as-string time)))))))
 
; Speak clause selector functions
(define speak-clause-kind (make-selector-function 2 "speak-clause-kind"))
(define speak-clause-number (make-selector-function 3 "speak-clause-number"))
(define speak-clause-time (make-selector-function 4 "speak-clause-time"))
(define speak-clause-next-name (make-selector-function 5 "speak-clause-next-url"))
(define speak-clause-sub-number (make-selector-function 6 "speak-clause-sub-number"))

; Speak clause contructor function.
; One optional parameter is supported, namely a sub-number of an image series (used for exploded specs only)
(define (make-speak-clause kind number time next-url . optional-parameters)
 (let ((sub-number (optional-parameter 1 optional-parameters #f)))
  (if sub-number
    (list 'speak-clause kind number time next-url sub-number)
    (list 'speak-clause kind number time next-url))))

; Return a speak selector function for part (higher order function).
(define (speak-select part)
  (lambda (speak-clause)
     (eq? (speak-clause-kind speak-clause) part)))

(define (speak-select-number part number)
  (lambda (speak-clause)
     (and 
        (eq? (speak-clause-kind speak-clause) part)
        (= (speak-clause-number speak-clause) number))))

(define (make-show-and-speak-slide slide-spec page-id elements)
 (let ((title-element (title-of-elements elements))
       (long-slide? (find-element 'long-slide elements))
       (element-keywords (extract-note-page-keywords elements))
       (clause-number (speak-clause-number slide-spec))
       (clause-time (speak-clause-time slide-spec))
       (clause-next-name (speak-clause-next-name slide-spec))
      )
  (reset-page-element-numbers)
  (write-text-file
   (show-and-speak-slide
    title-element
    (con
     (background-speaker-sound  (speak-name lecture-id page-id 'slide-part clause-number))
     (as-slide-text
      (apply con
	     (map
	      (lambda (e)
		(present-element
		 'slide-style
		 (element-tag e)
		 (element-contents e)) 
		)
	      elements))))
    long-slide?
    element-keywords
    (down-links elements lecture-id page-id 'slide)
    (html-file (as-string clause-next-name))
    clause-time 
    )
   (destination-path (show-and-speak-slide-name lecture-id page-id clause-number)))))

; Make a show and speak LENO by means with Javascript if the variable java-scripting allows it.
(define (show-and-speak-slide title contents long? keywords-to-meta down-links next-link show-time)
 (let* ((meta-contribution (if (null? keywords-to-meta) 
                              '()
                              (list (list 'name "keywords" 
                                  'lang (meta-language language-preference)
                                  'content (comma-separated-string keywords-to-meta)))))
        (prev (if (previous-page) (previous-page) #f))
        (next (if (next-page) (next-page) #f))
        (body (con 
                 (slide-start-marker)
                 (if slide-header-as-frame?
                    "" 
                    (cond ((eq? slide-header? 'normal) (con (slide-header 'show-and-speak next-link) (br)))
                          ((eq? slide-header? 'none) "")
                          ((eq? slide-header? 'minimal) (left-right-banner "" (minimal-slide-header)))
                          (else (string-append "Standard-slide: Unknown slide-header?: " (as-string slide-header?)))))
                 contents
                 (if slide-header-as-frame? "" (if long? 
                                                   (empty-slide-footer)     ; alternatively (long-slide-footer)
                                                   (empty-slide-footer)))
                 (slide-end-marker)))
        (body1 (if (> slide-page-offset 0) (indent-pixels slide-page-offset body) body))
       )
  (if java-scripting
   (timed-page
    (as-string title)
    show-time
    next-link
    meta-contribution
    body1

    slide-background-color black black black )
   (error "Use of show and speak slides requires that the variable java-scripting is turned on (value true).")
)))

(define (show-and-speak-program context-url title contents next-link show-time program-number)
  (let ((body  (con (program-header context-url (key-shortcut (text-choice "Tilbage til slide" "Back to slide") "u") next-link program-number)
                    (vertical-space 1)
                    (indent-pixels 10 (font-size slide-font-size contents)))))
    (if java-scripting
        (timed-page
         (as-string title)
         show-time
         next-link 
         '()
         body
         slide-background-color black black black
	 )
      (error "show-and-speak-program: Use of show and speak slides requires that the variable java-scripting is turned on (value true).")
    )))

(define (show-and-speak-image-series context-url prev-url next-url header title image-file next-link show-time speak-file-name im-ser-number number-in-series)
  (let ((body  (con (image-header context-url prev-url next-url next-link im-ser-number number-in-series) (vertical-space 1)
                    (indent-pixels 10 
                      (con (font-size slide-font-size title) (vertical-space 2)
                           (img-0 (string-append  "." "/" "graphics/" image-file)))))))
    (if java-scripting
      (timed-page
        (as-string header) 
        show-time
        next-link
        '()
        (con 
         (background-speaker-sound  speak-file-name)
         body
        )
        slide-background-color black black black
      )
      (error "show-and-speak-image-series: Use of show and speak slides requires that the variable java-scripting is turned on (value true).")
     )))


(define (save-slide-image-show-and-speak img-file img-text dest-file-name context-url prev-url next-url im-ser-number number-in-series)
 (let ((image-series-show-and-speak-clause 
          (filter (speak-select-number 'image-series-part im-ser-number) current-show-and-speak-specification)))

   (if (and show-and-speak? (= 1 (length image-series-show-and-speak-clause)))
       (let* ((the-clause (first image-series-show-and-speak-clause))
              (clause-number (speak-clause-number the-clause))
              (clause-times (speak-clause-time the-clause))
              (clause-time (list-ref clause-times (- number-in-series 1)))
              (clause-next-names (speak-clause-next-name the-clause))
              (clause-next-name (list-ref clause-next-names (- number-in-series 1)))
             )
        (write-text-file
  	 (show-and-speak-image-series
	  context-url prev-url next-url
	  "Image series"
          img-text
          img-file
	  (html-file clause-next-name)
	  clause-time
          (speak-name lecture-id page-id 'image-series-part im-ser-number number-in-series)
          im-ser-number number-in-series
	  )
	 (destination-path (image-name lecture-id page-id 'show clause-number number-in-series)))       
       )
   )
))

(define (end-show-and-speak-page)
  (page-1
     (string-append "End of " lecture-title)
     '()
     (con 
       (vertical-space 5)
       (center

           (font-size 5 (b (con (text-choice "Slut p " "End of ") lecture-title))) (p)

           (a-tag (html-file (index-name lecture-id)) (text-choice "Lektionsindeks" "Lecture index"))

       )
     )
     black white white white
  )
)
; Return an internal speak entry, to go on the internal -.spk file.
; lecture-id is the id of the lecture
; page-id is the page id of the relevant note page.
; kind is a symbol, one of slide-part, program-part, exercise-part, and image-series-part
; part is the part number 
; show-and-speak-name is the name of the show-and-speak HTML file (excluding extension).
; sound file name is the sound file (excluding extension) in the speak directory.
; explanation is a string explaing the role of the page
(define (make-internal-speak-entry lecture-id page-id kind part show-and-speak-name sound-file-name time explanation)
  (list 'internal-speak (as-symbol lecture-id) (as-symbol page-id) 
                        (as-symbol kind) (as-number part) 
                        (as-string show-and-speak-name) (as-string sound-file-name)
                        (as-number time) (as-string explanation)))

; Internal speak selectors:
(define internal-speak-lecture-id (make-selector-function 2 ""))
(define internal-speak-page-id (make-selector-function 3 ""))
(define internal-speak-kind (make-selector-function 4 ""))
(define internal-speak-part (make-selector-function 5 ""))
(define internal-speak-name (make-selector-function 6 ""))
(define internal-speak-sound (make-selector-function 7 ""))
(define internal-speak-time (make-selector-function 8 ""))
(define internal-speak-explanation (make-selector-function 9 ""))


(define (internal-show-and-speak-page internal-speak-list)
 (page-1 
   "Internal speak list"
   '()
   (con 
     (h 1 (con "Show and speak: " lecture-title))

     (general-show-and-speak-info) (p)

     (table-2 1
        (list 20 50 200 20 250 250)
        (make-list 6 white)
        (list "Nr." "Kind" "Title" "Time" "Show and speak page" "Sound file")
        (map2 present-internal-speak-entry internal-speak-list (number-interval 1 (length internal-speak-list)))
     )

     (p)

     (let* ((secs (sum-list (map internal-speak-time internal-speak-list)))
            (mins (quotient secs 60))
            (secs1 (modulo secs 60)))

       (con (b "Samlet spilletid: ") (as-string mins) " minutter og " (as-string secs1) " sekunder")) (p)

    (when-generated)  

   )
   white black black black))

; Present and entry in the internal speak file
(define (present-internal-speak-entry entry n)
 (let* ((lec-id (internal-speak-lecture-id entry))
        (pag-id (internal-speak-page-id entry))
        (kind (internal-speak-kind entry))
        (part (internal-speak-part entry))
        (name (internal-speak-name entry))
        (sound (internal-speak-sound entry))
        (time (internal-speak-time entry))
        (expl (internal-speak-explanation entry))
        (sound-exists? (if speak-file-prefix (file-exists? (sound-file-path sound)) #f))
       )
    (list (as-string n)
          (font-size 2 
           (con
            (cond ((eq? kind 'program-part) "Pr")
                  ((eq? kind 'slide-part) (b "Sl"))
                  ((eq? kind 'image-series-part) "Is")
                  ((eq? kind 'exercise-part) "Ex")
                  (else "???"))
            " " (as-string part)))
          (html4:a (font-1 2 (if (and (eq? kind 'slide-part) (= 1 part)) red black) (as-string expl))
                   'href (html-file (slide-name lec-id pag-id)) 'css:text-decoration "none")
          (as-string time)
          (html4:a (font-size 2 name) 'href (html-file name) 'css:text-decoration "none")
          (html4:a (font-1 2 (if sound-exists? red black) sound) 'href (speak-url sound) 'css:text-decoration "none" ))))

; Given a spec, which is a normalized show-and-speak clause specification,
; add appropriate internal-speak-entries to the global variable speak-list-in-this-lecture
(define (add-to-internal-speak-entries spec)
 (let ((exploded-spec (internal-explosion spec)))
   (for-each
     (lambda (spec)
       (set! speak-list-in-this-lecture
         (cons 
           (let ((kind (speak-clause-kind spec))
                 (part (speak-clause-number spec))
                 (time (speak-clause-time spec)))
             (make-internal-speak-entry
                lecture-id page-id kind part 
                (cond ((eq? kind 'slide-part) (show-and-speak-slide-name lecture-id page-id part))
                      ((eq? kind 'program-part) (program-name lecture-id page-id 'show part))
                      ((eq? kind 'exercise-part) "???-not-implemented")
                      ((eq? kind 'image-series-part) (image-name lecture-id page-id 'show part (speak-clause-sub-number spec)))
                      (else "????"))
                (if (eq? kind 'image-series-part) 
                    (speak-name lecture-id page-id kind part (speak-clause-sub-number spec))
                    (speak-name lecture-id page-id kind part))
                time
                (cond ((eq? kind 'slide-part) page-title)
                      ((eq? kind 'program-part) (string-append "Program nummer " (as-string part) " p " page-title))
                      ((eq? kind 'exercise-part) (string-append "Opgave nummer " (as-string part) " p " page-title))
                      ((eq? kind 'image-series-part) 
                         (string-append "Billedserie nummer " (as-string part) 
                                        "(" (as-string (speak-clause-sub-number spec)) ")  p " page-title))
                      (else "???"))))
           speak-list-in-this-lecture)))
      exploded-spec)))

; explode image series in spec-list, hereby flattening the specification
(define (internal-explosion spec-list)
 (flatten
  (map 
    (lambda (spec)
     (cond ((or (eq? (speak-clause-kind spec) 'slide-part)
               (eq? (speak-clause-kind spec) 'program-part)
               (eq? (speak-clause-kind spec) 'exercise-part))
             (list spec))
           ((eq? (speak-clause-kind spec) 'image-series-part)
             (let ((times (speak-clause-time spec)) ; a list of times for image series
                   (nexts (speak-clause-next-name spec)) ; also a list
                   (number (speak-clause-number spec))
                  )
               (map3 (lambda (time next sub-number)
                       (make-speak-clause 'image-series-part number time next sub-number))
                     times nexts (number-interval 1 (length times)))))
           (else (error "internal-explosion: Unknown kind of clause spec"))))
     spec-list)))


; sound name is the pure name of the sound file without prefix path and without extension            
(define (background-speaker-sound sound-name)
  (if (file-exists? (sound-file-path sound-name))
      (itag1 'bgsound (list 'src (speak-url sound-name)))
      "") 
)

; sound name is the pure name of the sound file without prefix path and without extension            
; As a precondition, assume that sound-source is the symbol real-audio.
(define (background-speaker-sound sound-name)
  (if (file-exists? (sound-file-path sound-name))
      (itag1 'embed
        (list 
          'console "Speaker sound"
          'src (speak-url sound-name)
          'controls "ControlPanel"
          'width "0"      ; invisible control - necessary due to interferrence with timing.
          'height "0"
          'type "audio/x-pn-realaudio-plugin"
          'nojava "true"
          'autostart "true"
        )
      )
      "")
)

; Return an informative string that reports on the show-and-speak settings:
(define (general-show-and-speak-info)
 (font-size 2
  (con 
    (b "default-showing-time: ") (as-string default-showing-time) " seconds" (br)
    (b "additional-showing-time: ") (as-string additional-showing-time) " seconds" (br)
    (b "sound-source: ") (as-string sound-source) (br)
    (b "speak-url-prefix: ") (as-string speak-url-prefix) (br)
    (b "speak-file-prefix: ") (as-string speak-file-prefix) (br)
  )))


; ---------------------------------------------------------------------------------------------------

; Show a logo img linked to logo-url. The logo image must be in the note-specific-image-files.
(define (logo-img . optional-parameter-list)
 (let* ((width (optional-parameter 1 optional-parameter-list #f))
        (img-glyph (if width (img-LN "logo.gif" "" width) (img-LN "logo.gif" "")))
       )
  (if (file-exists? (string-append note-source-directory "images/logo.gif"))
      (if (not (empty-string? logo-url))
          (a-tag logo-url img-glyph)
          img-glyph)
      "")))

; ---------------------------------------------------------------------------------------------------
; Lisp representation of entire note contents

; Return the full path of the lsp file for id.
; A lsp file contains the the entire contents of the lecture notes as a datastructure.
; Id defaults to the value of the global varible lecture-id
(define (lsp-file-name . id)
 (let ((id-1 (if (null? id) (as-string lecture-id) (as-string (first id)))))
   (string-append note-source-directory "internal/" id-1 ".lsp")))


; ---------------------------------------------------------------------------------------------------
; Per Madsen:

(define (a-tag-per url anchor accesskey)
  (a 'href url 'accesskey accesskey anchor))

; ---------------------------------------------------------------------------------------------------

; Return element, on the form as constructed by make-element, given
; lecture id, page id, element kind, element id, and further identification.
; The lecture id defaults to the current lecture-id if given as *.
; The page id defaults to the current page id if given as *
; The element kind must be one of the possible LENO element, such as point or items or item.
; Alternatively, element-id must be * (meaning the first encountered in the search).
(define (lookup-element lect-id pg-id element-kind element-id)
  (let ((final-lect-id (if (eq? '* (as-symbol lect-id)) lecture-id (as-symbol lect-id)))
        (final-page-id (if (eq? '* (as-symbol pg-id)) page-id (as-symbol pg-id)))
        (final-element-kind (as-symbol element-kind))
        (final-element-id (as-symbol element-id))
       )
    (let ((page-clauses (lookup-page-clause lect-id pg-id)))
      (if page-clauses 
          (lookup-element-in-sexpr page-clauses element-kind element-id)
          #f))))

; Return the lisp representation of the page clause with lecture id lect-id and page id pg-id.
; Return #f if none such exists.
(define (lookup-page-clause lect-id pg-id)
  (let* ((lsp-name (lsp-file-name lect-id))
         (lecture-structure 
            (if (file-exists? lsp-name)
                (file-read lsp-name)
                ()))
         (page-structure (find-in-list (lambda (pg) (eq? (id-of-lisp-page pg) pg-id)) lecture-structure))
        )
    (if page-structure
        (elements-of-lisp-page page-structure)
        #f)))

; precondition: pages-clauses is a list of elements
; a raw Sexpr search for a suitable structure
(define (lookup-element-in-sexpr sexpr el-kind el-id)
  (cond ((and (pair? sexpr) (leno-element? sexpr))
           (if (and (eq? (element-tag sexpr) el-kind) (if (eq? el-id '*) #t (eq? (element-id sexpr) el-id)))
               sexpr
               (let ((car-res (lookup-element-in-sexpr (car sexpr) el-kind el-id)))
                  (if car-res
                      car-res
                      (lookup-element-in-sexpr (cdr sexpr) el-kind el-id)))))
        ((pair? sexpr) 
               (let ((car-res (lookup-element-in-sexpr (car sexpr) el-kind el-id)))
                  (if car-res
                      car-res
                      (lookup-element-in-sexpr (cdr sexpr) el-kind el-id))))
        (else #f)))

; Do we identify x as a leno element in the Lisp representation of a page.
(define (leno-element? x)
  (turn-into-boolean (and (and (list? x) (= 3 (length x)) (memq (as-symbol (car x)) possible-leno-elements)))))
               
  
  

; ---------------------------------------------------------------------------------------------------
; IDAFUS support. Used in case distance-education-support? is #t


; Define an activity in IDAFUS, in the fixed unit idafus-unit-id, corresponding to the exicercise data passed as
; parameter to this procedure.
(define (make-idafus-activity! activity-id title formulation-text solution-text)
 (let* ((data-save-directory (string-append idafus-absolute-cgi-path "teacher-part" "/" "data" "/" (as-string idafus-unit-id) "/"))
        (existing-index (file-read (string-append data-save-directory "all.dat")))
        (cur-time (current-time))
        (dt-tm (date-time cur-time))
       )

  ; updata all.dat if necessary
  (if (not (member (as-string activity-id) existing-index))
      (file-append (string-append data-save-directory "all.dat") (as-string activity-id)))

  ; write the activity alist
  (file-write
    (propertylist-to-alist
      (list 
        'last-modifier idafus-teacher
        'date (car dt-tm)
        'time (cadr dt-tm)
        'second-count cur-time
        'unit-id (as-string idafus-unit-id)
        'activity-id (as-string activity-id)
        'prev-activity-id ""
        'next-activity-id ""
        'primary-activity "false"
        'start-date idafus-start-date
        'start-time ""
        'end-date idafus-end-date
        'end-time ""
        'teacher idafus-teacher
        'activity-title title
        'formulation-format "html"
        'formulation-location "here"
        'activity-formulation formulation-text
        'clarification-format "html"
        'clarification-location "here"
        'activity-clarification solution-text
        'top-level-contribution-types "contribution point-of-view question done"
        'non-top-level-contribution-types "contribution point-of-view question answer disagreement agreement"
        'html-base ""
        'activity-visibility "private"
        'group-members ""
        'password ""))
     (string-append data-save-directory (as-string activity-id))
  )))